/* Adapted for use with IAR Embedded Workbench */

#ifndef __IO_R8CL35C_H__
#define __IO_R8CL35C_H__

#ifdef __IAR_SYSTEMS_ICC__
#pragma language=extended

#ifndef _SYSTEM_BUILD
#pragma system_include
#endif
                                                                         
                                                                         
                                                                         
                                                                         
                                                                         
                                                                         
                                                                         
                                                                         
                                                                         
                                                                         
                                                                         
/*******************************************************************************
*
* Device       : R8C/L35C Group
*
* File Name    : sfr_r8l35c.h
*
* Abstract     : definition of R8C/L35C Group SFR
*
* History      : 1.10  ( 2010-06-18 ) [Hardware Manual Revision : 1.00]
*                1.00  ( 2010-02-26 ) [Hardware Manual Revision : 0.10]
*                0.01  ( 2009-11-16 ) [Hardware Manual Revision : -]
*
* NOTE         : THIS IS A TYPICAL EXAMPLE.
*
*  Copyright (C) 2010 Renesas Electronics Corporation and
*  Renesas Solutions Corp. All rights reserved.
*
*******************************************************************************/
/********************************************************
*  declare SFR addresses                                *
********************************************************/

/********************************************************
*  declare SFR bit                                      *
********************************************************/
struct	bit_def {
	unsigned char	b0:1;
	unsigned char	b1:1;
	unsigned char	b2:1;
	unsigned char	b3:1;
	unsigned char	b4:1;
	unsigned char	b5:1;
	unsigned char	b6:1;
	unsigned char	b7:1;
};
union	byte_def{
	struct	bit_def bit;
	unsigned char	byte;
};

/*------------------------------------------------------
  Processor Mode Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	pm0_addr@0x0004;
#define		pm0			pm0_addr.byte

#define		pm03		pm0_addr.bit.b3			/* Software reset bit */

/*------------------------------------------------------
  Processor Mode Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	pm1_addr@0x0005;
#define		pm1			pm1_addr.byte

#define		pm12		pm1_addr.bit.b2			/* WDT interrupt/reset switch bit */

/*------------------------------------------------------
  System Clock Control Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	cm0_addr@0x0006;
#define		cm0			cm0_addr.byte

#define		cm01		cm0_addr.bit.b1			/* Peripheral function clock stop bit in wait mode */
#define		cm02		cm0_addr.bit.b2			/* Peripheral function clock stop bit in wait mode */
#define		cm03		cm0_addr.bit.b3			/* XCIN clock stop bit */
#define		cm04		cm0_addr.bit.b4			/* XCIN external clock input enable bit */
#define		cm05		cm0_addr.bit.b5			/* XIN clock (XIN-XOUT) stop bit */
#define		cm06		cm0_addr.bit.b6			/* CPU clock division select bit 0 */
#define		cm07		cm0_addr.bit.b7			/* System clock select bit */

/*------------------------------------------------------
  System Clock Control Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	cm1_addr@0x0007;
#define		cm1			cm1_addr.byte

#define		cm10		cm1_addr.bit.b0			/* All clock stop control bit */
#define		cm11		cm1_addr.bit.b1			/* XIN-XOUT on-chip feedback resistor select bit */
#define		cm12		cm1_addr.bit.b2			/* XCIN-XCOUT on-chip feedback resistor select bit */
#define		cm13		cm1_addr.bit.b3			/* Port/XIN-XOUT switch bit */
#define		cm14		cm1_addr.bit.b4			/* Low-speed on-chip oscillator oscillation stop bit */
#define		cm16		cm1_addr.bit.b6			/* CPU clock division select bit 1 */
#define		cm17		cm1_addr.bit.b7			/* CPU clock division select bit 1 */

/*------------------------------------------------------
  Module standby control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	mstcr_addr@0x0008;
#define		mstcr		mstcr_addr.byte

#define		mstiic		mstcr_addr.bit.b3		/* SSU, I2C bus standby bit */
#define		msttrd		mstcr_addr.bit.b4		/* Timer RD standby bit */
#define		msttrc		mstcr_addr.bit.b5		/* Timer RC standby bit */
#define		msttrg		mstcr_addr.bit.b6		/* Timer RG standby bit */

/*------------------------------------------------------
  System clock control register 3
------------------------------------------------------*/
__no_init  volatile union	byte_def	cm3_addr@0x0009;
#define		cm3			cm3_addr.byte

#define		cm30		cm3_addr.bit.b0			/* WAIT control bit */
#define		cm35		cm3_addr.bit.b5			/* CPU clock division ratio select bit when exiting wait mode */
#define		cm36		cm3_addr.bit.b6			/* System clock select bit when exiting wait or stop mode */
#define		cm37		cm3_addr.bit.b7			/* System clock select bit when exiting wait or stop mode */

/*------------------------------------------------------
  Protect register
------------------------------------------------------*/
__no_init  volatile union	byte_def	prcr_addr@0x000A;
#define		prcr		prcr_addr.byte

#define		prc0		prcr_addr.bit.b0		/* Protect bit 0 */
#define		prc1		prcr_addr.bit.b1		/* Protect bit 1 */
#define		prc3		prcr_addr.bit.b3		/* Protect bit 3 */

/*------------------------------------------------------
  Reset source determination register
------------------------------------------------------*/
__no_init  volatile union	byte_def	rstfr_addr@0x000B;
#define		rstfr		rstfr_addr.byte

#define		cwr			rstfr_addr.bit.b0		/* Cold start-up/warm start-up determine flag */
#define		hwr			rstfr_addr.bit.b1		/* Hardware reset detect flag */
#define		swr			rstfr_addr.bit.b2		/* Software reset detect flag */
#define		wdr			rstfr_addr.bit.b3		/* Watchdog timer reset detect flag */

/*------------------------------------------------------
  Oscillation stop detection register
------------------------------------------------------*/
__no_init  volatile union	byte_def	ocd_addr@0x000C;
#define		ocd			ocd_addr.byte

#define		ocd0		ocd_addr.bit.b0			/* Oscillation stop detection enable bit */
#define		ocd1		ocd_addr.bit.b1			/* Oscillation stop detection interrupt enable bit */
#define		ocd2		ocd_addr.bit.b2			/* On-chip oscillator clock select bit */
#define		ocd3		ocd_addr.bit.b3			/* Clock monitor bit */

/*------------------------------------------------------
  Watchdog timer reset register
------------------------------------------------------*/
__no_init  volatile union	byte_def	wdtr_addr@0x000D;
#define		wdtr		wdtr_addr.byte

/*------------------------------------------------------
  Watchdog timer start register
------------------------------------------------------*/
__no_init  volatile union	byte_def	wdts_addr@0x000E;
#define		wdts		wdts_addr.byte

/*------------------------------------------------------
  Watchdog timer control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	wdtc_addr@0x000F;
#define		wdtc		wdtc_addr.byte

#define		wdtc7		wdtc_addr.bit.b7		/* Prescaler select bit */

/*------------------------------------------------------
  High-speed on-chip oscillator control register 7
------------------------------------------------------*/
__no_init  volatile union	byte_def	fra7_addr@0x0015;
#define		fra7		fra7_addr.byte

/*------------------------------------------------------
  Count Source Protection Mode Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	cspr_addr@0x001C;
#define		cspr		cspr_addr.byte

#define		cspro		cspr_addr.bit.b7		/* Count source protection mode select bit */

/*------------------------------------------------------
  Power-Off Mode Control Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	pomcr0_addr@0x0020;
#define		pomcr0		pomcr0_addr.byte

#define		pom00		pomcr0_addr.bit.b0		/* Power-off mode select bit/WKUP0 source power-off exit flag */

/*------------------------------------------------------
  High-speed on-chip oscillator control register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	fra0_addr@0x0023;
#define		fra0		fra0_addr.byte

#define		fra00		fra0_addr.bit.b0		/* High-speed on-chip oscillator enable bit */
#define		fra01		fra0_addr.bit.b1		/* High-speed on-chip oscillator select bit */
#define		fra03		fra0_addr.bit.b3		/* fOCO128 clock select bit */

/*------------------------------------------------------
  High-speed on-chip oscillator control register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	fra1_addr@0x0024;
#define		fra1		fra1_addr.byte

/*------------------------------------------------------
  High-speed on-chip oscillator control register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	fra2_addr@0x0025;
#define		fra2		fra2_addr.byte

#define		fra20		fra2_addr.bit.b0		/* High-speed on-chip oscillator frequency switch bit */
#define		fra21		fra2_addr.bit.b1		/* High-speed on-chip oscillator frequency switch bit */
#define		fra22		fra2_addr.bit.b2		/* High-speed on-chip oscillator frequency switch bit */

/*------------------------------------------------------
  On-chip reference voltage control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	ocvrefcr_addr@0x0026;
#define		ocvrefcr	ocvrefcr_addr.byte

#define		ocvrefan	ocvrefcr_addr.bit.b0	/* On-chip reference voltage to analog input connect bit */

/*------------------------------------------------------
  High-speed on-chip oscillator control register 4
------------------------------------------------------*/
__no_init  volatile union	byte_def	fra4_addr@0x0029;
#define		fra4		fra4_addr.byte

/*------------------------------------------------------
  High-speed on-chip oscillator control register 5
------------------------------------------------------*/
__no_init  volatile union	byte_def	fra5_addr@0x002A;
#define		fra5		fra5_addr.byte

/*------------------------------------------------------
  High-speed on-chip oscillator control register 6
------------------------------------------------------*/
__no_init  volatile union	byte_def	fra6_addr@0x002B;
#define		fra6		fra6_addr.byte

/*------------------------------------------------------
  High-speed on-chip oscillator control register 3
------------------------------------------------------*/
__no_init  volatile union	byte_def	fra3_addr@0x002F;
#define		fra3		fra3_addr.byte

/*------------------------------------------------------
  Voltage Monitor Circuit Control Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	cmpa_addr@0x0030;
#define		cmpa		cmpa_addr.byte

#define		irq1sel		cmpa_addr.bit.b4		/* Voltage monitor 1 interrupt select bit */
#define		irq2sel		cmpa_addr.bit.b5		/* Voltage monitor 2 interrupt select bit */
#define		compsel		cmpa_addr.bit.b7		/* Voltage monitor interrupt type selection enable bit */

/*------------------------------------------------------
  Voltage monitor circuit edge select register
------------------------------------------------------*/
__no_init  volatile union	byte_def	vcac_addr@0x0031;
#define		vcac		vcac_addr.byte

#define		vcac1		vcac_addr.bit.b1		/* Voltage monitor 1 circuit edge select bit */
#define		vcac2		vcac_addr.bit.b2		/* Voltage monitor 2 circuit edge select bit */

/*------------------------------------------------------
  Voltage Detect Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	vca1_addr@0x0033;
#define		vca1		vca1_addr.byte

#define		vca13		vca1_addr.bit.b3		/* Voltage detection 2 signal monitor flag */

/*------------------------------------------------------
  Voltage Detect Register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	vca2_addr@0x0034;
#define		vca2		vca2_addr.byte

#define		vca20		vca2_addr.bit.b0		/* Internal power low consumption enable bit */
#define		vca25		vca2_addr.bit.b5		/* Voltage detection 0 enable bit */
#define		vca26		vca2_addr.bit.b6		/* Voltage detection 1 enable bit */
#define		vca27		vca2_addr.bit.b7		/* Voltage detection 2 enable bit */

/*------------------------------------------------------
  Voltage detection 1 level select register
------------------------------------------------------*/
__no_init  volatile union	byte_def	vd1ls_addr@0x0036;
#define		vd1ls		vd1ls_addr.byte

#define		vd1s0		vd1ls_addr.bit.b0		/* Voltage detection 1 Level select bit */
#define		vd1s1		vd1ls_addr.bit.b1		/* Voltage detection 1 Level select bit */
#define		vd1s2		vd1ls_addr.bit.b2		/* Voltage detection 1 Level select bit */
#define		vd1s3		vd1ls_addr.bit.b3		/* Voltage detection 1 Level select bit */

/*------------------------------------------------------
  Voltage monitor 0 circuit control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	vw0c_addr@0x0038;
#define		vw0c		vw0c_addr.byte

#define		vw0c0		vw0c_addr.bit.b0		/* Voltage monitor 0 reset enable bit */

/*------------------------------------------------------
  Voltage monitor 1 circuit control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	vw1c_addr@0x0039;
#define		vw1c		vw1c_addr.byte

#define		vw1c0		vw1c_addr.bit.b0		/* Voltage monitor 1 reset enable bit */
#define		vw1c1		vw1c_addr.bit.b1		/* Voltage monitor 1 digital filter disable mode select bit */
#define		vw1c2		vw1c_addr.bit.b2		/* Voltage change detection flag */
#define		vw1c3		vw1c_addr.bit.b3		/* Voltage detection 1 signal monitor flag */
#define		vw1f0		vw1c_addr.bit.b4		/* Sampling clock select bit */
#define		vw1f1		vw1c_addr.bit.b5		/* Sampling clock select bit */
#define		vw1c7		vw1c_addr.bit.b7		/* Voltage monitor 1 reset generation condition select bit */

/*------------------------------------------------------
  Voltage Monitor 2 Circuit Control Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	vw2c_addr@0x003A;
#define		vw2c		vw2c_addr.byte

#define		vw2c0		vw2c_addr.bit.b0		/* Voltage monitor 2 interrupt enable bit */
#define		vw2c1		vw2c_addr.bit.b1		/* Voltage monitor 2 digital filter disable mode select bit */
#define		vw2c2		vw2c_addr.bit.b2		/* Voltage change detection flag */
#define		vw2c3		vw2c_addr.bit.b3		/* WDT detection monitor flag */
#define		vw2f0		vw2c_addr.bit.b4		/* Sampling clock select bit */
#define		vw2f1		vw2c_addr.bit.b5		/* Sampling clock select bit */
#define		vw2c7		vw2c_addr.bit.b7		/* Voltage monitor 2 interrupt generation condition select bit */

/*------------------------------------------------------
  DTC Activation Control Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtctl_addr@0x0080;
#define		dtctl		dtctl_addr.byte

#define		nmif		dtctl_addr.bit.b1		/* Non-maskable interrupt generation bit */

/*------------------------------------------------------
  DTC Activation Enable Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcen0_addr@0x0088;
#define		dtcen0		dtcen0_addr.byte

#define		dtcen00		dtcen0_addr.bit.b0		/* DTC activation enable bit */
#define		dtcen01		dtcen0_addr.bit.b1		/* DTC activation enable bit */
#define		dtcen02		dtcen0_addr.bit.b2		/* DTC activation enable bit */
#define		dtcen03		dtcen0_addr.bit.b3		/* DTC activation enable bit */
#define		dtcen04		dtcen0_addr.bit.b4		/* DTC activation enable bit */
#define		dtcen05		dtcen0_addr.bit.b5		/* DTC activation enable bit */
#define		dtcen06		dtcen0_addr.bit.b6		/* DTC activation enable bit */
#define		dtcen07		dtcen0_addr.bit.b7		/* DTC activation enable bit */

/*------------------------------------------------------
  DTC Activation Enable Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcen1_addr@0x0089;
#define		dtcen1		dtcen1_addr.byte

#define		dtcen10		dtcen1_addr.bit.b0		/* DTC activation enable bit */
#define		dtcen11		dtcen1_addr.bit.b1		/* DTC activation enable bit */
#define		dtcen12		dtcen1_addr.bit.b2		/* DTC activation enable bit */
#define		dtcen13		dtcen1_addr.bit.b3		/* DTC activation enable bit */
#define		dtcen14		dtcen1_addr.bit.b4		/* DTC activation enable bit */
#define		dtcen15		dtcen1_addr.bit.b5		/* DTC activation enable bit */
#define		dtcen16		dtcen1_addr.bit.b6		/* DTC activation enable bit */
#define		dtcen17		dtcen1_addr.bit.b7		/* DTC activation enable bit */

/*------------------------------------------------------
  DTC Activation Enable Register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcen2_addr@0x008A;
#define		dtcen2		dtcen2_addr.byte

#define		dtcen20		dtcen2_addr.bit.b0		/* DTC activation enable bit */
#define		dtcen21		dtcen2_addr.bit.b1		/* DTC activation enable bit */
#define		dtcen22		dtcen2_addr.bit.b2		/* DTC activation enable bit */
#define		dtcen23		dtcen2_addr.bit.b3		/* DTC activation enable bit */
#define		dtcen24		dtcen2_addr.bit.b4		/* DTC activation enable bit */
#define		dtcen25		dtcen2_addr.bit.b5		/* DTC activation enable bit */
#define		dtcen26		dtcen2_addr.bit.b6		/* DTC activation enable bit */
#define		dtcen27		dtcen2_addr.bit.b7		/* DTC activation enable bit */

/*------------------------------------------------------
  DTC Activation Enable Register 3
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcen3_addr@0x008B;
#define		dtcen3		dtcen3_addr.byte

#define		dtcen30		dtcen3_addr.bit.b0		/* DTC activation enable bit */
#define		dtcen31		dtcen3_addr.bit.b1		/* DTC activation enable bit */
#define		dtcen32		dtcen3_addr.bit.b2		/* DTC activation enable bit */
#define		dtcen33		dtcen3_addr.bit.b3		/* DTC activation enable bit */
#define		dtcen34		dtcen3_addr.bit.b4		/* DTC activation enable bit */
#define		dtcen35		dtcen3_addr.bit.b5		/* DTC activation enable bit */
#define		dtcen36		dtcen3_addr.bit.b6		/* DTC activation enable bit */
#define		dtcen37		dtcen3_addr.bit.b7		/* DTC activation enable bit */

/*------------------------------------------------------
  DTC Activation Enable Register 4
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcen4_addr@0x008C;
#define		dtcen4		dtcen4_addr.byte

#define		dtcen40		dtcen4_addr.bit.b0		/* DTC activation enable bit */
#define		dtcen41		dtcen4_addr.bit.b1		/* DTC activation enable bit */
#define		dtcen42		dtcen4_addr.bit.b2		/* DTC activation enable bit */
#define		dtcen43		dtcen4_addr.bit.b3		/* DTC activation enable bit */
#define		dtcen44		dtcen4_addr.bit.b4		/* DTC activation enable bit */
#define		dtcen45		dtcen4_addr.bit.b5		/* DTC activation enable bit */
#define		dtcen46		dtcen4_addr.bit.b6		/* DTC activation enable bit */
#define		dtcen47		dtcen4_addr.bit.b7		/* DTC activation enable bit */

/*------------------------------------------------------
  DTC Activation Enable Register 5
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcen5_addr@0x008D;
#define		dtcen5		dtcen5_addr.byte

#define		dtcen50		dtcen5_addr.bit.b0		/* DTC activation enable bit */
#define		dtcen51		dtcen5_addr.bit.b1		/* DTC activation enable bit */
#define		dtcen52		dtcen5_addr.bit.b2		/* DTC activation enable bit */
#define		dtcen53		dtcen5_addr.bit.b3		/* DTC activation enable bit */
#define		dtcen54		dtcen5_addr.bit.b4		/* DTC activation enable bit */
#define		dtcen55		dtcen5_addr.bit.b5		/* DTC activation enable bit */
#define		dtcen56		dtcen5_addr.bit.b6		/* DTC activation enable bit */
#define		dtcen57		dtcen5_addr.bit.b7		/* DTC activation enable bit */

/*------------------------------------------------------
  DTC Activation Enable Register 6
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcen6_addr@0x008E;
#define		dtcen6		dtcen6_addr.byte

#define		dtcen60		dtcen6_addr.bit.b0		/* DTC activation enable bit */
#define		dtcen61		dtcen6_addr.bit.b1		/* DTC activation enable bit */
#define		dtcen62		dtcen6_addr.bit.b2		/* DTC activation enable bit */
#define		dtcen63		dtcen6_addr.bit.b3		/* DTC activation enable bit */
#define		dtcen64		dtcen6_addr.bit.b4		/* DTC activation enable bit */
#define		dtcen65		dtcen6_addr.bit.b5		/* DTC activation enable bit */
#define		dtcen66		dtcen6_addr.bit.b6		/* DTC activation enable bit */
#define		dtcen67		dtcen6_addr.bit.b7		/* DTC activation enable bit */

/*------------------------------------------------------
  UART0 bit rate register
------------------------------------------------------*/
__no_init  volatile union	byte_def	u0brg_addr@0x00A1;
#define		u0brg		u0brg_addr.byte

/*------------------------------------------------------
  UART0 transmit buffer register Low
------------------------------------------------------*/
__no_init  volatile union	byte_def	u0tbl_addr@0x00A2;
#define		u0tbl		u0tbl_addr.byte

/*------------------------------------------------------
  UART0 transmit buffer register High
------------------------------------------------------*/
__no_init  volatile union	byte_def	u0tbh_addr@0x00A3;
#define		u0tbh		u0tbh_addr.byte

/*------------------------------------------------------
  UART0 Receive Buffer Register
------------------------------------------------------*/
__no_init  volatile unsigned short u0rb_addr@0x00A6;
#define		u0rb		u0rb_addr

/*------------------------------------------------------
  UART2 bit rate register
------------------------------------------------------*/
__no_init  volatile union	byte_def	u2brg_addr@0x00A9;
#define		u2brg		u2brg_addr.byte

/*------------------------------------------------------
  UART2 transmit buffer register Low
------------------------------------------------------*/
__no_init  volatile union	byte_def	u2tbl_addr@0x00AA;
#define		u2tbl		u2tbl_addr.byte

/*------------------------------------------------------
  UART2 transmit buffer register High
------------------------------------------------------*/
__no_init  volatile union	byte_def	u2tbh_addr@0x00AB;
#define		u2tbh		u2tbh_addr.byte

#define		mptb_u2tbh	u2tbh_addr.bit.b0		/* Transmit data */

/*------------------------------------------------------
  UART2 receive buffer register
------------------------------------------------------*/
__no_init  volatile unsigned short u2rb_addr@0x00AE;
#define		u2rb			u2rb_addr

/*------------------------------------------------------
  UART2 Digital Filter Function Select Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	urxdf_addr@0x00B0;
#define		urxdf		urxdf_addr.byte

#define		df2en		urxdf_addr.bit.b2		/* RXD2 digital filter enable bit */

/*------------------------------------------------------
  UART2 special mode register 5
------------------------------------------------------*/
__no_init  volatile union	byte_def	u2smr5_addr@0x00BB;
#define		u2smr5		u2smr5_addr.byte

#define		mp			u2smr5_addr.bit.b0		/* Multiprocessor Communication enable bit */
#define		mpie		u2smr5_addr.bit.b4		/* Multiprocessor Communication control bit */

/*------------------------------------------------------
  UART2 special mode register 4
------------------------------------------------------*/
__no_init  volatile union	byte_def	u2smr4_addr@0x00BC;
#define		u2smr4		u2smr4_addr.byte

#define		stareq		u2smr4_addr.bit.b0		/* Start condition generate bit */
#define		rstareq		u2smr4_addr.bit.b1		/* Restart condition generate bit */
#define		stpreq		u2smr4_addr.bit.b2		/* Stop condition generate bit */
#define		stspsel		u2smr4_addr.bit.b3		/* SCL, SDA output select bit */
#define		ackd		u2smr4_addr.bit.b4		/* ACK data bit */
#define		ackc		u2smr4_addr.bit.b5		/* ACK data output enable bit */
#define		sclhi		u2smr4_addr.bit.b6		/* SCL output stop enable bit */
#define		swc9		u2smr4_addr.bit.b7		/* SCL WAIT bit 3 */

/*------------------------------------------------------
  UART2 special mode register 3
------------------------------------------------------*/
__no_init  volatile union	byte_def	u2smr3_addr@0x00BD;
#define		u2smr3		u2smr3_addr.byte

#define		ckph		u2smr3_addr.bit.b1		/* Clock phase set bit */
#define		nodc		u2smr3_addr.bit.b3		/* Clock output select bit */
#define		dl0			u2smr3_addr.bit.b5		/* SDA2 digital delay setup bit */
#define		dl1			u2smr3_addr.bit.b6		/* SDA2 digital delay setup bit */
#define		dl2			u2smr3_addr.bit.b7		/* SDA2 digital delay setup bit */

/*------------------------------------------------------
  UART2 special mode register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	u2smr2_addr@0x00BE;
#define		u2smr2		u2smr2_addr.byte

#define		iicm2		u2smr2_addr.bit.b0		/* I2C mode select bit 2 */
#define		csc			u2smr2_addr.bit.b1		/* Clock synchronization bit */
#define		swc			u2smr2_addr.bit.b2		/* SCL wait output bit */
#define		stac		u2smr2_addr.bit.b4		/* UART2 initialization bit */
#define		swc2		u2smr2_addr.bit.b5		/* SCL wait output bit 2 */
#define		sdhi		u2smr2_addr.bit.b6		/* SDA output disable bit */

/*------------------------------------------------------
  UART2 special mode register
------------------------------------------------------*/
__no_init  volatile union	byte_def	u2smr_addr@0x00BF;
#define		u2smr		u2smr_addr.byte

#define		iicm		u2smr_addr.bit.b0		/* I2C mode select bit */
#define		bbs			u2smr_addr.bit.b2		/* Bus busy flag */

/*------------------------------------------------------
  A/D Mode Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	admod_addr@0x00D4;
#define		admod		admod_addr.byte

#define		cks0		admod_addr.bit.b0		/* Division select bit */
#define		cks1		admod_addr.bit.b1		/* Division select bit */
#define		cks2		admod_addr.bit.b2		/* Clock source select bit */
#define		md0			admod_addr.bit.b3		/* A/D operating mode select bit */
#define		md1			admod_addr.bit.b4		/* A/D operating mode select bit */
#define		md2			admod_addr.bit.b5		/* A/D operating mode select bit */
#define		adcap0		admod_addr.bit.b6		/* A/D conversion trigger select bit */
#define		adcap1		admod_addr.bit.b7		/* A/D conversion trigger select bit */

/*------------------------------------------------------
  A/D Input Select Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	adinsel_addr@0x00D5;
#define		adinsel		adinsel_addr.byte

#define		ch0			adinsel_addr.bit.b0		/* Analog input pin select bit */
#define		ch1			adinsel_addr.bit.b1		/* Analog input pin select bit */
#define		ch2			adinsel_addr.bit.b2		/* Analog input pin select bit */
#define		scan0		adinsel_addr.bit.b4		/* A/D sweep pin count select bit */
#define		scan1		adinsel_addr.bit.b5		/* A/D sweep pin count select bit */
#define		adgsel0		adinsel_addr.bit.b6		/* A/D input group select bit */
#define		adgsel1		adinsel_addr.bit.b7		/* A/D input group select bit */

/*------------------------------------------------------
  A/D Control Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	adcon0_addr@0x00D6;
#define		adcon0		adcon0_addr.byte

#define		adst		adcon0_addr.bit.b0		/* A/D conversion start flag */

/*------------------------------------------------------
  A/D Control Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	adcon1_addr@0x00D7;
#define		adcon1		adcon1_addr.byte

#define		adex0		adcon1_addr.bit.b0		/* Extended analog input pin select bit */
#define		bits		adcon1_addr.bit.b4		/* 8-/10-bit mode select bit */
#define		adstby		adcon1_addr.bit.b5		/* A/D standby bit */
#define		adddaen		adcon1_addr.bit.b6		/* A/D open-circuit detection assist function enable bit */
#define		adddael		adcon1_addr.bit.b7		/* A/D open-circuit detection assist method select bit */

/*------------------------------------------------------
  D/A 0 Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	da0_addr@0x00D8;
#define		da0			da0_addr.byte

/*------------------------------------------------------
  D/A 1 Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	da1_addr@0x00D9;
#define		da1			da1_addr.byte

/*------------------------------------------------------
  D/A Control Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	dacon_addr@0x00DC;
#define		dacon		dacon_addr.byte

#define		da0e_dacon	dacon_addr.bit.b0		/* D/A0 output enable bit */
#define		da1e_dacon	dacon_addr.bit.b1		/* D/A1 output enable bit */

/*------------------------------------------------------
  Port P0 register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p0_addr@0x00E0;
#define		p0			p0_addr.byte

#define		p0_0		p0_addr.bit.b0			/* Port P0_0 bit */
#define		p0_1		p0_addr.bit.b1			/* Port P0_1 bit */
#define		p0_2		p0_addr.bit.b2			/* Port P0_2 bit */
#define		p0_3		p0_addr.bit.b3			/* Port P0_3 bit */
#define		p0_4		p0_addr.bit.b4			/* Port P0_4 bit */
#define		p0_5		p0_addr.bit.b5			/* Port P0_5 bit */
#define		p0_6		p0_addr.bit.b6			/* Port P0_6 bit */
#define		p0_7		p0_addr.bit.b7			/* Port P0_7 bit */

/*------------------------------------------------------
  Port P1 register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p1_addr@0x00E1;
#define		p1			p1_addr.byte

#define		p1_0		p1_addr.bit.b0			/* Port P1_0 bit */
#define		p1_1		p1_addr.bit.b1			/* Port P1_1 bit */
#define		p1_2		p1_addr.bit.b2			/* Port P1_2 bit */
#define		p1_3		p1_addr.bit.b3			/* Port P1_3 bit */
#define		p1_4		p1_addr.bit.b4			/* Port P1_4 bit */
#define		p1_5		p1_addr.bit.b5			/* Port P1_5 bit */
#define		p1_6		p1_addr.bit.b6			/* Port P1_6 bit */
#define		p1_7		p1_addr.bit.b7			/* Port P1_7 bit */

/*------------------------------------------------------
  Port P0 direction register
------------------------------------------------------*/
__no_init  volatile union	byte_def	pd0_addr@0x00E2;
#define		pd0			pd0_addr.byte

#define		pd0_0		pd0_addr.bit.b0			/* Port P0_0 direction bit */
#define		pd0_1		pd0_addr.bit.b1			/* Port P0_1 direction bit */
#define		pd0_2		pd0_addr.bit.b2			/* Port P0_2 direction bit */
#define		pd0_3		pd0_addr.bit.b3			/* Port P0_3 direction bit */
#define		pd0_4		pd0_addr.bit.b4			/* Port P0_4 direction bit */
#define		pd0_5		pd0_addr.bit.b5			/* Port P0_5 direction bit */
#define		pd0_6		pd0_addr.bit.b6			/* Port P0_6 direction bit */
#define		pd0_7		pd0_addr.bit.b7			/* Port P0_7 direction bit */

/*------------------------------------------------------
  Port P1 direction register
------------------------------------------------------*/
__no_init  volatile union	byte_def	pd1_addr@0x00E3;
#define		pd1			pd1_addr.byte

#define		pd1_0		pd1_addr.bit.b0			/* Port P1_0 direction bit */
#define		pd1_1		pd1_addr.bit.b1			/* Port P1_1 direction bit */
#define		pd1_2		pd1_addr.bit.b2			/* Port P1_2 direction bit */
#define		pd1_3		pd1_addr.bit.b3			/* Port P1_3 direction bit */
#define		pd1_4		pd1_addr.bit.b4			/* Port P1_4 direction bit */
#define		pd1_5		pd1_addr.bit.b5			/* Port P1_5 direction bit */
#define		pd1_6		pd1_addr.bit.b6			/* Port P1_6 direction bit */
#define		pd1_7		pd1_addr.bit.b7			/* Port P1_7 direction bit */

/*------------------------------------------------------
  Port P2 register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p2_addr@0x00E4;
#define		p2			p2_addr.byte

#define		p2_0		p2_addr.bit.b0			/* Port P2_0 bit */
#define		p2_1		p2_addr.bit.b1			/* Port P2_1 bit */
#define		p2_2		p2_addr.bit.b2			/* Port P2_2 bit */
#define		p2_3		p2_addr.bit.b3			/* Port P2_3 bit */
#define		p2_4		p2_addr.bit.b4			/* Port P2_4 bit */
#define		p2_5		p2_addr.bit.b5			/* Port P2_5 bit */
#define		p2_6		p2_addr.bit.b6			/* Port P2_6 bit */
#define		p2_7		p2_addr.bit.b7			/* Port P2_7 bit */

/*------------------------------------------------------
  Port P3 register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p3_addr@0x00E5;
#define		p3			p3_addr.byte

#define		p3_0		p3_addr.bit.b0			/* Port P3_0 bit */
#define		p3_1		p3_addr.bit.b1			/* Port P3_1 bit */
#define		p3_2		p3_addr.bit.b2			/* Port P3_2 bit */
#define		p3_3		p3_addr.bit.b3			/* Port P3_3 bit */
#define		p3_4		p3_addr.bit.b4			/* Port P3_4 bit */
#define		p3_5		p3_addr.bit.b5			/* Port P3_5 bit */
#define		p3_6		p3_addr.bit.b6			/* Port P3_6 bit */
#define		p3_7		p3_addr.bit.b7			/* Port P3_7 bit */

/*------------------------------------------------------
  Port P2 direction register
------------------------------------------------------*/
__no_init  volatile union	byte_def	pd2_addr@0x00E6;
#define		pd2			pd2_addr.byte

#define		pd2_0		pd2_addr.bit.b0			/* Port P2_0 direction bit */
#define		pd2_1		pd2_addr.bit.b1			/* Port P2_1 direction bit */
#define		pd2_2		pd2_addr.bit.b2			/* Port P2_2 direction bit */
#define		pd2_3		pd2_addr.bit.b3			/* Port P2_3 direction bit */
#define		pd2_4		pd2_addr.bit.b4			/* Port P2_4 direction bit */
#define		pd2_5		pd2_addr.bit.b5			/* Port P2_5 direction bit */
#define		pd2_6		pd2_addr.bit.b6			/* Port P2_6 direction bit */
#define		pd2_7		pd2_addr.bit.b7			/* Port P2_7 direction bit */

/*------------------------------------------------------
  Port P3 direction register
------------------------------------------------------*/
__no_init  volatile union	byte_def	pd3_addr@0x00E7;
#define		pd3			pd3_addr.byte

#define		pd3_0		pd3_addr.bit.b0			/* Port P3_0 direction bit */
#define		pd3_1		pd3_addr.bit.b1			/* Port P3_1 direction bit */
#define		pd3_2		pd3_addr.bit.b2			/* Port P3_2 direction bit */
#define		pd3_3		pd3_addr.bit.b3			/* Port P3_3 direction bit */
#define		pd3_4		pd3_addr.bit.b4			/* Port P3_4 direction bit */
#define		pd3_5		pd3_addr.bit.b5			/* Port P3_5 direction bit */
#define		pd3_6		pd3_addr.bit.b6			/* Port P3_6 direction bit */
#define		pd3_7		pd3_addr.bit.b7			/* Port P3_7 direction bit */

/*------------------------------------------------------
  Port P4 register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p4_addr@0x00E8;
#define		p4			p4_addr.byte

#define		p4_0		p4_addr.bit.b0			/* Port P4_0 bit */
#define		p4_1		p4_addr.bit.b1			/* Port P4_1 bit */
#define		p4_2		p4_addr.bit.b2			/* Port P4_2 bit */
#define		p4_3		p4_addr.bit.b3			/* Port P4_3 bit */
#define		p4_4		p4_addr.bit.b4			/* Port P4_4 bit */
#define		p4_5		p4_addr.bit.b5			/* Port P4_5 bit */
#define		p4_6		p4_addr.bit.b6			/* Port P4_6 bit */
#define		p4_7		p4_addr.bit.b7			/* Port P4_7 bit */

/*------------------------------------------------------
  Port P5 register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p5_addr@0x00E9;
#define		p5			p5_addr.byte

#define		p5_0		p5_addr.bit.b0			/* Port P5_0 bit */
#define		p5_1		p5_addr.bit.b1			/* Port P5_1 bit */
#define		p5_2		p5_addr.bit.b2			/* Port P5_2 bit */
#define		p5_3		p5_addr.bit.b3			/* Port P5_3 bit */

/*------------------------------------------------------
  Port P4 direction register
------------------------------------------------------*/
__no_init  volatile union	byte_def	pd4_addr@0x00EA;
#define		pd4			pd4_addr.byte

#define		pd4_0		pd4_addr.bit.b0			/* Port P4_0 direction bit */
#define		pd4_1		pd4_addr.bit.b1			/* Port P4_1 direction bit */
#define		pd4_2		pd4_addr.bit.b2			/* Port P4_2 direction bit */
#define		pd4_3		pd4_addr.bit.b3			/* Port P4_3 direction bit */
#define		pd4_4		pd4_addr.bit.b4			/* Port P4_4 direction bit */
#define		pd4_5		pd4_addr.bit.b5			/* Port P4_5 direction bit */
#define		pd4_6		pd4_addr.bit.b6			/* Port P4_6 direction bit */
#define		pd4_7		pd4_addr.bit.b7			/* Port P4_7 direction bit */

/*------------------------------------------------------
  Port P5 direction register
------------------------------------------------------*/
__no_init  volatile union	byte_def	pd5_addr@0x00EB;
#define		pd5			pd5_addr.byte

#define		pd5_0		pd5_addr.bit.b0			/* Port P5_0 direction bit */
#define		pd5_1		pd5_addr.bit.b1			/* Port P5_1 direction bit */
#define		pd5_2		pd5_addr.bit.b2			/* Port P5_2 direction bit */
#define		pd5_3		pd5_addr.bit.b3			/* Port P5_3 direction bit */

/*------------------------------------------------------
  Port P6 register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p6_addr@0x00EC;
#define		p6			p6_addr.byte

#define		p6_0		p6_addr.bit.b0			/* Port P6_0 bit */
#define		p6_1		p6_addr.bit.b1			/* Port P6_1 bit */
#define		p6_2		p6_addr.bit.b2			/* Port P6_2 bit */
#define		p6_3		p6_addr.bit.b3			/* Port P6_3 bit */
#define		p6_4		p6_addr.bit.b4			/* Port P6_4 bit */
#define		p6_5		p6_addr.bit.b5			/* Port P6_5 bit */
#define		p6_6		p6_addr.bit.b6			/* Port P6_6 bit */
#define		p6_7		p6_addr.bit.b7			/* Port P6_7 bit */

/*------------------------------------------------------
  Port P7 register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p7_addr@0x00ED;
#define		p7			p7_addr.byte

#define		p7_0		p7_addr.bit.b0			/* Port P7_0 bit */
#define		p7_1		p7_addr.bit.b1			/* Port P7_1 bit */
#define		p7_2		p7_addr.bit.b2			/* Port P7_2 bit */
#define		p7_3		p7_addr.bit.b3			/* Port P7_3 bit */
#define		p7_4		p7_addr.bit.b4			/* Port P7_4 bit */
#define		p7_5		p7_addr.bit.b5			/* Port P7_5 bit */
#define		p7_6		p7_addr.bit.b6			/* Port P7_6 bit */
#define		p7_7		p7_addr.bit.b7			/* Port P7_7 bit */

/*------------------------------------------------------
  Port P6 direction register
------------------------------------------------------*/
__no_init  volatile union	byte_def	pd6_addr@0x00EE;
#define		pd6			pd6_addr.byte

#define		pd6_0		pd6_addr.bit.b0			/* Port P6_0 direction bit */
#define		pd6_1		pd6_addr.bit.b1			/* Port P6_1 direction bit */
#define		pd6_2		pd6_addr.bit.b2			/* Port P6_2 direction bit */
#define		pd6_3		pd6_addr.bit.b3			/* Port P6_3 direction bit */
#define		pd6_4		pd6_addr.bit.b4			/* Port P6_4 direction bit */
#define		pd6_5		pd6_addr.bit.b5			/* Port P6_5 direction bit */
#define		pd6_6		pd6_addr.bit.b6			/* Port P6_6 direction bit */
#define		pd6_7		pd6_addr.bit.b7			/* Port P6_7 direction bit */

/*------------------------------------------------------
  Port P7 direction register
------------------------------------------------------*/
__no_init  volatile union	byte_def	pd7_addr@0x00EF;
#define		pd7			pd7_addr.byte

#define		pd7_0		pd7_addr.bit.b0			/* Port P7_0 direction bit */
#define		pd7_1		pd7_addr.bit.b1			/* Port P7_1 direction bit */
#define		pd7_2		pd7_addr.bit.b2			/* Port P7_2 direction bit */
#define		pd7_3		pd7_addr.bit.b3			/* Port P7_3 direction bit */
#define		pd7_4		pd7_addr.bit.b4			/* Port P7_4 direction bit */
#define		pd7_5		pd7_addr.bit.b5			/* Port P7_5 direction bit */
#define		pd7_6		pd7_addr.bit.b6			/* Port P7_6 direction bit */
#define		pd7_7		pd7_addr.bit.b7			/* Port P7_7 direction bit */

/*------------------------------------------------------
  Port P10 register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p10_addr@0x00F4;
#define		p10			p10_addr.byte

#define		p10_0		p10_addr.bit.b0			/* Port P10_0 bit */
#define		p10_1		p10_addr.bit.b1			/* Port P10_1 bit */
#define		p10_2		p10_addr.bit.b2			/* Port P10_2 bit */
#define		p10_3		p10_addr.bit.b3			/* Port P10_3 bit */
#define		p10_4		p10_addr.bit.b4			/* Port P10_4 bit */
#define		p10_5		p10_addr.bit.b5			/* Port P10_5 bit */
#define		p10_6		p10_addr.bit.b6			/* Port P10_6 bit */
#define		p10_7		p10_addr.bit.b7			/* Port P10_7 bit */

/*------------------------------------------------------
  Port P11 register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p11_addr@0x00F5;
#define		p11			p11_addr.byte

#define		p11_0		p11_addr.bit.b0			/* Port P11_0 bit */
#define		p11_1		p11_addr.bit.b1			/* Port P11_1 bit */
#define		p11_2		p11_addr.bit.b2			/* Port P11_2 bit */
#define		p11_3		p11_addr.bit.b3			/* Port P11_3 bit */
#define		p11_4		p11_addr.bit.b4			/* Port P11_4 bit */
#define		p11_5		p11_addr.bit.b5			/* Port P11_5 bit */
#define		p11_6		p11_addr.bit.b6			/* Port P11_6 bit */
#define		p11_7		p11_addr.bit.b7			/* Port P11_7 bit */

/*------------------------------------------------------
  Port P10 direction register
------------------------------------------------------*/
__no_init  volatile union	byte_def	pd10_addr@0x00F6;
#define		pd10		pd10_addr.byte

#define		pd10_0		pd10_addr.bit.b0		/* Port P10_0 direction bit */
#define		pd10_1		pd10_addr.bit.b1		/* Port P10_1 direction bit */
#define		pd10_2		pd10_addr.bit.b2		/* Port P10_2 direction bit */
#define		pd10_3		pd10_addr.bit.b3		/* Port P10_3 direction bit */
#define		pd10_4		pd10_addr.bit.b4		/* Port P10_4 direction bit */
#define		pd10_5		pd10_addr.bit.b5		/* Port P10_5 direction bit */
#define		pd10_6		pd10_addr.bit.b6		/* Port P10_6 direction bit */
#define		pd10_7		pd10_addr.bit.b7		/* Port P10_7 direction bit */

/*------------------------------------------------------
  Port P11 direction register
------------------------------------------------------*/
__no_init  volatile union	byte_def	pd11_addr@0x00F7;
#define		pd11		pd11_addr.byte

#define		pd11_0		pd11_addr.bit.b0		/* Port P11_0 direction bit */
#define		pd11_1		pd11_addr.bit.b1		/* Port P11_1 direction bit */
#define		pd11_2		pd11_addr.bit.b2		/* Port P11_2 direction bit */
#define		pd11_3		pd11_addr.bit.b3		/* Port P11_3 direction bit */
#define		pd11_4		pd11_addr.bit.b4		/* Port P11_4 direction bit */
#define		pd11_5		pd11_addr.bit.b5		/* Port P11_5 direction bit */
#define		pd11_6		pd11_addr.bit.b6		/* Port P11_6 direction bit */
#define		pd11_7		pd11_addr.bit.b7		/* Port P11_7 direction bit */

/*------------------------------------------------------
  Port P12 register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p12_addr@0x00F8;
#define		p12			p12_addr.byte

#define		p12_0		p12_addr.bit.b0			/* Port P12_0 bit */
#define		p12_1		p12_addr.bit.b1			/* Port P12_1 bit */
#define		p12_2		p12_addr.bit.b2			/* Port P12_2 bit */
#define		p12_3		p12_addr.bit.b3			/* Port P12_3 bit */

/*------------------------------------------------------
  Port P13 register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p13_addr@0x00F9;
#define		p13			p13_addr.byte

#define		p13_0		p13_addr.bit.b0			/* Port P13_0 bit */
#define		p13_1		p13_addr.bit.b1			/* Port P13_1 bit */
#define		p13_2		p13_addr.bit.b2			/* Port P13_2 bit */
#define		p13_3		p13_addr.bit.b3			/* Port P13_3 bit */
#define		p13_4		p13_addr.bit.b4			/* Port P13_4 bit */
#define		p13_5		p13_addr.bit.b5			/* Port P13_5 bit */
#define		p13_6		p13_addr.bit.b6			/* Port P13_6 bit */
#define		p13_7		p13_addr.bit.b7			/* Port P13_7 bit */

/*------------------------------------------------------
  Port P12 direction register
------------------------------------------------------*/
__no_init  volatile union	byte_def	pd12_addr@0x00FA;
#define		pd12		pd12_addr.byte

#define		pd12_0		pd12_addr.bit.b0		/* Port P12_0 direction bit */
#define		pd12_1		pd12_addr.bit.b1		/* Port P12_1 direction bit */
#define		pd12_2		pd12_addr.bit.b2		/* Port P12_2 direction bit */
#define		pd12_3		pd12_addr.bit.b3		/* Port P12_3 direction bit */

/*------------------------------------------------------
  Port P13 direction register
------------------------------------------------------*/
__no_init  volatile union	byte_def	pd13_addr@0x00FB;
#define		pd13		pd13_addr.byte

#define		pd13_0		pd13_addr.bit.b0		/* Port P13_0 direction bit */
#define		pd13_1		pd13_addr.bit.b1		/* Port P13_1 direction bit */
#define		pd13_2		pd13_addr.bit.b2		/* Port P13_2 direction bit */
#define		pd13_3		pd13_addr.bit.b3		/* Port P13_3 direction bit */
#define		pd13_4		pd13_addr.bit.b4		/* Port P13_4 direction bit */
#define		pd13_5		pd13_addr.bit.b5		/* Port P13_5 direction bit */
#define		pd13_6		pd13_addr.bit.b6		/* Port P13_6 direction bit */
#define		pd13_7		pd13_addr.bit.b7		/* Port P13_7 direction bit */

/*------------------------------------------------------
  Timer RA control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	tracr_addr@0x0100;
#define		tracr		tracr_addr.byte

#define		tstart_tracr	tracr_addr.bit.b0	/* Timer RA count start bit */
#define		tcstf_tracr		tracr_addr.bit.b1	/* Timer RA count status flag */
#define		tstop_tracr		tracr_addr.bit.b2	/* Timer RA count forcible stop bit */
#define		tedgf_tracr		tracr_addr.bit.b4	/* Active edge judgment flag */
#define		tundf_tracr		tracr_addr.bit.b5	/* Timer RA underflow flag */

/*------------------------------------------------------
  Timer RA I/O control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	traioc_addr@0x0101;
#define		traioc		traioc_addr.byte

#define		tedgsel_traioc	traioc_addr.bit.b0	/* TRAIO polarity switch bit */
#define		topcr_traioc	traioc_addr.bit.b1	/* TRAIO output control bit */
#define		tiosel_traioc	traioc_addr.bit.b3	/* Hardware LIN function select bit */
#define		tipf0_traioc	traioc_addr.bit.b4	/* TRAIO input filter select bit */
#define		tipf1_traioc	traioc_addr.bit.b5	/* TRAIO input filter select bit */
#define		tiogt0_traioc	traioc_addr.bit.b6	/* TRAIO event input control bit */
#define		tiogt1_traioc	traioc_addr.bit.b7	/* TRAIO event input control bit */

/*------------------------------------------------------
  Timer RA mode register
------------------------------------------------------*/
__no_init  volatile union	byte_def	tramr_addr@0x0102;
#define		tramr		tramr_addr.byte

#define		tmod0_tramr		tramr_addr.bit.b0	/* Timer RA operating mode select bit */
#define		tmod1_tramr		tramr_addr.bit.b1	/* Timer RA operating mode select bit */
#define		tmod2_tramr		tramr_addr.bit.b2	/* Timer RA operating mode select bit */
#define		tck0_tramr		tramr_addr.bit.b4	/* Timer RA count source select bit */
#define		tck1_tramr		tramr_addr.bit.b5	/* Timer RA count source select bit */
#define		tck2_tramr		tramr_addr.bit.b6	/* Timer RA count source select bit */
#define		tckcut_tramr	tramr_addr.bit.b7	/* Timer RA count source cutoff bit */

/*------------------------------------------------------
  Timer RA prescaler register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trapre_addr@0x0103;
#define		trapre			trapre_addr.byte

/*------------------------------------------------------
  Timer RA register
------------------------------------------------------*/
__no_init  volatile union	byte_def	tra_addr@0x0104;
#define		tra				tra_addr.byte

/*------------------------------------------------------
  LIN control register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	lincr2_addr@0x0105;
#define		lincr2		lincr2_addr.byte

#define		bce_lincr2		lincr2_addr.bit.b0	/* Bus collision detection enable bit during Sync Break transmission */

/*------------------------------------------------------
  LIN control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	lincr_addr@0x0106;
#define		lincr		lincr_addr.byte

#define		sfie_lincr		lincr_addr.bit.b0	/* Synch Field measurement-complete interrupt enable bit */
#define		sbie_lincr		lincr_addr.bit.b1	/* Synch Break detection interrupt enable bit */
#define		bcie_lincr		lincr_addr.bit.b2	/* Bus collision detection interrupt enable bit */
#define		rxdsf_lincr		lincr_addr.bit.b3	/* RxD0 input status flag */
#define		lstart_lincr	lincr_addr.bit.b4	/* Synch Break detection start bit */
#define		sbe_lincr		lincr_addr.bit.b5	/* RxD0 input unmasking timing select bit */
#define		mst_lincr		lincr_addr.bit.b6	/* LIN operation mode setting bit */
#define		line_lincr		lincr_addr.bit.b7	/* LIN operation start bit */

/*------------------------------------------------------
  LIN status register
------------------------------------------------------*/
__no_init  volatile union	byte_def	linst_addr@0x0107;
#define		linst		linst_addr.byte

#define		sfdct_linst		linst_addr.bit.b0	/* Synch Field measurement-complete flag */
#define		sbdct_linst		linst_addr.bit.b1	/* Synch Break detection flag */
#define		bcdct_linst		linst_addr.bit.b2	/* Bus collision detection flag */
#define		b0clr_linst		linst_addr.bit.b3	/* SFDCT flag clear bit */
#define		b1clr_linst		linst_addr.bit.b4	/* SBDCT flag clear bit */
#define		b2clr_linst		linst_addr.bit.b5	/* BCDCT flag clear bit */

/*------------------------------------------------------
  Timer RB control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trbcr_addr@0x0108;
#define		trbcr		trbcr_addr.byte

#define		tstart_trbcr	trbcr_addr.bit.b0	/* Timer RB count start bit */
#define		tcstf_trbcr		trbcr_addr.bit.b1	/* Timer RB count status flag */
#define		tstop_trbcr		trbcr_addr.bit.b2	/* Timer RB count forcible stop bit */

/*------------------------------------------------------
  Timer RB One-Shot Control Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trbocr_addr@0x0109;
#define		trbocr		trbocr_addr.byte

#define		tosst_trbocr	trbocr_addr.bit.b0	/* Timer RB one-shot start bit */
#define		tossp_trbocr	trbocr_addr.bit.b1	/* Timer RB one-shot stop bit */
#define		tosstf_trbocr	trbocr_addr.bit.b2	/* Timer RB one-shot status flag */

/*------------------------------------------------------
  Timer RB I/O control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trbioc_addr@0x010A;
#define		trbioc		trbioc_addr.byte

#define		topl_trbioc		trbioc_addr.bit.b0	/* Timer RB output level select bit */
#define		tocnt_trbioc	trbioc_addr.bit.b1	/* Timer RB output switch bit */
#define		inostg_trbioc	trbioc_addr.bit.b2	/* One-shot trigger control bit */
#define		inoseg_trbioc	trbioc_addr.bit.b3	/* One-shot trigger polarity select bit */

/*------------------------------------------------------
  Timer RB mode register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trbmr_addr@0x010B;
#define		trbmr		trbmr_addr.byte

#define		tmod0_trbmr		trbmr_addr.bit.b0	/* Timer RB operating mode select bit */
#define		tmod1_trbmr		trbmr_addr.bit.b1	/* Timer RB operating mode select bit */
#define		twrc_trbmr		trbmr_addr.bit.b3	/* Timer RB write control bit */
#define		tck0_trbmr		trbmr_addr.bit.b4	/* Timer RB count source select bit */
#define		tck1_trbmr		trbmr_addr.bit.b5	/* Timer RB count source select bit */
#define		tckcut_trbmr	trbmr_addr.bit.b7	/* Timer RB count source cutoff bit */

/*------------------------------------------------------
  Timer RB prescaler register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trbpre_addr@0x010C;
#define		trbpre		trbpre_addr.byte

/*------------------------------------------------------
  Timer RB secondary register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trbsc_addr@0x010D;
#define		trbsc		trbsc_addr.byte

/*------------------------------------------------------
  Timer RB Primary Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trbpr_addr@0x010E;
#define		trbpr		trbpr_addr.byte

/*------------------------------------------------------
  Timer RE Second Data Register / Timer RE Counter Data Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	tresec_addr@0x0118;
#define		tresec		tresec_addr.byte

#define		sc00_tresec		tresec_addr.bit.b0	/* 1st digit of second count bit */
#define		sc01_tresec		tresec_addr.bit.b1	/* 1st digit of second count bit */
#define		sc02_tresec		tresec_addr.bit.b2	/* 1st digit of second count bit */
#define		sc03_tresec		tresec_addr.bit.b3	/* 1st digit of second count bit */
#define		sc10_tresec		tresec_addr.bit.b4	/* 2nd digit of second count bit */
#define		sc11_tresec		tresec_addr.bit.b5	/* 2nd digit of second count bit */
#define		sc12_tresec		tresec_addr.bit.b6	/* 2nd digit of second count bit */
#define		bsy_tresec		tresec_addr.bit.b7	/* Timer RE busy flag */

/*------------------------------------------------------
  Timer RE Minute Data Register / Timer RE Compare Data Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	tremin_addr@0x0119;
#define		tremin		tremin_addr.byte

#define		mn00_tremin		tremin_addr.bit.b0	/* 1st digit of minute count bit */
#define		mn01_tremin		tremin_addr.bit.b1	/* 1st digit of minute count bit */
#define		mn02_tremin		tremin_addr.bit.b2	/* 1st digit of minute count bit */
#define		mn03_tremin		tremin_addr.bit.b3	/* 1st digit of minute count bit */
#define		mn10_tremin		tremin_addr.bit.b4	/* 2nd digit of minute count bit */
#define		mn11_tremin		tremin_addr.bit.b5	/* 2nd digit of minute count bit */
#define		mn12_tremin		tremin_addr.bit.b6	/* 2nd digit of minute count bit */
#define		bsy_tremin		tremin_addr.bit.b7	/* Timer RE busy flag */

/*------------------------------------------------------
  Timer RE Hour Data Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trehr_addr@0x011A;
#define		trehr		trehr_addr.byte

#define		hr00_trehr		trehr_addr.bit.b0	/* 1st digit of hour count bit */
#define		hr01_trehr		trehr_addr.bit.b1	/* 1st digit of hour count bit */
#define		hr02_trehr		trehr_addr.bit.b2	/* 1st digit of hour count bit */
#define		hr03_trehr		trehr_addr.bit.b3	/* 1st digit of hour count bit */
#define		hr10_trehr		trehr_addr.bit.b4	/* 2nd digit of hour count bit */
#define		hr11_trehr		trehr_addr.bit.b5	/* 2nd digit of hour count bit */
#define		bsy_trehr		trehr_addr.bit.b7	/* Timer RE busy flag */

/*------------------------------------------------------
  Timer RE Day of Week Data Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trewk_addr@0x011B;
#define		trewk		trewk_addr.byte

#define		wk0_trewk		trewk_addr.bit.b0	/* Day of week count bit */
#define		wk1_trewk		trewk_addr.bit.b1	/* Day of week count bit */
#define		wk2_trewk		trewk_addr.bit.b2	/* Day of week count bit */
#define		bsy_trewk		trewk_addr.bit.b7	/* Timer RE busy flag */

/*------------------------------------------------------
  Timer RE Control Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	trecr1_addr@0x011C;
#define		trecr1		trecr1_addr.byte

#define		tcstf_trecr1	trecr1_addr.bit.b1	/* Timer RE count status flag */
#define		toena_trecr1	trecr1_addr.bit.b2	/* TREO pin output enable bit */
#define		int_trecr1		trecr1_addr.bit.b3	/* Interrupt request timing bit */
#define		trerst_trecr1	trecr1_addr.bit.b4	/* Timer RE reset bit */
#define		pm_trecr1		trecr1_addr.bit.b5	/* A.m./p.m. bit */
#define		h12_h24_trecr1	trecr1_addr.bit.b6	/* Operating mode select bit */
#define		tstart_trecr1	trecr1_addr.bit.b7	/* Timer RE count start bit */

/*------------------------------------------------------
  Timer RE Control Register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	trecr2_addr@0x011D;
#define		trecr2		trecr2_addr.byte

#define		seie025_trecr2	trecr2_addr.bit.b0	/* Periodic interrupt triggered every 0.25 seconds enable bit */
#define		seie05_trecr2	trecr2_addr.bit.b1	/* Periodic interrupt triggered every 0.5 seconds enable bit */
#define		seie_trecr2		trecr2_addr.bit.b2	/* Periodic interrupt triggered every second enable bit */
#define		mnie_trecr2		trecr2_addr.bit.b3	/* Periodic interrupt triggered every minute enable bit */
#define		hrie_trecr2		trecr2_addr.bit.b4	/* Periodic interrupt triggered every hour enable bit */
#define		dyie_trecr2		trecr2_addr.bit.b5	/* Periodic interrupt triggered every day enable bit */
#define		wkie_trecr2		trecr2_addr.bit.b6	/* Periodic interrupt triggered every week enable bit */
#define		comie_trecr2	trecr2_addr.bit.b7	/* Compare match interrupt enable bit */

/*------------------------------------------------------
  Timer RE count source select register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trecsr_addr@0x011E;
#define		trecsr		trecsr_addr.byte

#define		rcs0_trecsr		trecsr_addr.bit.b0	/* Count source select bit */
#define		rcs1_trecsr		trecsr_addr.bit.b1	/* Count source select bit */
#define		rcs2_trecsr		trecsr_addr.bit.b2	/* 4-Bit counter select bit */
#define		rcs3_trecsr		trecsr_addr.bit.b3	/* Real-Time clock mode select bit */
#define		rcs4_trecsr		trecsr_addr.bit.b4	/* Clock output select bit */
#define		rcs5_trecsr		trecsr_addr.bit.b5	/* Clock output select bit */
#define		rcs6_trecsr		trecsr_addr.bit.b6	/* Clock output select bit */

/*------------------------------------------------------
  Timer RC mode register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trcmr_addr@0x0120;
#define		trcmr		trcmr_addr.byte

#define		pwmb_trcmr		trcmr_addr.bit.b0	/* PWM mode of TRCIOB select bit */
#define		pwmc_trcmr		trcmr_addr.bit.b1	/* PWM mode of TRCIOC select bit */
#define		pwmd_trcmr		trcmr_addr.bit.b2	/* PWM mode of TRCIOD select bit */
#define		pwm2_trcmr		trcmr_addr.bit.b3	/* PWM2 mode select bit */
#define		bfc_trcmr		trcmr_addr.bit.b4	/* TRCGRC register function select bit */
#define		bfd_trcmr		trcmr_addr.bit.b5	/* TRCGRD register function select bit */
#define		tstart_trcmr	trcmr_addr.bit.b7	/* TRC count start bit */

/*------------------------------------------------------
  Timer RC control register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	trccr1_addr@0x0121;
#define		trccr1		trccr1_addr.byte

#define		toa_trccr1		trccr1_addr.bit.b0	/* TRCIOA output level select bit */
#define		tob_trccr1		trccr1_addr.bit.b1	/* TRCIOB output level select bit */
#define		toc_trccr1		trccr1_addr.bit.b2	/* TRCIOC output level select bit */
#define		tod_trccr1		trccr1_addr.bit.b3	/* TRCIOD output level select bit */
#define		tck0_trccr1		trccr1_addr.bit.b4	/* Count source select bit */
#define		tck1_trccr1		trccr1_addr.bit.b5	/* Count source select bit */
#define		tck2_trccr1		trccr1_addr.bit.b6	/* Count source select bit */
#define		cclr_trccr1		trccr1_addr.bit.b7	/* TRC counter clear select bit */

/*------------------------------------------------------
  Timer RC interrupt enable register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trcier_addr@0x0122;
#define		trcier		trcier_addr.byte

#define		imiea_trcier	trcier_addr.bit.b0	/* Input-capture/compare-match interrupt enable bit A */
#define		imieb_trcier	trcier_addr.bit.b1	/* Input-capture/compare-match interrupt enable bit B */
#define		imiec_trcier	trcier_addr.bit.b2	/* Input-capture/compare-match interrupt enable bit C */
#define		imied_trcier	trcier_addr.bit.b3	/* Input-capture/compare-match interrupt enable bit D */
#define		ovie_trcier		trcier_addr.bit.b7	/* Overflow interrupt enable bit */

/*------------------------------------------------------
  Timer RC status register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trcsr_addr@0x0123;
#define		trcsr		trcsr_addr.byte

#define		imfa_trcsr		trcsr_addr.bit.b0	/* Input-capture/compare-match flag A */
#define		imfb_trcsr		trcsr_addr.bit.b1	/* Input-capture/compare-match flag B */
#define		imfc_trcsr		trcsr_addr.bit.b2	/* Input-capture/compare-match flag C */
#define		imfd_trcsr		trcsr_addr.bit.b3	/* Input-capture/compare-match flag D */
#define		ovf_trcsr		trcsr_addr.bit.b7	/* Overflow flag */

/*------------------------------------------------------
  Timer RC I/O Control Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	trcior0_addr@0x0124;
#define		trcior0		trcior0_addr.byte

#define		ioa0_trcior0	trcior0_addr.bit.b0	/* TRCGRA control bit */
#define		ioa1_trcior0	trcior0_addr.bit.b1	/* TRCGRA control bit */
#define		ioa2_trcior0	trcior0_addr.bit.b2	/* TRCGRA mode select bit */
#define		ioa3_trcior0	trcior0_addr.bit.b3	/* TRCGRA input capture input switch bit */
#define		iob0_trcior0	trcior0_addr.bit.b4	/* TRCGRB control bit */
#define		iob1_trcior0	trcior0_addr.bit.b5	/* TRCGRB control bit */
#define		iob2_trcior0	trcior0_addr.bit.b6	/* TRCGRB mode select bit */

/*------------------------------------------------------
  Timer RC I/O Control Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	trcior1_addr@0x0125;
#define		trcior1		trcior1_addr.byte

#define		ioc0_trcior1	trcior1_addr.bit.b0	/* TRCGRC control bit */
#define		ioc1_trcior1	trcior1_addr.bit.b1	/* TRCGRC control bit */
#define		ioc2_trcior1	trcior1_addr.bit.b2	/* TRCGRC mode select bit */
#define		ioc3_trcior1	trcior1_addr.bit.b3	/* TRCGRC register function select bit */
#define		iod0_trcior1	trcior1_addr.bit.b4	/* TRCGRD control bit */
#define		iod1_trcior1	trcior1_addr.bit.b5	/* TRCGRD control bit */
#define		iod2_trcior1	trcior1_addr.bit.b6	/* TRCGRD mode select bit */
#define		iod3_trcior1	trcior1_addr.bit.b7	/* TRCGRD register function select bit */

/*------------------------------------------------------
  Timer RC control register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	trccr2_addr@0x0130;
#define		trccr2		trccr2_addr.byte

#define		polb_trccr2		trccr2_addr.bit.b0	/* PWM mode output level control bit B */
#define		polc_trccr2		trccr2_addr.bit.b1	/* PWM mode output level control bit C */
#define		pold_trccr2		trccr2_addr.bit.b2	/* PWM mode output level control bit D */
#define		csel_trccr2		trccr2_addr.bit.b5	/* TRC count operation select bit */
#define		tceg0_trccr2	trccr2_addr.bit.b6	/* TRCTRG input edge select bit */
#define		tceg1_trccr2	trccr2_addr.bit.b7	/* TRCTRG input edge select bit */

/*------------------------------------------------------
  Timer RC Digital Filter Function Select Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trcdf_addr@0x0131;
#define		trcdf		trcdf_addr.byte

#define		dfa_trcdf		trcdf_addr.bit.b0	/* TRCIOA pin digital filter function select bit */
#define		dfb_trcdf		trcdf_addr.bit.b1	/* TRCIOB pin digital filter function select bit */
#define		dfc_trcdf		trcdf_addr.bit.b2	/* TRCIOC pin digital filter function select bit */
#define		dfd_trcdf		trcdf_addr.bit.b3	/* TRCIOD pin digital filter function select bit */
#define		dftrg_trcdf		trcdf_addr.bit.b4	/* TRCTRG pin digital filter function select bit */
#define		dfck0_trcdf		trcdf_addr.bit.b6	/* Digital filter function clock select bit */
#define		dfck1_trcdf		trcdf_addr.bit.b7	/* Digital filter function clock select bit */

/*------------------------------------------------------
  Timer RC output master enable register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trcoer_addr@0x0132;
#define		trcoer		trcoer_addr.byte

#define		ea_trcoer		trcoer_addr.bit.b0	/* TRCIOA output disable bit */
#define		eb_trcoer		trcoer_addr.bit.b1	/* TRCIOB output disable bit */
#define		ec_trcoer		trcoer_addr.bit.b2	/* TRCIOC output disable bit */
#define		ed_trcoer		trcoer_addr.bit.b3	/* TRCIOD output disable bit */
#define		pto_trcoer		trcoer_addr.bit.b7	/* INT0 of pulse output forced cutoff signal input enabled bit */

/*------------------------------------------------------
  Timer RC trigger control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trcadcr_addr@0x0133;
#define		trcadcr		trcadcr_addr.byte

#define		adtrgae_trcadcr	trcadcr_addr.bit.b0	/* A/D trigger A enable bit */
#define		adtrgbe_trcadcr	trcadcr_addr.bit.b1	/* A/D trigger B enable bit */
#define		adtrgce_trcadcr	trcadcr_addr.bit.b2	/* A/D trigger C enable bit */
#define		adtrgde_trcadcr	trcadcr_addr.bit.b3	/* A/D trigger D enable bit */

/*------------------------------------------------------
  Timer RD Control Expansion Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdecr_addr@0x0135;
#define		trdecr		trdecr_addr.byte

#define		itclk0_trdecr	trdecr_addr.bit.b3	/* Timer RD0 fC2 select bit */
#define		itclk1_trdecr	trdecr_addr.bit.b7	/* Timer RD1 fC2 select bit */

/*------------------------------------------------------
  Timer RD trigger control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdadcr_addr@0x0136;
#define		trdadcr		trdadcr_addr.byte

#define		adtrga0e_trdadcr	trdadcr_addr.bit.b0	/* A/D trigger A0 enable bit */
#define		adtrgb0e_trdadcr	trdadcr_addr.bit.b1	/* A/D trigger B0 enable bit */
#define		adtrgc0e_trdadcr	trdadcr_addr.bit.b2	/* A/D trigger C0 enable bit */
#define		adtrgd0e_trdadcr	trdadcr_addr.bit.b3	/* A/D trigger D0 enable bit */
#define		adtrga1e_trdadcr	trdadcr_addr.bit.b4	/* A/D trigger A1 enable bit */
#define		adtrgb1e_trdadcr	trdadcr_addr.bit.b5	/* A/D trigger B1 enable bit */
#define		adtrgc1e_trdadcr	trdadcr_addr.bit.b6	/* A/D trigger C1 enable bit */
#define		adtrgd1e_trdadcr	trdadcr_addr.bit.b7	/* A/D trigger D1 enable bit */

/*------------------------------------------------------
  Timer RD start register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdstr_addr@0x0137;
#define		trdstr		trdstr_addr.byte

#define		tstart0_trdstr	trdstr_addr.bit.b0	/* TRD0 count start flag */
#define		tstart1_trdstr	trdstr_addr.bit.b1	/* TRD1 count start flag */
#define		csel0_trdstr	trdstr_addr.bit.b2	/* TRD0 count operation select bit */
#define		csel1_trdstr	trdstr_addr.bit.b3	/* TRD1 count operation select bit */

/*------------------------------------------------------
  Timer RD mode register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdmr_addr@0x0138;
#define		trdmr		trdmr_addr.byte

#define		sync_trdmr		trdmr_addr.bit.b0	/* Timer RD synchronous bit */
#define		bfc0_trdmr		trdmr_addr.bit.b4	/* TRDGRC0 register function select bit */
#define		bfd0_trdmr		trdmr_addr.bit.b5	/* TRDGRD0 register function select bit */
#define		bfc1_trdmr		trdmr_addr.bit.b6	/* TRDGRC1 register function select bit */
#define		bfd1_trdmr		trdmr_addr.bit.b7	/* TRDGRD1 register function select bit */

/*------------------------------------------------------
  Timer RD PWM mode register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdpmr_addr@0x0139;
#define		trdpmr		trdpmr_addr.byte

#define		pwmb0_trdpmr	trdpmr_addr.bit.b0	/* PWM mode of TRDIOB0 select bit */
#define		pwmc0_trdpmr	trdpmr_addr.bit.b1	/* PWM mode of TRDIOC0 select bit */
#define		pwmd0_trdpmr	trdpmr_addr.bit.b2	/* PWM mode of TRDIOD0 select bit */
#define		pwmb1_trdpmr	trdpmr_addr.bit.b4	/* PWM mode of TRDIOB1 select bit */
#define		pwmc1_trdpmr	trdpmr_addr.bit.b5	/* PWM mode of TRDIOC1 select bit */
#define		pwmd1_trdpmr	trdpmr_addr.bit.b6	/* PWM mode of TRDIOD1 select bit */

/*------------------------------------------------------
  Timer RD function control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdfcr_addr@0x013A;
#define		trdfcr		trdfcr_addr.byte

#define		cmd0_trdfcr		trdfcr_addr.bit.b0	/* Combination mode select bit */
#define		cmd1_trdfcr		trdfcr_addr.bit.b1	/* Combination mode select bit */
#define		ols0_trdfcr		trdfcr_addr.bit.b2	/* Normal-phase output level select bit */
#define		ols1_trdfcr		trdfcr_addr.bit.b3	/* Counter-phase output level select bit */
#define		adtrg_trdfcr	trdfcr_addr.bit.b4	/* A/D trigger enable bit */
#define		adeg_trdfcr		trdfcr_addr.bit.b5	/* A/D trigger edge select bit */
#define		stclk_trdfcr	trdfcr_addr.bit.b6	/* External clock input select bit */
#define		pwm3_trdfcr		trdfcr_addr.bit.b7	/* PWM3 mode select bit */

/*------------------------------------------------------
  Timer RD output master enable register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdoer1_addr@0x013B;
#define		trdoer1		trdoer1_addr.byte

#define		ea0_trdoer1		trdoer1_addr.bit.b0	/* TRDIOA0 output disable bit */
#define		eb0_trdoer1		trdoer1_addr.bit.b1	/* TRDIOB0 output disable bit */
#define		ec0_trdoer1		trdoer1_addr.bit.b2	/* TRDIOC0 output disable bit */
#define		ed0_trdoer1		trdoer1_addr.bit.b3	/* TRDIOD0 output disable bit */
#define		ea1_trdoer1		trdoer1_addr.bit.b4	/* TRDIOA1 output disable bit */
#define		eb1_trdoer1		trdoer1_addr.bit.b5	/* TRDIOB1 output disable bit */
#define		ec1_trdoer1		trdoer1_addr.bit.b6	/* TRDIOC1 output disable bit */
#define		ed1_trdoer1		trdoer1_addr.bit.b7	/* TRDIOD1 output disable bit */

/*------------------------------------------------------
  Timer RD output master enable register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdoer2_addr@0x013C;
#define		trdoer2		trdoer2_addr.byte

#define		pto_trdoer2		trdoer2_addr.bit.b7	/* INT0 of pulse output forced cutoff signal input enabled bit */

/*------------------------------------------------------
  Timer RD output control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdocr_addr@0x013D;
#define		trdocr		trdocr_addr.byte

#define		toa0_trdocr		trdocr_addr.bit.b0	/* TRDIOA0 output level select bit */
#define		tob0_trdocr		trdocr_addr.bit.b1	/* TRDIOB0 output level select bit */
#define		toc0_trdocr		trdocr_addr.bit.b2	/* TRDIOC0 initial output level select bit */
#define		tod0_trdocr		trdocr_addr.bit.b3	/* TRDIOD0 initial output level select bit */
#define		toa1_trdocr		trdocr_addr.bit.b4	/* TRDIOA1 initial output level select bit */
#define		tob1_trdocr		trdocr_addr.bit.b5	/* TRDIOB1 initial output level select bit */
#define		toc1_trdocr		trdocr_addr.bit.b6	/* TRDIOC1 initial output level select bit */
#define		tod1_trdocr		trdocr_addr.bit.b7	/* TRDIOD1 initial output level select bit */

/*------------------------------------------------------
  Timer RD Digital Filter Function Select Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	trddf0_addr@0x013E;
#define		trddf0		trddf0_addr.byte

#define		dfa_trddf0		trddf0_addr.bit.b0	/* TRDIOA pin digital filter function select bit */
#define		dfb_trddf0		trddf0_addr.bit.b1	/* TRDIOB pin digital filter function select bit */
#define		dfc_trddf0		trddf0_addr.bit.b2	/* TRDIOC pin digital filter function select bit */
#define		dfd_trddf0		trddf0_addr.bit.b3	/* TRDIOD pin digital filter function select bit */
#define		dfck0_trddf0	trddf0_addr.bit.b6	/* Clock select bits for digital filter function */
#define		dfck1_trddf0	trddf0_addr.bit.b7	/* Clock select bits for digital filter function */

/*------------------------------------------------------
  Timer RD Digital Filter Function Select Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	trddf1_addr@0x013F;
#define		trddf1		trddf1_addr.byte

#define		dfa_trddf1		trddf1_addr.bit.b0	/* TRDIOA pin digital filter function select bit */
#define		dfb_trddf1		trddf1_addr.bit.b1	/* TRDIOB pin digital filter function select bit */
#define		dfc_trddf1		trddf1_addr.bit.b2	/* TRDIOC pin digital filter function select bit */
#define		dfd_trddf1		trddf1_addr.bit.b3	/* TRDIOD pin digital filter function select bit */
#define		dfck0_trddf1	trddf1_addr.bit.b6	/* Clock select bits for digital filter function */
#define		dfck1_trddf1	trddf1_addr.bit.b7	/* Clock select bits for digital filter function */

/*------------------------------------------------------
  Timer RD control register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdcr0_addr@0x0140;
#define		trdcr0		trdcr0_addr.byte

#define		tck0_trdcr0		trdcr0_addr.bit.b0	/* Count source select bit */
#define		tck1_trdcr0		trdcr0_addr.bit.b1	/* Count source select bit */
#define		tck2_trdcr0		trdcr0_addr.bit.b2	/* Count source select bit */
#define		ckeg0_trdcr0	trdcr0_addr.bit.b3	/* External clock edge select bit */
#define		ckeg1_trdcr0	trdcr0_addr.bit.b4	/* External clock edge select bit */
#define		cclr0_trdcr0	trdcr0_addr.bit.b5	/* TRD0 counter clear select bit */
#define		cclr1_trdcr0	trdcr0_addr.bit.b6	/* TRD0 counter clear select bit */
#define		cclr2_trdcr0	trdcr0_addr.bit.b7	/* TRD0 counter clear select bit */

/*------------------------------------------------------
  Timer RD I/O Control Register A0
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdiora0_addr@0x0141;
#define		trdiora0	trdiora0_addr.byte

#define		ioa0_trdiora0	trdiora0_addr.bit.b0	/* TRDGRA control bit */
#define		ioa1_trdiora0	trdiora0_addr.bit.b1	/* TRDGRA control bit */
#define		ioa2_trdiora0	trdiora0_addr.bit.b2	/* TRDGRA mode select bit */
#define		ioa3_trdiora0	trdiora0_addr.bit.b3	/* Input capture input switch bit */
#define		iob0_trdiora0	trdiora0_addr.bit.b4	/* TRDGRB control bit */
#define		iob1_trdiora0	trdiora0_addr.bit.b5	/* TRDGRB control bit */
#define		iob2_trdiora0	trdiora0_addr.bit.b6	/* TRDGRB mode select bit */

/*------------------------------------------------------
  Timer RD I/O Control Register C0
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdiorc0_addr@0x0142;
#define		trdiorc0	trdiorc0_addr.byte

#define		ioc0_trdiorc0	trdiorc0_addr.bit.b0	/* TRDGRC control bit */
#define		ioc1_trdiorc0	trdiorc0_addr.bit.b1	/* TRDGRC control bit */
#define		ioc2_trdiorc0	trdiorc0_addr.bit.b2	/* TRDGRC mode select bit */
#define		ioc3_trdiorc0	trdiorc0_addr.bit.b3	/* TRDGRC register function select bit */
#define		iod0_trdiorc0	trdiorc0_addr.bit.b4	/* TRDGRD control bit */
#define		iod1_trdiorc0	trdiorc0_addr.bit.b5	/* TRDGRD control bit */
#define		iod2_trdiorc0	trdiorc0_addr.bit.b6	/* TRDGRD mode select bit */
#define		iod3_trdiorc0	trdiorc0_addr.bit.b7	/* TRDGRD register function select bit */

/*------------------------------------------------------
  Timer RD status register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdsr0_addr@0x0143;
#define		trdsr0		trdsr0_addr.byte

#define		imfa_trdsr0		trdsr0_addr.bit.b0	/* Input-capture/compare-match flag A */
#define		imfb_trdsr0		trdsr0_addr.bit.b1	/* Input-capture/compare-match flag B */
#define		imfc_trdsr0		trdsr0_addr.bit.b2	/* Input-capture/compare-match flag C */
#define		imfd_trdsr0		trdsr0_addr.bit.b3	/* Input-capture/compare-match flag D */
#define		ovf_trdsr0		trdsr0_addr.bit.b4	/* Overflow flag */
#define		udf_trdsr0		trdsr0_addr.bit.b5	/* Underflow flag */

/*------------------------------------------------------
  Timer RD interrupt enable register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdier0_addr@0x0144;
#define		trdier0		trdier0_addr.byte

#define		imiea_trdier0	trdier0_addr.bit.b0	/* Input-capture/compare-match interrupt enable bit A */
#define		imieb_trdier0	trdier0_addr.bit.b1	/* Input-capture/compare-match interrupt enable bit B */
#define		imiec_trdier0	trdier0_addr.bit.b2	/* Input-capture/compare-match interrupt enable bit C */
#define		imied_trdier0	trdier0_addr.bit.b3	/* Input-capture/compare-match interrupt enable bit D */
#define		ovie_trdier0	trdier0_addr.bit.b4	/* Overflow/underflow interrupt enable bit */

/*------------------------------------------------------
  Timer RD PWM mode output level control register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdpocr0_addr@0x0145;
#define		trdpocr0	trdpocr0_addr.byte

#define		polb_trdpocr0	trdpocr0_addr.bit.b0	/* PWM mode output level control bit B */
#define		polc_trdpocr0	trdpocr0_addr.bit.b1	/* PWM mode output level control bit C */
#define		pold_trdpocr0	trdpocr0_addr.bit.b2	/* PWM mode output level control bit D */

/*------------------------------------------------------
  Timer RD control register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdcr1_addr@0x0150;
#define		trdcr1		trdcr1_addr.byte

#define		tck0_trdcr1		trdcr1_addr.bit.b0	/* Count source select bit */
#define		tck1_trdcr1		trdcr1_addr.bit.b1	/* Count source select bit */
#define		tck2_trdcr1		trdcr1_addr.bit.b2	/* Count source select bit */
#define		ckeg0_trdcr1	trdcr1_addr.bit.b3	/* External clock edge select bit */
#define		ckeg1_trdcr1	trdcr1_addr.bit.b4	/* External clock edge select bit */
#define		cclr0_trdcr1	trdcr1_addr.bit.b5	/* TRD1 counter clear select bit */
#define		cclr1_trdcr1	trdcr1_addr.bit.b6	/* TRD1 counter clear select bit */
#define		cclr2_trdcr1	trdcr1_addr.bit.b7	/* TRD1 counter clear select bit */

/*------------------------------------------------------
  Timer RD I/O Control Register A1
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdiora1_addr@0x0151;
#define		trdiora1	trdiora1_addr.byte

#define		ioa0_trdiora1	trdiora1_addr.bit.b0	/* TRDGRA control bit */
#define		ioa1_trdiora1	trdiora1_addr.bit.b1	/* TRDGRA control bit */
#define		ioa2_trdiora1	trdiora1_addr.bit.b2	/* TRDGRA mode select bit */
#define		ioa3_trdiora1	trdiora1_addr.bit.b3	/* Input capture input switch bit */
#define		iob0_trdiora1	trdiora1_addr.bit.b4	/* TRDGRB control bit */
#define		iob1_trdiora1	trdiora1_addr.bit.b5	/* TRDGRB control bit */
#define		iob2_trdiora1	trdiora1_addr.bit.b6	/* TRDGRB mode select bit */

/*------------------------------------------------------
  Timer RD I/O Control Register C1
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdiorc1_addr@0x0152;
#define		trdiorc1	trdiorc1_addr.byte

#define		ioc0_trdiorc1	trdiorc1_addr.bit.b0	/* TRDGRC control bit */
#define		ioc1_trdiorc1	trdiorc1_addr.bit.b1	/* TRDGRC control bit */
#define		ioc2_trdiorc1	trdiorc1_addr.bit.b2	/* TRDGRC mode select bit */
#define		ioc3_trdiorc1	trdiorc1_addr.bit.b3	/* TRDGRC register function select bit */
#define		iod0_trdiorc1	trdiorc1_addr.bit.b4	/* TRDGRD control bit */
#define		iod1_trdiorc1	trdiorc1_addr.bit.b5	/* TRDGRD control bit */
#define		iod2_trdiorc1	trdiorc1_addr.bit.b6	/* TRDGRD mode select bit */
#define		iod3_trdiorc1	trdiorc1_addr.bit.b7	/* TRDGRD register function select bit */

/*------------------------------------------------------
  Timer RD status register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdsr1_addr@0x0153;
#define		trdsr1		trdsr1_addr.byte

#define		imfa_trdsr1		trdsr1_addr.bit.b0	/* Input-capture/compare-match flag A */
#define		imfb_trdsr1		trdsr1_addr.bit.b1	/* Input-capture/compare-match flag B */
#define		imfc_trdsr1		trdsr1_addr.bit.b2	/* Input-capture/compare-match flag C */
#define		imfd_trdsr1		trdsr1_addr.bit.b3	/* Input-capture/compare-match flag D */
#define		ovf_trdsr1		trdsr1_addr.bit.b4	/* Overflow flag */
#define		udf_trdsr1		trdsr1_addr.bit.b5	/* Underflow flag */

/*------------------------------------------------------
  Timer RD interrupt enable register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdier1_addr@0x0154;
#define		trdier1		trdier1_addr.byte

#define		imiea_trdier1	trdier1_addr.bit.b0	/* Input-capture/compare-match interrupt enable bit A */
#define		imieb_trdier1	trdier1_addr.bit.b1	/* Input-capture/compare-match interrupt enable bit B */
#define		imiec_trdier1	trdier1_addr.bit.b2	/* Input-capture/compare-match interrupt enable bit C */
#define		imied_trdier1	trdier1_addr.bit.b3	/* Input-capture/compare-match interrupt enable bit D */
#define		ovie_trdier1	trdier1_addr.bit.b4	/* Overflow/underflow interrupt enable bit */

/*------------------------------------------------------
  Timer RD PWM mode output level control register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	trdpocr1_addr@0x0155;
#define		trdpocr1	trdpocr1_addr.byte

#define		polb_trdpocr1	trdpocr1_addr.bit.b0	/* PWM mode output level control bit B */
#define		polc_trdpocr1	trdpocr1_addr.bit.b1	/* PWM mode output level control bit C */
#define		pold_trdpocr1	trdpocr1_addr.bit.b2	/* PWM mode output level control bit D */

/*------------------------------------------------------
  UART1 bit rate register
------------------------------------------------------*/
__no_init  volatile union	byte_def	u1brg_addr@0x0161;
#define		u1brg		u1brg_addr.byte

/*------------------------------------------------------
  UART1 Transmit Buffer Register Low
------------------------------------------------------*/
__no_init  volatile union	byte_def	u1tbl_addr@0x0162;
#define		u1tbl		u1tbl_addr.byte

/*------------------------------------------------------
  UART1 Transmit Buffer Register High
------------------------------------------------------*/
__no_init  volatile union	byte_def	u1tbh_addr@0x0163;
#define		u1tbh		u1tbh_addr.byte

/*------------------------------------------------------
  UART1 Receive Buffer Register
------------------------------------------------------*/
__no_init  volatile unsigned short u1rb_addr@0x0166;
#define		u1rb		u1rb_addr

/*------------------------------------------------------
  Timer RG Mode Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trgmr_addr@0x0170;
#define		trgmr		trgmr_addr.byte

#define		pwm_trgmr		trgmr_addr.bit.b0	/* PWM mode select bit */
#define		mdf_trgmr		trgmr_addr.bit.b1	/* Phase counting mode select bit */
#define		dfa_trgmr		trgmr_addr.bit.b2	/* Digital filer function select bit for TRGIOA pin */
#define		dfb_trgmr		trgmr_addr.bit.b3	/* Digital filer function select bit for TRGIOB pin */
#define		dfck0_trgmr		trgmr_addr.bit.b4	/* Digital filter function clock select bit */
#define		dfck1_trgmr		trgmr_addr.bit.b5	/* Digital filter function clock select bit */
#define		tstart_trgmr	trgmr_addr.bit.b7	/* TRG count start bit */

/*------------------------------------------------------
  Timer RG Count Control Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trgcntc_addr@0x0171;
#define		trgcntc		trgcntc_addr.byte

#define		cnten0_trgcntc	trgcntc_addr.bit.b0	/* Counter enable bit 0 */
#define		cnten1_trgcntc	trgcntc_addr.bit.b1	/* Counter enable bit 1 */
#define		cnten2_trgcntc	trgcntc_addr.bit.b2	/* Counter enable bit 2 */
#define		cnten3_trgcntc	trgcntc_addr.bit.b3	/* Counter enable bit 3 */
#define		cnten4_trgcntc	trgcntc_addr.bit.b4	/* Counter enable bit 4 */
#define		cnten5_trgcntc	trgcntc_addr.bit.b5	/* Counter enable bit 5 */
#define		cnten6_trgcntc	trgcntc_addr.bit.b6	/* Counter enable bit 6 */
#define		cnten7_trgcntc	trgcntc_addr.bit.b7	/* Counter enable bit 7 */

/*------------------------------------------------------
  Timer RG control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trgcr_addr@0x0172;
#define		trgcr		trgcr_addr.byte

#define		tck0_trgcr	trgcr_addr.bit.b0		/* Count source select bit */
#define		tck1_trgcr	trgcr_addr.bit.b1		/* Count source select bit */
#define		tck2_trgcr	trgcr_addr.bit.b2		/* Count source select bit */
#define		ckeg0_trgcr	trgcr_addr.bit.b3		/* External clock active edge select bit */
#define		ckeg1_trgcr	trgcr_addr.bit.b4		/* External clock active edge select bit */
#define		cclr0_trgcr	trgcr_addr.bit.b5		/* TRG register clear select bit */
#define		cclr1_trgcr	trgcr_addr.bit.b6		/* TRG register clear select bit */

/*------------------------------------------------------
  Timer RG interrupt enable register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trgier_addr@0x0173;
#define		trgier		trgier_addr.byte

#define		imiea_trgier	trgier_addr.bit.b0	/* Input-capture/compare-match interrupt enable bit A */
#define		imieb_trgier	trgier_addr.bit.b1	/* Input-capture/compare-match interrupt enable bit B */
#define		udie_trgier		trgier_addr.bit.b2	/* Underflow interrupt enable bit */
#define		ovie_trgier		trgier_addr.bit.b3	/* Overflow interrupt enable bit */

/*------------------------------------------------------
  Timer RG status register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trgsr_addr@0x0174;
#define		trgsr		trgsr_addr.byte

#define		imfa_trgsr	trgsr_addr.bit.b0		/* Input-capture/compare-match flag A */
#define		imfb_trgsr	trgsr_addr.bit.b1		/* Input-capture/compare-match flag B */
#define		udf_trgsr	trgsr_addr.bit.b2		/* Underflow flag */
#define		ovf_trgsr	trgsr_addr.bit.b3		/* Overflow flag */
#define		dirf_trgsr	trgsr_addr.bit.b4		/* Count direction flag */

/*------------------------------------------------------
  Timer RG I/O Control Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trgior_addr@0x0175;
#define		trgior		trgior_addr.byte

#define		ioa0_trgior	trgior_addr.bit.b0		/* TRGGRA control bit */
#define		ioa1_trgior	trgior_addr.bit.b1		/* TRGGRA control bit */
#define		ioa2_trgior	trgior_addr.bit.b2		/* TRGGRA mode select bit */
#define		bufa_trgior	trgior_addr.bit.b3		/* TRGGRC register function select bit */
#define		iob0_trgior	trgior_addr.bit.b4		/* TRGGRB control bit */
#define		iob1_trgior	trgior_addr.bit.b5		/* TRGGRB control bit */
#define		iob2_trgior	trgior_addr.bit.b6		/* TRGGRB mode select bit */
#define		bufb_trgior	trgior_addr.bit.b7		/* TRGGRD register function select bit */

/*------------------------------------------------------
  Timer RG counter register, Timer RG Counter , General register A,B,C,D
------------------------------------------------------*/
__no_init  volatile unsigned short trg_addr@0x0176, trggra_addr@0x0178, trggrb_addr@0x017A,trggrc_addr@0x017C,trggrd_addr@0x017E;

#define		trg				trg_addr			/* Timer GR counter */
#define		trggra			trggra_addr			/* Timer GR general register A */
#define		trggrb			trggrb_addr			/* Timer GR general register B */
#define		trggrc			trggrc_addr			/* Timer GR general register C */
#define		trggrd			trggrd_addr			/* Timer GR general register D */

/*------------------------------------------------------
  Timer RA Pin Select Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trasr_addr@0x0180;
#define		trasr		trasr_addr.byte

#define		traiosel0			trasr_addr.bit.b0	/* TRAIO pin select bit */
#define		traiosel1			trasr_addr.bit.b1	/* TRAIO pin select bit */
#define		traiosel0_trasr		trasr_addr.bit.b0	/* TRAIO pin select bit */
#define		traiosel1_trasr		trasr_addr.bit.b1	/* TRAIO pin select bit */

/*------------------------------------------------------
  Timer RB/RC pin select register
------------------------------------------------------*/
__no_init  volatile union	byte_def	trbrcsr_addr@0x0181;
#define		trbrcsr		trbrcsr_addr.byte

#define		trcclksel0			trbrcsr_addr.bit.b4	/* TRCCLK pin select bit */
#define		trctrgsel0			trbrcsr_addr.bit.b6	/* TRCTRG pin select bit */
#define		trctrgsel1			trbrcsr_addr.bit.b7	/* TRCTRG pin select bit */
#define		trcclksel0_trbrcsr	trbrcsr_addr.bit.b4	/* TRCCLK pin select bit */
#define		trctrgsel0_trbrcsr	trbrcsr_addr.bit.b6	/* TRCTRG pin select bit */
#define		trctrgsel1_trbrcsr	trbrcsr_addr.bit.b7	/* TRCTRG pin select bit */

/*------------------------------------------------------
  Timer RC Pin Select Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	trcpsr0_addr@0x0182;
#define		trcpsr0		trcpsr0_addr.byte

#define		trcioasel0			trcpsr0_addr.bit.b0	/* TRCIOA pin select bit */
#define		trciobsel0			trcpsr0_addr.bit.b4	/* TRCIOB pin select bit */
#define		trciobsel1			trcpsr0_addr.bit.b5	/* TRCIOB pin select bit */
#define		trcioasel0_trcpsr0	trcpsr0_addr.bit.b0	/* TRCIOA pin select bit */
#define		trciobsel0_trcpsr0	trcpsr0_addr.bit.b4	/* TRCIOB pin select bit */
#define		trciobsel1_trcpsr0	trcpsr0_addr.bit.b5	/* TRCIOB pin select bit */

/*------------------------------------------------------
  Timer RC pin select register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	trcpsr1_addr@0x0183;
#define		trcpsr1		trcpsr1_addr.byte

#define		trciocsel0			trcpsr1_addr.bit.b0	/* TRCIOC pin select bit */
#define		trciodsel0			trcpsr1_addr.bit.b4	/* TRCIOD pin select bit */
#define		trciocsel0_trcpsr1	trcpsr1_addr.bit.b0	/* TRCIOC pin select bit */
#define		trciodsel0_trcpsr1	trcpsr1_addr.bit.b4	/* TRCIOD pin select bit */

/*------------------------------------------------------
  UART0 pin select register
------------------------------------------------------*/
__no_init  volatile union	byte_def	u0sr_addr@0x0188;
#define		u0sr		u0sr_addr.byte

#define		txd0sel0		u0sr_addr.bit.b0	/* TXD0 pin select bit */
#define		rxd0sel0		u0sr_addr.bit.b2	/* RXD0 pin select bit */
#define		rxd0sel1		u0sr_addr.bit.b3	/* RXD0 pin select bit */
#define		clk0sel0		u0sr_addr.bit.b4	/* CLK0 pin select bit */
#define		txd0sel0_u0sr	u0sr_addr.bit.b0	/* TXD0 pin select bit */
#define		rxd0sel0_u0sr	u0sr_addr.bit.b2	/* RXD0 pin select bit */
#define		rxd0sel1_u0sr	u0sr_addr.bit.b3	/* RXD0 pin select bit */
#define		clk0sel0_u0sr	u0sr_addr.bit.b4	/* CLK0 pin select bit */

/*------------------------------------------------------
  UART1 pin select register
------------------------------------------------------*/
__no_init  volatile union	byte_def	u1sr_addr@0x0189;
#define		u1sr		u1sr_addr.byte

#define		txd1sel0		u1sr_addr.bit.b0	/* TXD1 pin select bit */
#define		rxd1sel0		u1sr_addr.bit.b2	/* RXD1 pin select bit */
#define		clk1sel0		u1sr_addr.bit.b4	/* CLK1 pin select bit */
#define		txd1sel0_u1sr	u1sr_addr.bit.b0	/* TXD1 pin select bit */
#define		rxd1sel0_u1sr	u1sr_addr.bit.b2	/* RXD1 pin select bit */
#define		clk1sel0_u1sr	u1sr_addr.bit.b4	/* CLK1 pin select bit */

/*------------------------------------------------------
  UART2 pin select register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	u2sr0_addr@0x018A;
#define		u2sr0		u2sr0_addr.byte

#define		txd2sel0		u2sr0_addr.bit.b0	/* TXD2/SDA2 pin select bit */
#define		txd2sel1		u2sr0_addr.bit.b1	/* TXD2/SDA2 pin select bit */
#define		rxd2sel0		u2sr0_addr.bit.b4	/* RXD2/SCL2 pin select bit */
#define		rxd2sel1		u2sr0_addr.bit.b5	/* RXD2/SCL2 pin select bit */
#define		txd2sel0_u2sr0	u2sr0_addr.bit.b0	/* TXD2/SDA2 pin select bit */
#define		txd2sel1_u2sr0	u2sr0_addr.bit.b1	/* TXD2/SDA2 pin select bit */
#define		rxd2sel0_u2sr0	u2sr0_addr.bit.b4	/* RXD2/SCL2 pin select bit */
#define		rxd2sel1_u2sr0	u2sr0_addr.bit.b5	/* RXD2/SCL2 pin select bit */

/*------------------------------------------------------
  UART2 pin select register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	u2sr1_addr@0x018B;
#define		u2sr1		u2sr1_addr.byte

#define		clk2sel0		u2sr1_addr.bit.b0	/* CLK2 pin select bit */
#define		cts2sel0		u2sr1_addr.bit.b4	/* CTS2/RTS2 pin select bit */
#define		clk2sel0_u2sr1	u2sr1_addr.bit.b0	/* CLK2 pin select bit */
#define		cts2sel0_u2sr1	u2sr1_addr.bit.b4	/* CTS2/RTS2 pin select bit */

/*------------------------------------------------------
  SSU/IIC Pin Select Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	ssuiicsr_addr@0x018C;
#define		ssuiicsr	ssuiicsr_addr.byte

#define		iicsel			ssuiicsr_addr.bit.b0	/* SSU/I2C bus switch bit */
#define		iicsel_ssuiicsr	ssuiicsr_addr.bit.b0	/* SSU/I2C bus switch bit */

/*------------------------------------------------------
  Key Input Pin Select Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	kisr_addr@0x018D;
#define		kisr	kisr_addr.byte

#define		ki4sel0			kisr_addr.bit.b4	/* KI4 pin select bit */
#define		ki5sel0			kisr_addr.bit.b5	/* KI5 pin select bit */
#define		ki6sel0			kisr_addr.bit.b6	/* KI6 pin select bit */
#define		ki7sel0			kisr_addr.bit.b7	/* KI7 pin select bit */
#define		ki4sel0_kisr	kisr_addr.bit.b4	/* KI4 pin select bit */
#define		ki5sel0_kisr	kisr_addr.bit.b5	/* KI5 pin select bit */
#define		ki6sel0_kisr	kisr_addr.bit.b6	/* KI6 pin select bit */
#define		ki7sel0_kisr	kisr_addr.bit.b7	/* KI7 pin select bit */

/*------------------------------------------------------
  INT Interrupt Input Pin Select Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	intsr_addr@0x018E;
#define		intsr		intsr_addr.byte

#define		int0sel0		intsr_addr.bit.b0	/* INT0 pin select bit */
#define		int1sel0		intsr_addr.bit.b1	/* INT1 pin select bit */
#define		int2sel0		intsr_addr.bit.b2	/* INT2 pin select bit */
#define		int3sel0		intsr_addr.bit.b3	/* INT3 pin select bit */
#define		int4sel0		intsr_addr.bit.b4	/* INT4 pin select bit */
#define		int0sel0_intsr	intsr_addr.bit.b0	/* INT0 pin select bit */
#define		int1sel0_intsr	intsr_addr.bit.b1	/* INT1 pin select bit */
#define		int2sel0_intsr	intsr_addr.bit.b2	/* INT2 pin select bit */
#define		int3sel0_intsr	intsr_addr.bit.b3	/* INT3 pin select bit */
#define		int4sel0_intsr	intsr_addr.bit.b4	/* INT4 pin select bit */

/*------------------------------------------------------
  I/O Function Pin Select Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	pinsr_addr@0x018F;
#define		pinsr		pinsr_addr.byte

#define		ioinsel			pinsr_addr.bit.b3	/* I/O port input function select bit */
#define		iictctwi		pinsr_addr.bit.b4	/* I2C double transfer rate select bit */
#define		iictchalf		pinsr_addr.bit.b5	/* I2C half transfer rate select bit */
#define		sdadly0			pinsr_addr.bit.b6	/* SDA digital delay select bit */
#define		sdadly1			pinsr_addr.bit.b7	/* SDA digital delay select bit */
#define		ioinsel_pinsr	pinsr_addr.bit.b3	/* I/O port input function select bit */
#define		iictctwi_pinsr	pinsr_addr.bit.b4	/* I2C double transfer rate select bit */
#define		iictchalf_pinsr	pinsr_addr.bit.b5	/* I2C half transfer rate select bit */
#define		sdadly0_pinsr	pinsr_addr.bit.b6	/* SDA digital delay select bit */
#define		sdadly1_pinsr	pinsr_addr.bit.b7	/* SDA digital delay select bit */

/*------------------------------------------------------
  SS bit counter register
------------------------------------------------------*/
__no_init  volatile union	byte_def	ssbr_addr@0x0193;
#define		ssbr		ssbr_addr.byte

#define		bs0				ssbr_addr.bit.b0	/* SSU data transfer length set bit */
#define		bs1				ssbr_addr.bit.b1	/* SSU data transfer length set bit */
#define		bs2				ssbr_addr.bit.b2	/* SSU data transfer length set bit */
#define		bs3				ssbr_addr.bit.b3	/* SSU data transfer length set bit */
#define		bs0_ssbr		ssbr_addr.bit.b0	/* SSU data transfer length set bit */
#define		bs1_ssbr		ssbr_addr.bit.b1	/* SSU data transfer length set bit */
#define		bs2_ssbr		ssbr_addr.bit.b2	/* SSU data transfer length set bit */
#define		bs3_ssbr		ssbr_addr.bit.b3	/* SSU data transfer length set bit */

/*------------------------------------------------------
  IIC bus transmit data register
------------------------------------------------------*/
__no_init  volatile union	byte_def	icdrt_addr@0x0194;
#define		icdrt		icdrt_addr.byte

/*------------------------------------------------------
  IIC bus receive data register
------------------------------------------------------*/
__no_init  volatile union	byte_def	icdrr_addr@0x0196;
#define		icdrr		icdrr_addr.byte

/*------------------------------------------------------
  SS Control Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	sscrh_addr@0x0198;
#define		sscrh		sscrh_addr.byte

#define		cks0_sscrh		sscrh_addr.bit.b0	/* Transfer clock select bit */
#define		cks1_sscrh		sscrh_addr.bit.b1	/* Transfer clock select bit */
#define		cks2_sscrh		sscrh_addr.bit.b2	/* Transfer clock select bit */
#define		mss_sscrh		sscrh_addr.bit.b5	/* Master/Slave device select bit */
#define		rsstp_sscrh		sscrh_addr.bit.b6	/* Receive single stop bit */

/*------------------------------------------------------
  IIC bus control register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	iccr1_addr@0x0198;
#define		iccr1		iccr1_addr.byte

#define		cks0_iccr1		iccr1_addr.bit.b0	/* Transmit clock select bit 3 to 0 */
#define		cks1_iccr1		iccr1_addr.bit.b1	/* Transmit clock select bit 3 to 0 */
#define		cks2_iccr1		iccr1_addr.bit.b2	/* Transmit clock select bit 3 to 0 */
#define		cks3_iccr1		iccr1_addr.bit.b3	/* Transmit clock select bit 3 to 0 */
#define		trs_iccr1		iccr1_addr.bit.b4	/* Transmission/reception select bit */
#define		mst_iccr1		iccr1_addr.bit.b5	/* Master/slave select bit */
#define		rcvd_iccr1		iccr1_addr.bit.b6	/* Reception disable bit */
#define		ice_iccr1		iccr1_addr.bit.b7	/* I2C bus interface enable bit */

/*------------------------------------------------------
  SS control register L
------------------------------------------------------*/
__no_init  volatile union	byte_def	sscrl_addr@0x0199;
#define		sscrl		sscrl_addr.byte

#define		sres_sscrl		sscrl_addr.bit.b1	/* SSU control unit reset bit */
#define		solp_sscrl		sscrl_addr.bit.b4	/* SOL write protect bit */
#define		sol_sscrl		sscrl_addr.bit.b5	/* Serial data output value setting bit */

/*------------------------------------------------------
  IIC bus control register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	iccr2_addr@0x0199;
#define		iccr2		iccr2_addr.byte

#define		iicrst_iccr2	iccr2_addr.bit.b1	/* I2C bus control block reset bit */
#define		sclo_iccr2		iccr2_addr.bit.b3	/* SCL monitor flag */
#define		sdaop_iccr2		iccr2_addr.bit.b4	/* SDAO write protect bit */
#define		sdao_iccr2		iccr2_addr.bit.b5	/* SDA output value control bit */
#define		scp_iccr2		iccr2_addr.bit.b6	/* Start/Stop condition generation disable bit */
#define		bbsy_iccr2		iccr2_addr.bit.b7	/* Bus busy bit */

/*------------------------------------------------------
  SS mode register
------------------------------------------------------*/
__no_init  volatile union	byte_def	ssmr_addr@0x019A;
#define		ssmr		ssmr_addr.byte

#define		bc0_ssmr		ssmr_addr.bit.b0	/* Bit counter 3 to 0 */
#define		bc1_ssmr		ssmr_addr.bit.b1	/* Bit counter 3 to 0 */
#define		bc2_ssmr		ssmr_addr.bit.b2	/* Bit counter 3 to 0 */
#define		bc3_ssmr		ssmr_addr.bit.b3	/* Bit counter 3 to 0 */
#define		cphs_ssmr		ssmr_addr.bit.b5	/* SSCK clock phase select bit */
#define		cpos_ssmr		ssmr_addr.bit.b6	/* SSCK clock polarity select bit */
#define		mls_ssmr		ssmr_addr.bit.b7	/* MSB first/LSB first select bit */

/*------------------------------------------------------
  IIC bus mode register
------------------------------------------------------*/
__no_init  volatile union	byte_def	icmr_addr@0x019A;
#define		icmr		icmr_addr.byte

#define		bc0_icmr		icmr_addr.bit.b0	/* Bit counter 2 to 0 */
#define		bc1_icmr		icmr_addr.bit.b1	/* Bit Counter 2 to 0 */
#define		bc2_icmr		icmr_addr.bit.b2	/* Bit Counter 2 to 0 */
#define		bcwp_icmr		icmr_addr.bit.b3	/* BC write protect bit */
#define		wait_icmr		icmr_addr.bit.b6	/* Wait insertion bit */
#define		mls_icmr		icmr_addr.bit.b7	/* MSB first/LSB first select bit */

/*------------------------------------------------------
  SS Enable Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	sser_addr@0x019B;
#define		sser		sser_addr.byte

#define		ceie_sser		sser_addr.bit.b0	/* Conflict error interrupt enable bit */
#define		re_sser			sser_addr.bit.b3	/* Reception enable bit */
#define		te_sser			sser_addr.bit.b4	/* Transmission enable bit */
#define		rie_sser		sser_addr.bit.b5	/* Receive interrupt enable bit */
#define		teie_sser		sser_addr.bit.b6	/* Transmit end interrupt enable bit */
#define		tie_sser		sser_addr.bit.b7	/* Transmit interrupt enable bit */

/*------------------------------------------------------
  IIC bus interrupt enable register
------------------------------------------------------*/
__no_init  volatile union	byte_def	icier_addr@0x019B;
#define		icier		icier_addr.byte

#define		ackbt_icier		icier_addr.bit.b0	/* Transmit acknowledge select bit */
#define		ackbr_icier		icier_addr.bit.b1	/* Receive acknowledge bit */
#define		acke_icier		icier_addr.bit.b2	/* Acknowledge bit detection select bit */
#define		stie_icier		icier_addr.bit.b3	/* Stop condition detection interrupt enable bit */
#define		nakie_icier		icier_addr.bit.b4	/* NACK receive interrupt enable bit */
#define		rie_icier		icier_addr.bit.b5	/* Receive interrupt enable bit */
#define		teie_icier		icier_addr.bit.b6	/* Transmit end interrupt enable bit */
#define		tie_icier		icier_addr.bit.b7	/* Transmit interrupt enable bit */

/*------------------------------------------------------
  SS status register
------------------------------------------------------*/
__no_init  volatile union	byte_def	sssr_addr@0x019C;
#define		sssr		sssr_addr.byte

#define		ce_sssr			sssr_addr.bit.b0	/* Conflict error flag */
#define		orer_sssr		sssr_addr.bit.b2	/* Overrun error flag */
#define		rdrf_sssr		sssr_addr.bit.b5	/* Receive data register full flag */
#define		tend_sssr		sssr_addr.bit.b6	/* Transmit end flag */
#define		tdre_sssr		sssr_addr.bit.b7	/* Transmit data empty flag */

/*------------------------------------------------------
  IIC bus status register
------------------------------------------------------*/
__no_init  volatile union	byte_def	icsr_addr@0x019C;
#define		icsr		icsr_addr.byte

#define		adz_icsr		icsr_addr.bit.b0	/* General call address recognition flag */
#define		aas_icsr		icsr_addr.bit.b1	/* Slave address recognition flag */
#define		al_icsr			icsr_addr.bit.b2	/* Arbitration lost flag/ overrun error flag */
#define		stop_icsr		icsr_addr.bit.b3	/* Stop condition detection flag */
#define		nackf_icsr		icsr_addr.bit.b4	/* No acknowledge detection flag */
#define		rdrf_icsr		icsr_addr.bit.b5	/* Receive data register full flag */
#define		tend_icsr		icsr_addr.bit.b6	/* Transmit end flag */
#define		tdre_icsr		icsr_addr.bit.b7	/* Transmit data empty flag */

/*------------------------------------------------------
  SS mode register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	ssmr2_addr@0x019D;
#define		ssmr2		ssmr2_addr.byte

#define		ssums_ssmr2		ssmr2_addr.bit.b0	/* SSU mode select bit */
#define		csos_ssmr2		ssmr2_addr.bit.b1	/* SCS pin open-drain output select bit */
#define		soos_ssmr2		ssmr2_addr.bit.b2	/* Serial data open-drain output select bit */
#define		sckos_ssmr2		ssmr2_addr.bit.b3	/* SSCK pin open-drain output select bit */
#define		css0_ssmr2		ssmr2_addr.bit.b4	/* SCS pin select bit */
#define		css1_ssmr2		ssmr2_addr.bit.b5	/* SCS pin select bit */
#define		scks_ssmr2		ssmr2_addr.bit.b6	/* SSCK pin select bit */
#define		bide_ssmr2		ssmr2_addr.bit.b7	/* Bidirectional mode enable bit */

/*------------------------------------------------------
  Slave address register
------------------------------------------------------*/
__no_init  volatile union	byte_def	sar_addr@0x019D;
#define		sar			sar_addr.byte

#define		fs_sar			sar_addr.bit.b0		/* Format select bit */
#define		sva0_sar		sar_addr.bit.b1		/* Slave address 6 to 0 */
#define		sva1_sar		sar_addr.bit.b2		/* Slave address 6 to 0 */
#define		sva2_sar		sar_addr.bit.b3		/* Slave address 6 to 0 */
#define		sva3_sar		sar_addr.bit.b4		/* Slave address 6 to 0 */
#define		sva4_sar		sar_addr.bit.b5		/* Slave address 6 to 0 */
#define		sva5_sar		sar_addr.bit.b6		/* Slave address 6 to 0 */
#define		sva6_sar		sar_addr.bit.b7		/* Slave address 6 to 0 */

/*------------------------------------------------------
  Flash memory status register
------------------------------------------------------*/
__no_init  volatile union	byte_def	fst_addr@0x01B2;
#define		fst			fst_addr.byte

#define		rdysti			fst_addr.bit.b0		/* Flash ready status interrupt request flag */
#define		bsyaei			fst_addr.bit.b1		/* Flash access error interrupt request flag */
#define		lbdata			fst_addr.bit.b2		/* LBDATA monitor flag */
#define		fst4			fst_addr.bit.b4		/* Program error flag */
#define		fst5			fst_addr.bit.b5		/* Erase error/blank check error flag */
#define		fst6			fst_addr.bit.b6		/* Erase-suspend status flag */
#define		fst7			fst_addr.bit.b7		/* Ready/Busy status flag */
#define		rdysti_fst		fst_addr.bit.b0		/* Flash ready status interrupt request flag */
#define		bsyaei_fst		fst_addr.bit.b1		/* Flash access error interrupt request flag */
#define		lbdata_fst		fst_addr.bit.b2		/* LBDATA monitor flag */
#define		fst4_fst		fst_addr.bit.b4		/* Program error flag */
#define		fst5_fst		fst_addr.bit.b5		/* Erase error/blank check error flag */
#define		fst6_fst		fst_addr.bit.b6		/* Erase-suspend status flag */
#define		fst7_fst		fst_addr.bit.b7		/* Ready/Busy status flag */

/*------------------------------------------------------
  Flash Memory Control Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	fmr0_addr@0x01B4;
#define		fmr0		fmr0_addr.byte

#define		fmr00			fmr0_addr.bit.b0	/* Program unit select bit */
#define		fmr01			fmr0_addr.bit.b1	/* CPU rewrite mode select bit */
#define		fmr02			fmr0_addr.bit.b2	/* EW1 mode select bit */
#define		fmstp			fmr0_addr.bit.b3	/* Flash memory stop bit */
#define		cmdrst			fmr0_addr.bit.b4	/* Erase/Write sequence reset bit */
#define		cmderie			fmr0_addr.bit.b5	/* Erase/Write error interrupt enable bit */
#define		bsyaeie			fmr0_addr.bit.b6	/* Flash access error interrupt enable bit */
#define		rdystie			fmr0_addr.bit.b7	/* Flash ready status interrupt enable bit */
#define		fmr00_fmr0		fmr0_addr.bit.b0	/* Program unit select bit */
#define		fmr01_fmr0		fmr0_addr.bit.b1	/* CPU rewrite mode select bit */
#define		fmr02_fmr0		fmr0_addr.bit.b2	/* EW1 mode select bit */
#define		fmstp_fmr0		fmr0_addr.bit.b3	/* Flash memory stop bit */
#define		cmdrst_fmr0		fmr0_addr.bit.b4	/* Erase/Write sequence reset bit */
#define		cmderie_fmr0	fmr0_addr.bit.b5	/* Erase/Write error interrupt enable bit */
#define		bsyaeie_fmr0	fmr0_addr.bit.b6	/* Flash access error interrupt enable bit */
#define		rdystie_fmr0	fmr0_addr.bit.b7	/* Flash ready status interrupt enable bit */

/*------------------------------------------------------
  Flash Memory Control Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	fmr1_addr@0x01B5;
#define		fmr1		fmr1_addr.byte

#define		fmr13			fmr1_addr.bit.b3	/* Lock bit disable select bit */
#define		fmr14			fmr1_addr.bit.b4	/* Data flash block A rewrite disable bit */
#define		fmr15			fmr1_addr.bit.b5	/* Data flash block B rewrite disable bit */
#define		fmr16			fmr1_addr.bit.b6	/* Data flash block C rewrite disable bit */
#define		fmr17			fmr1_addr.bit.b7	/* Data flash block D rewrite disable bit */
#define		fmr13_fmr1		fmr1_addr.bit.b3	/* Lock bit disable select bit */
#define		fmr14_fmr1		fmr1_addr.bit.b4	/* Data flash block A rewrite disable bit */
#define		fmr15_fmr1		fmr1_addr.bit.b5	/* Data flash block B rewrite disable bit */
#define		fmr16_fmr1		fmr1_addr.bit.b6	/* Data flash block C rewrite disable bit */
#define		fmr17_fmr1		fmr1_addr.bit.b7	/* Data flash block D rewrite disable bit */

/*------------------------------------------------------
  Flash Memory Control Register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	fmr2_addr@0x01B6;
#define		fmr2		fmr2_addr.byte

#define		fmr20			fmr2_addr.bit.b0	/* Erase-suspend enable bit */
#define		fmr21			fmr2_addr.bit.b1	/* Erase-suspend request bit */
#define		fmr22			fmr2_addr.bit.b2	/* Interrupt request suspend request enable bit */
#define		fmr27			fmr2_addr.bit.b7	/* Low-consumption-current read mode enable bit */
#define		fmr20_fmr2		fmr2_addr.bit.b0	/* Erase-suspend enable bit */
#define		fmr21_fmr2		fmr2_addr.bit.b1	/* Erase-suspend request bit */
#define		fmr22_fmr2		fmr2_addr.bit.b2	/* Interrupt request suspend request enable bit */
#define		fmr27_fmr2		fmr2_addr.bit.b7	/* Low-consumption-current read mode enable bit */

/*------------------------------------------------------
  Address match interrupt enable register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	aier0_addr@0x01C3;
#define		aier0		aier0_addr.byte

#define		aier00			aier0_addr.bit.b0	/* Address match interrupt 0 enable bit */
#define		aier00_aier0	aier0_addr.bit.b0	/* Address match interrupt 0 enable bit */

/*------------------------------------------------------
  Address match interrupt enable register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	aier1_addr@0x01C7;
#define		aier1		aier1_addr.byte

#define		aier10			aier1_addr.bit.b0	/* Address match interrupt 1 enable bit */
#define		aier10_aier1	aier1_addr.bit.b0	/* Address match interrupt 1 enable bit */

/*------------------------------------------------------
  Port P0 Pull-up control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p0pur_addr@0x01E0;
#define		p0pur		p0pur_addr.byte

#define		pu00			p0pur_addr.bit.b0	/* Port P0_0 pull-up */
#define		pu01			p0pur_addr.bit.b1	/* Port P0_1 pull-up */
#define		pu02			p0pur_addr.bit.b2	/* Port P0_2 pull-up */
#define		pu03			p0pur_addr.bit.b3	/* Port P0_3 pull-up */
#define		pu04			p0pur_addr.bit.b4	/* Port P0_4 pull-up */
#define		pu05			p0pur_addr.bit.b5	/* Port P0_5 pull-up */
#define		pu06			p0pur_addr.bit.b6	/* Port P0_6 pull-up */
#define		pu07			p0pur_addr.bit.b7	/* Port P0_7 pull-up */
#define		pu00_p0pur		p0pur_addr.bit.b0	/* Port P0_0 pull-up */
#define		pu01_p0pur		p0pur_addr.bit.b1	/* Port P0_1 pull-up */
#define		pu02_p0pur		p0pur_addr.bit.b2	/* Port P0_2 pull-up */
#define		pu03_p0pur		p0pur_addr.bit.b3	/* Port P0_3 pull-up */
#define		pu04_p0pur		p0pur_addr.bit.b4	/* Port P0_4 pull-up */
#define		pu05_p0pur		p0pur_addr.bit.b5	/* Port P0_5 pull-up */
#define		pu06_p0pur		p0pur_addr.bit.b6	/* Port P0_6 pull-up */
#define		pu07_p0pur		p0pur_addr.bit.b7	/* Port P0_7 pull-up */

/*------------------------------------------------------
  Port P2 Pull-up control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p2pur_addr@0x01E2;
#define		p2pur		p2pur_addr.byte

#define		pu24			p2pur_addr.bit.b4	/* Port P2_4 pull-up */
#define		pu25			p2pur_addr.bit.b5	/* Port P2_5 pull-up */
#define		pu26			p2pur_addr.bit.b6	/* Port P2_6 pull-up */
#define		pu27			p2pur_addr.bit.b7	/* Port P2_7 pull-up */
#define		pu24_p2pur		p2pur_addr.bit.b4	/* Port P2_4 pull-up */
#define		pu25_p2pur		p2pur_addr.bit.b5	/* Port P2_5 pull-up */
#define		pu26_p2pur		p2pur_addr.bit.b6	/* Port P2_6 pull-up */
#define		pu27_p2pur		p2pur_addr.bit.b7	/* Port P2_7 pull-up */

/*------------------------------------------------------
  Port P3 Pull-up control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p3pur_addr@0x01E3;
#define		p3pur		p3pur_addr.byte

#define		pu30			p3pur_addr.bit.b0	/* Port P3_0 pull-up */
#define		pu31			p3pur_addr.bit.b1	/* Port P3_1 pull-up */
#define		pu32			p3pur_addr.bit.b2	/* Port P3_2 pull-up */
#define		pu33			p3pur_addr.bit.b3	/* Port P3_3 pull-up */
#define		pu30_p3pur		p3pur_addr.bit.b0	/* Port P3_0 pull-up */
#define		pu31_p3pur		p3pur_addr.bit.b1	/* Port P3_1 pull-up */
#define		pu32_p3pur		p3pur_addr.bit.b2	/* Port P3_2 pull-up */
#define		pu33_p3pur		p3pur_addr.bit.b3	/* Port P3_3 pull-up */

/*------------------------------------------------------
  Port P4 Pull-up control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p4pur_addr@0x01E4;
#define		p4pur		p4pur_addr.byte

#define		pu40			p4pur_addr.bit.b0	/* Port P4_0 pull-up */
#define		pu41			p4pur_addr.bit.b1	/* Port P4_1 pull-up */
#define		pu42			p4pur_addr.bit.b2	/* Port P4_2 pull-up */
#define		pu43			p4pur_addr.bit.b3	/* Port P4_3 pull-up */
#define		pu44			p4pur_addr.bit.b4	/* Port P4_4 pull-up */
#define		pu45			p4pur_addr.bit.b5	/* Port P4_5 pull-up */
#define		pu46			p4pur_addr.bit.b6	/* Port P4_6 pull-up */
#define		pu47			p4pur_addr.bit.b7	/* Port P4_7 pull-up */
#define		pu40_p4pur		p4pur_addr.bit.b0	/* Port P4_0 pull-up */
#define		pu41_p4pur		p4pur_addr.bit.b1	/* Port P4_1 pull-up */
#define		pu42_p4pur		p4pur_addr.bit.b2	/* Port P4_2 pull-up */
#define		pu43_p4pur		p4pur_addr.bit.b3	/* Port P4_3 pull-up */
#define		pu44_p4pur		p4pur_addr.bit.b4	/* Port P4_4 pull-up */
#define		pu45_p4pur		p4pur_addr.bit.b5	/* Port P4_5 pull-up */
#define		pu46_p4pur		p4pur_addr.bit.b6	/* Port P4_6 pull-up */
#define		pu47_p4pur		p4pur_addr.bit.b7	/* Port P4_7 pull-up */


/*------------------------------------------------------
  Port P7 Pull-up control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p7pur_addr@0x01E7;
#define		p7pur		p7pur_addr.byte

#define		pu74			p7pur_addr.bit.b4	/* Port P7_4 pull-up */
#define		pu75			p7pur_addr.bit.b5	/* Port P7_5 pull-up */
#define		pu76			p7pur_addr.bit.b6	/* Port P7_6 pull-up */
#define		pu77			p7pur_addr.bit.b7	/* Port P7_7 pull-up */
#define		pu74_p7pur		p7pur_addr.bit.b4	/* Port P7_4 pull-up */
#define		pu75_p7pur		p7pur_addr.bit.b5	/* Port P7_5 pull-up */
#define		pu76_p7pur		p7pur_addr.bit.b6	/* Port P7_6 pull-up */
#define		pu77_p7pur		p7pur_addr.bit.b7	/* Port P7_7 pull-up */

/*------------------------------------------------------
  Port P11 Pull-up control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p11pur_addr@0x01EB;
#define		p11pur		p11pur_addr.byte

#define		pu110			p11pur_addr.bit.b0	/* Port P11_0 pull-up */
#define		pu111			p11pur_addr.bit.b1	/* Port P11_1 pull-up */
#define		pu112			p11pur_addr.bit.b2	/* Port P11_2 pull-up */
#define		pu113			p11pur_addr.bit.b3	/* Port P11_3 pull-up */
#define		pu114			p11pur_addr.bit.b4	/* Port P11_4 pull-up */
#define		pu110_p11pur	p11pur_addr.bit.b0	/* Port P11_0 pull-up */
#define		pu111_p11pur	p11pur_addr.bit.b1	/* Port P11_1 pull-up */
#define		pu112_p11pur	p11pur_addr.bit.b2	/* Port P11_2 pull-up */
#define		pu113_p11pur	p11pur_addr.bit.b3	/* Port P11_3 pull-up */
#define		pu114_p11pur	p11pur_addr.bit.b4	/* Port P11_4 pull-up */

/*------------------------------------------------------
  Port P12 Pull-up control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p12pur_addr@0x01EC;
#define		p12pur		p12pur_addr.byte

#define		pu120			p12pur_addr.bit.b0	/* Port P12_0 pull-up */
#define		pu121			p12pur_addr.bit.b1	/* Port P12_1 pull-up */
#define		pu122			p12pur_addr.bit.b2	/* Port P12_2 pull-up */
#define		pu123			p12pur_addr.bit.b3	/* Port P12_3 pull-up */
#define		pu124			p12pur_addr.bit.b4	/* Port P12_4 pull-up */
#define		pu125			p12pur_addr.bit.b5	/* Port P12_5 pull-up */
#define		pu126			p12pur_addr.bit.b6	/* Port P12_6 pull-up */
#define		pu127			p12pur_addr.bit.b7	/* Port P12_7 pull-up */
#define		pu120_p12pur	p12pur_addr.bit.b0	/* Port P12_0 pull-up */
#define		pu121_p12pur	p12pur_addr.bit.b1	/* Port P12_1 pull-up */
#define		pu122_p12pur	p12pur_addr.bit.b2	/* Port P12_2 pull-up */
#define		pu123_p12pur	p12pur_addr.bit.b3	/* Port P12_3 pull-up */
#define		pu124_p12pur	p12pur_addr.bit.b4	/* Port P12_4 pull-up */
#define		pu125_p12pur	p12pur_addr.bit.b5	/* Port P12_5 pull-up */
#define		pu126_p12pur	p12pur_addr.bit.b6	/* Port P12_6 pull-up */
#define		pu127_p12pur	p12pur_addr.bit.b7	/* Port P12_7 pull-up */

/*------------------------------------------------------
  Port P13 Pull-up control register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p13pur_addr@0x01ED;
#define		p13pur		p13pur_addr.byte

#define		pu130			p13pur_addr.bit.b0	/* Port P13_0 pull-up */
#define		pu131			p13pur_addr.bit.b1	/* Port P13_1 pull-up */
#define		pu132			p13pur_addr.bit.b2	/* Port P13_2 pull-up */
#define		pu133			p13pur_addr.bit.b3	/* Port P13_3 pull-up */
#define		pu130_p13pur	p13pur_addr.bit.b0	/* Port P13_0 pull-up */
#define		pu131_p13pur	p13pur_addr.bit.b1	/* Port P13_1 pull-up */
#define		pu132_p13pur	p13pur_addr.bit.b2	/* Port P13_2 pull-up */
#define		pu133_p13pur	p13pur_addr.bit.b3	/* Port P13_3 pull-up */

/*------------------------------------------------------
  Port P10 Drive Capacity Control Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p10drr_addr@0x01F0;
#define		p10drr		p10drr_addr.byte

#define		p10drr0			p10drr_addr.bit.b0	/* P10_0 drive capacity */
#define		p10drr1			p10drr_addr.bit.b1	/* P10_1 drive capacity */
#define		p10drr2			p10drr_addr.bit.b2	/* P10_2 drive capacity */
#define		p10drr3			p10drr_addr.bit.b3	/* P10_3 drive capacity */
#define		p10drr4			p10drr_addr.bit.b4	/* P10_4 drive capacity */
#define		p10drr5			p10drr_addr.bit.b5	/* P10_5 drive capacity */
#define		p10drr6			p10drr_addr.bit.b6	/* P10_6 drive capacity */
#define		p10drr7			p10drr_addr.bit.b7	/* P10_7 drive capacity */
#define		p10drr0_p10drr	p10drr_addr.bit.b0	/* P10_0 drive capacity */
#define		p10drr1_p10drr	p10drr_addr.bit.b1	/* P10_1 drive capacity */
#define		p10drr2_p10drr	p10drr_addr.bit.b2	/* P10_2 drive capacity */
#define		p10drr3_p10drr	p10drr_addr.bit.b3	/* P10_3 drive capacity */
#define		p10drr4_p10drr	p10drr_addr.bit.b4	/* P10_4 drive capacity */
#define		p10drr5_p10drr	p10drr_addr.bit.b5	/* P10_5 drive capacity */
#define		p10drr6_p10drr	p10drr_addr.bit.b6	/* P10_6 drive capacity */
#define		p10drr7_p10drr	p10drr_addr.bit.b7	/* P10_7 drive capacity */

/*------------------------------------------------------
  Port P11 Drive Capacity Control Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	p11drr_addr@0x01F1;
#define		p11drr		p11drr_addr.byte

#define		p11drr0			p11drr_addr.bit.b0	/* P11_0 drive capacity */
#define		p11drr1			p11drr_addr.bit.b1	/* P11_1 drive capacity */
#define		p11drr2			p11drr_addr.bit.b2	/* P11_2 drive capacity */
#define		p11drr3			p11drr_addr.bit.b3	/* P11_3 drive capacity */
#define		p11drr4			p11drr_addr.bit.b4	/* P11_4 drive capacity */
#define		p11drr5			p11drr_addr.bit.b5	/* P11_5 drive capacity */
#define		p11drr6			p11drr_addr.bit.b6	/* P11_6 drive capacity */
#define		p11drr7			p11drr_addr.bit.b7	/* P11_7 drive capacity */
#define		p11drr0_p11drr	p11drr_addr.bit.b0	/* P11_0 drive capacity */
#define		p11drr1_p11drr	p11drr_addr.bit.b1	/* P11_1 drive capacity */
#define		p11drr2_p11drr	p11drr_addr.bit.b2	/* P11_2 drive capacity */
#define		p11drr3_p11drr	p11drr_addr.bit.b3	/* P11_3 drive capacity */
#define		p11drr4_p11drr	p11drr_addr.bit.b4	/* P11_4 drive capacity */
#define		p11drr5_p11drr	p11drr_addr.bit.b5	/* P11_5 drive capacity */
#define		p11drr6_p11drr	p11drr_addr.bit.b6	/* P11_6 drive capacity */
#define		p11drr7_p11drr	p11drr_addr.bit.b7	/* P11_7 drive capacity */

/*------------------------------------------------------
  Input threshold control register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	vlt0_addr@0x01F5;
#define		vlt0		vlt0_addr.byte

#define		vlt00			vlt0_addr.bit.b0	/* P0 input level select bit */
#define		vlt01			vlt0_addr.bit.b1	/* P0 input level select bit */
#define		vlt02			vlt0_addr.bit.b2	/* P1 input level select bit */
#define		vlt03			vlt0_addr.bit.b3	/* P1 input level select bit */
#define		vlt04			vlt0_addr.bit.b4	/* P2 input level select bit */
#define		vlt05			vlt0_addr.bit.b5	/* P2 input level select bit */
#define		vlt06			vlt0_addr.bit.b6	/* P3 input level select bit */
#define		vlt07			vlt0_addr.bit.b7	/* P3 input level select bit */
#define		vlt00_vlt0		vlt0_addr.bit.b0	/* P0 input level select bit */
#define		vlt01_vlt0		vlt0_addr.bit.b1	/* P0 input level select bit */
#define		vlt02_vlt0		vlt0_addr.bit.b2	/* P1 input level select bit */
#define		vlt03_vlt0		vlt0_addr.bit.b3	/* P1 input level select bit */
#define		vlt04_vlt0		vlt0_addr.bit.b4	/* P2 input level select bit */
#define		vlt05_vlt0		vlt0_addr.bit.b5	/* P2 input level select bit */
#define		vlt06_vlt0		vlt0_addr.bit.b6	/* P3 input level select bit */
#define		vlt07_vlt0		vlt0_addr.bit.b7	/* P3 input level select bit */

/*------------------------------------------------------
  Input threshold control register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	vlt1_addr@0x01F6;
#define		vlt1		vlt1_addr.byte

#define		vlt10			vlt1_addr.bit.b0	/* P4 input level select bit */
#define		vlt11			vlt1_addr.bit.b1	/* P4 input level select bit */
#define		vlt16			vlt1_addr.bit.b6	/* P7 input level select bit */
#define		vlt17			vlt1_addr.bit.b7	/* P7 input level select bit */
#define		vlt10_vlt1		vlt1_addr.bit.b0	/* P4 input level select bit */
#define		vlt11_vlt1		vlt1_addr.bit.b1	/* P4 input level select bit */
#define		vlt16_vlt1		vlt1_addr.bit.b6	/* P7 input level select bit */
#define		vlt17_vlt1		vlt1_addr.bit.b7	/* P7 input level select bit */

/*------------------------------------------------------
  Input threshold control register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	vlt2_addr@0x01F7;
#define		vlt2		vlt2_addr.byte

#define		vlt22			vlt2_addr.bit.b2	/* P11 input level select bit */
#define		vlt23			vlt2_addr.bit.b3	/* P11 input level select bit */
#define		vlt24			vlt2_addr.bit.b4	/* P12_0 to P12_3 input level select bit */
#define		vlt25			vlt2_addr.bit.b5	/* P12_0 to P12_3 input level select bit */
#define		vlt26			vlt2_addr.bit.b6	/* P13 input level select bit */
#define		vlt27			vlt2_addr.bit.b7	/* P13 input level select bit */
#define		vlt22_vlt2		vlt2_addr.bit.b2	/* P11 input level select bit */
#define		vlt23_vlt2		vlt2_addr.bit.b3	/* P11 input level select bit */
#define		vlt24_vlt2		vlt2_addr.bit.b4	/* P12_0 to P12_3 input level select bit */
#define		vlt25_vlt2		vlt2_addr.bit.b5	/* P12_0 to P12_3 input level select bit */
#define		vlt26_vlt2		vlt2_addr.bit.b6	/* P13 input level select bit */
#define		vlt27_vlt2		vlt2_addr.bit.b7	/* P13 input level select bit */

/*------------------------------------------------------
  Comparator B Control Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	intcmp_addr@0x01F8;
#define		intcmp		intcmp_addr.byte

#define		int1cp0			intcmp_addr.bit.b0	/* Comparator B1 operation enable bit */
#define		int1cout		intcmp_addr.bit.b3	/* Comparator B1 monitor flag */
#define		int3cp0			intcmp_addr.bit.b4	/* Comparator B3 operation enable bit */
#define		int3cout		intcmp_addr.bit.b7	/* Comparator B3 monitor flag */
#define		int1cp0_intcmp	intcmp_addr.bit.b0	/* Comparator B1 operation enable bit */
#define		int1cout_intcmp	intcmp_addr.bit.b3	/* Comparator B1 monitor flag */
#define		int3cp0_intcmp	intcmp_addr.bit.b4	/* Comparator B3 operation enable bit */
#define		int3cout_intcmp	intcmp_addr.bit.b7	/* Comparator B3 monitor flag */

/*------------------------------------------------------
  External Input Enable Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	inten_addr@0x01FA;
#define		inten		inten_addr.byte

#define		int0en			inten_addr.bit.b0	/* INT0 input enable bit */
#define		int0pl			inten_addr.bit.b1	/* INT0 input polarity select bit */
#define		int1en			inten_addr.bit.b2	/* INT1 input enable bit */
#define		int1pl			inten_addr.bit.b3	/* INT1 input polarity select bit */
#define		int2en			inten_addr.bit.b4	/* INT2 input enable bit */
#define		int2pl			inten_addr.bit.b5	/* INT2 input polarity select bit */
#define		int3en			inten_addr.bit.b6	/* INT3 input enable bit */
#define		int3pl			inten_addr.bit.b7	/* INT3 input polarity select bit */
#define		int0en_inten	inten_addr.bit.b0	/* INT0 input enable bit */
#define		int0pl_inten	inten_addr.bit.b1	/* INT0 input polarity select bit */
#define		int1en_inten	inten_addr.bit.b2	/* INT1 input enable bit */
#define		int1pl_inten	inten_addr.bit.b3	/* INT1 input polarity select bit */
#define		int2en_inten	inten_addr.bit.b4	/* INT2 input enable bit */
#define		int2pl_inten	inten_addr.bit.b5	/* INT2 input polarity select bit */
#define		int3en_inten	inten_addr.bit.b6	/* INT3 input enable bit */
#define		int3pl_inten	inten_addr.bit.b7	/* INT3 input polarity select bit */

/*------------------------------------------------------
  External Input Enable Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	inten1_addr@0x01FB;
#define		inten1		inten1_addr.byte

#define		int4en			inten1_addr.bit.b0	/* INT4 input enable bit */
#define		int4pl			inten1_addr.bit.b1	/* INT4 input polarity select bit */
#define		int4en_inten1	inten1_addr.bit.b0	/* INT4 input enable bit */
#define		int4pl_inten1	inten1_addr.bit.b1	/* INT4 input polarity select bit */

/*------------------------------------------------------
  INT input filter select register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	intf_addr@0x01FC;
#define		intf		intf_addr.byte

#define		int0f0			intf_addr.bit.b0	/* INT0 input filter select bit */
#define		int0f1			intf_addr.bit.b1	/* INT0 input filter select bit */
#define		int1f0			intf_addr.bit.b2	/* INT1 input filter select bit */
#define		int1f1			intf_addr.bit.b3	/* INT1 input filter select bit */
#define		int2f0			intf_addr.bit.b4	/* INT2 input filter select bit */
#define		int2f1			intf_addr.bit.b5	/* INT2 input filter select bit */
#define		int3f0			intf_addr.bit.b6	/* INT3 input filter select bit */
#define		int3f1			intf_addr.bit.b7	/* INT3 input filter select bit */
#define		int0f0_intf		intf_addr.bit.b0	/* INT0 input filter select bit */
#define		int0f1_intf		intf_addr.bit.b1	/* INT0 input filter select bit */
#define		int1f0_intf		intf_addr.bit.b2	/* INT1 input filter select bit */
#define		int1f1_intf		intf_addr.bit.b3	/* INT1 input filter select bit */
#define		int2f0_intf		intf_addr.bit.b4	/* INT2 input filter select bit */
#define		int2f1_intf		intf_addr.bit.b5	/* INT2 input filter select bit */
#define		int3f0_intf		intf_addr.bit.b6	/* INT3 input filter select bit */
#define		int3f1_intf		intf_addr.bit.b7	/* INT3 input filter select bit */

/*------------------------------------------------------
  INT input filter select register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	intf1_addr@0x01FD;
#define		intf1		intf1_addr.byte

#define		int4f0			intf1_addr.bit.b0	/* INT4 input filter select bit */
#define		int4f1			intf1_addr.bit.b1	/* INT4 input filter select bit */
#define		int4f0_intf1	intf1_addr.bit.b0	/* INT4 input filter select bit */
#define		int4f1_intf1	intf1_addr.bit.b1	/* INT4 input filter select bit */

/*------------------------------------------------------
  Key input enable register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	kien_addr@0x01FE;
#define		kien		kien_addr.byte

#define		ki0en			kien_addr.bit.b0	/* KI0 input enable bit */
#define		ki0pl			kien_addr.bit.b1	/* KI0 input polarity select bit */
#define		ki1en			kien_addr.bit.b2	/* KI1 input enable bit */
#define		ki1pl			kien_addr.bit.b3	/* KI1 input polarity select bit */
#define		ki2en			kien_addr.bit.b4	/* KI2 input enable bit */
#define		ki2pl			kien_addr.bit.b5	/* KI2 input polarity select bit */
#define		ki3en			kien_addr.bit.b6	/* KI3 input enable bit */
#define		ki3pl			kien_addr.bit.b7	/* KI3 input polarity select bit */
#define		ki0en_kien		kien_addr.bit.b0	/* KI0 input enable bit */
#define		ki0pl_kien		kien_addr.bit.b1	/* KI0 input polarity select bit */
#define		ki1en_kien		kien_addr.bit.b2	/* KI1 input enable bit */
#define		ki1pl_kien		kien_addr.bit.b3	/* KI1 input polarity select bit */
#define		ki2en_kien		kien_addr.bit.b4	/* KI2 input enable bit */
#define		ki2pl_kien		kien_addr.bit.b5	/* KI2 input polarity select bit */
#define		ki3en_kien		kien_addr.bit.b6	/* KI3 input enable bit */
#define		ki3pl_kien		kien_addr.bit.b7	/* KI3 input polarity select bit */

/*------------------------------------------------------
  Key Input Enable Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	kien1_addr@0x01FF;
#define		kien1		kien1_addr.byte

#define		ki4en			kien1_addr.bit.b0	/* KI4 input enable bit */
#define		ki4pl			kien1_addr.bit.b1	/* KI4 input polarity select bit */
#define		ki5en			kien1_addr.bit.b2	/* KI5 input enable bit */
#define		ki5pl			kien1_addr.bit.b3	/* KI5 input polarity select bit */
#define		ki6en			kien1_addr.bit.b4	/* KI6 input enable bit */
#define		ki6pl			kien1_addr.bit.b5	/* KI6 input polarity select bit */
#define		ki7en			kien1_addr.bit.b6	/* KI7 input enable bit */
#define		ki7pl			kien1_addr.bit.b7	/* KI7 input polarity select bit */
#define		ki4en_kien1		kien1_addr.bit.b0	/* KI4 input enable bit */
#define		ki4pl_kien1		kien1_addr.bit.b1	/* KI4 input polarity select bit */
#define		ki5en_kien1		kien1_addr.bit.b2	/* KI5 input enable bit */
#define		ki5pl_kien1		kien1_addr.bit.b3	/* KI5 input polarity select bit */
#define		ki6en_kien1		kien1_addr.bit.b4	/* KI6 input enable bit */
#define		ki6pl_kien1		kien1_addr.bit.b5	/* KI6 input polarity select bit */
#define		ki7en_kien1		kien1_addr.bit.b6	/* KI7 input enable bit */
#define		ki7pl_kien1		kien1_addr.bit.b7	/* KI7 input polarity select bit */

/*------------------------------------------------------
  LCD Control Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	lcr0_addr@0x0200;
#define		lcr0		lcr0_addr.byte

#define		ldty0			lcr0_addr.bit.b0	/* Duty select bit */
#define		ldty1			lcr0_addr.bit.b1	/* Duty select bit */
#define		ldty2			lcr0_addr.bit.b2	/* Duty select bit */
#define		lwav			lcr0_addr.bit.b3	/* LCD waveform control select bit */
#define		lbas0			lcr0_addr.bit.b4	/* Bias select bit */
#define		lbas1			lcr0_addr.bit.b5	/* Bias select bit */
#define		ldspe			lcr0_addr.bit.b6	/* LCD display enable bit */
#define		lstat			lcr0_addr.bit.b7	/* LCD drive start bit */
#define		ldty0_lcr0		lcr0_addr.bit.b0	/* Duty select bit */
#define		ldty1_lcr0		lcr0_addr.bit.b1	/* Duty select bit */
#define		ldty2_lcr0		lcr0_addr.bit.b2	/* Duty select bit */
#define		lwav_lcr0		lcr0_addr.bit.b3	/* LCD waveform control select bit */
#define		lbas0_lcr0		lcr0_addr.bit.b4	/* Bias select bit */
#define		lbas1_lcr0		lcr0_addr.bit.b5	/* Bias select bit */
#define		ldspe_lcr0		lcr0_addr.bit.b6	/* LCD display enable bit */
#define		lstat_lcr0		lcr0_addr.bit.b7	/* LCD drive start bit */

/*------------------------------------------------------
  LCD Bias Control Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	lcr1_addr@0x0201;
#define		lcr1		lcr1_addr.byte

#define		lvls0			lcr1_addr.bit.b0	/* VL1 internally-generated voltage select bit */
#define		lvls1			lcr1_addr.bit.b1	/* VL1 internally-generated voltage select bit */
#define		lvls2			lcr1_addr.bit.b2	/* VL1 internally-generated voltage select bit */
#define		lvls3			lcr1_addr.bit.b3	/* VL1 internally-generated voltage select bit */
#define		lvwt0			lcr1_addr.bit.b4	/* Voltage multiplier wait time select bit */
#define		lvwt1			lcr1_addr.bit.b5	/* Voltage multiplier wait time select bit */
#define		lvurs			lcr1_addr.bit.b6	/* Voltage multiplier reference voltage source select bit */
#define		lvupe			lcr1_addr.bit.b7	/* Voltage multiplier enable bit */
#define		lvls0_lcr1		lcr1_addr.bit.b0	/* VL1 internally-generated voltage select bit */
#define		lvls1_lcr1		lcr1_addr.bit.b1	/* VL1 internally-generated voltage select bit */
#define		lvls2_lcr1		lcr1_addr.bit.b2	/* VL1 internally-generated voltage select bit */
#define		lvls3_lcr1		lcr1_addr.bit.b3	/* VL1 internally-generated voltage select bit */
#define		lvwt0_lcr1		lcr1_addr.bit.b4	/* Voltage multiplier wait time select bit */
#define		lvwt1_lcr1		lcr1_addr.bit.b5	/* Voltage multiplier wait time select bit */
#define		lvurs_lcr1		lcr1_addr.bit.b6	/* Voltage multiplier reference voltage source select bit */
#define		lvupe_lcr1		lcr1_addr.bit.b7	/* Voltage multiplier enable bit */

/*------------------------------------------------------
  LCD Display Control Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	lcr2_addr@0x0202;
#define		lcr2		lcr2_addr.byte

#define		ldfr0			lcr2_addr.bit.b0	/* LCD data display control interval select bit 1 */
#define		ldfr1			lcr2_addr.bit.b1	/* LCD data display control interval select bit 1 */
#define		ldfr2			lcr2_addr.bit.b2	/* LCD data display control interval select bit 1 */
#define		ldspc			lcr2_addr.bit.b3	/* LCD data display control enable bit */
#define		lrvrs			lcr2_addr.bit.b4	/* LCD display control mode select bit */
#define		ldfr20			lcr2_addr.bit.b5	/* LCD data display control interval select bit 2 */
#define		ldfr21			lcr2_addr.bit.b6	/* LCD data display control interval select bit 2 */
#define		ldfr0_lcr2		lcr2_addr.bit.b0	/* LCD data display control interval select bit 1 */
#define		ldfr1_lcr2		lcr2_addr.bit.b1	/* LCD data display control interval select bit 1 */
#define		ldfr2_lcr2		lcr2_addr.bit.b2	/* LCD data display control interval select bit 1 */
#define		ldspc_lcr2		lcr2_addr.bit.b3	/* LCD data display control enable bit */
#define		lrvrs_lcr2		lcr2_addr.bit.b4	/* LCD display control mode select bit */
#define		ldfr20_lcr2		lcr2_addr.bit.b5	/* LCD data display control interval select bit 2 */
#define		ldfr21_lcr2		lcr2_addr.bit.b6	/* LCD data display control interval select bit 2 */

/*------------------------------------------------------
  LCD Clock Control Register
------------------------------------------------------*/
__no_init  volatile union	byte_def	lcr3_addr@0x0203;
#define		lcr3		lcr3_addr.byte

#define		lpsc0			lcr3_addr.bit.b0	/* Division ratio select bit */
#define		lpsc1			lcr3_addr.bit.b1	/* Division ratio select bit */
#define		lpsc2			lcr3_addr.bit.b2	/* Division ratio select bit */
#define		lcks0			lcr3_addr.bit.b6	/* LCD clock source select bit */
#define		lcks1			lcr3_addr.bit.b7	/* LCD clock source select bit */
#define		lpsc0_lcr3		lcr3_addr.bit.b0	/* Division ratio select bit */
#define		lpsc1_lcr3		lcr3_addr.bit.b1	/* Division ratio select bit */
#define		lpsc2_lcr3		lcr3_addr.bit.b2	/* Division ratio select bit */
#define		lcks0_lcr3		lcr3_addr.bit.b6	/* LCD clock source select bit */
#define		lcks1_lcr3		lcr3_addr.bit.b7	/* LCD clock source select bit */

/*------------------------------------------------------
  LCD Port Select Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	lse0_addr@0x0206;
#define		lse0		lse0_addr.byte

#define		lse00			lse0_addr.bit.b0	/* LCD port select bit 0 */
#define		lse01			lse0_addr.bit.b1	/* LCD port select bit 1 */
#define		lse02			lse0_addr.bit.b2	/* LCD port select bit 2 */
#define		lse03			lse0_addr.bit.b3	/* LCD port select bit 3 */
#define		lse04			lse0_addr.bit.b4	/* LCD port select bit 4 */
#define		lse05			lse0_addr.bit.b5	/* LCD port select bit 5 */
#define		lse06			lse0_addr.bit.b6	/* LCD port select bit 6 */
#define		lse07			lse0_addr.bit.b7	/* LCD port select bit 7 */
#define		lse00_lse0		lse0_addr.bit.b0	/* LCD port select bit 0 */
#define		lse01_lse0		lse0_addr.bit.b1	/* LCD port select bit 1 */
#define		lse02_lse0		lse0_addr.bit.b2	/* LCD port select bit 2 */
#define		lse03_lse0		lse0_addr.bit.b3	/* LCD port select bit 3 */
#define		lse04_lse0		lse0_addr.bit.b4	/* LCD port select bit 4 */
#define		lse05_lse0		lse0_addr.bit.b5	/* LCD port select bit 5 */
#define		lse06_lse0		lse0_addr.bit.b6	/* LCD port select bit 6 */
#define		lse07_lse0		lse0_addr.bit.b7	/* LCD port select bit 7 */

/*------------------------------------------------------
  LCD Port Select Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	lse1_addr@0x0207;
#define		lse1		lse1_addr.byte

#define		lse08			lse1_addr.bit.b0	/* LCD port select bit 8 */
#define		lse09			lse1_addr.bit.b1	/* LCD port select bit 9 */
#define		lse10			lse1_addr.bit.b2	/* LCD port select bit 10 */
#define		lse11			lse1_addr.bit.b3	/* LCD port select bit 11 */
#define		lse12			lse1_addr.bit.b4	/* LCD port select bit 12 */
#define		lse13			lse1_addr.bit.b5	/* LCD port select bit 13 */
#define		lse14			lse1_addr.bit.b6	/* LCD port select bit 14 */
#define		lse15			lse1_addr.bit.b7	/* LCD port select bit 15 */
#define		lse08_lse1		lse1_addr.bit.b0	/* LCD port select bit 8 */
#define		lse09_lse1		lse1_addr.bit.b1	/* LCD port select bit 9 */
#define		lse10_lse1		lse1_addr.bit.b2	/* LCD port select bit 10 */
#define		lse11_lse1		lse1_addr.bit.b3	/* LCD port select bit 11 */
#define		lse12_lse1		lse1_addr.bit.b4	/* LCD port select bit 12 */
#define		lse13_lse1		lse1_addr.bit.b5	/* LCD port select bit 13 */
#define		lse14_lse1		lse1_addr.bit.b6	/* LCD port select bit 14 */
#define		lse15_lse1		lse1_addr.bit.b7	/* LCD port select bit 15 */

/*------------------------------------------------------
  LCD Port Select Register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	lse2_addr@0x0208;
#define		lse2		lse2_addr.byte

#define		lse16			lse2_addr.bit.b0	/* LCD port select bit 16 */
#define		lse17			lse2_addr.bit.b1	/* LCD port select bit 17 */
#define		lse18			lse2_addr.bit.b2	/* LCD port select bit 18 */
#define		lse19			lse2_addr.bit.b3	/* LCD port select bit 19 */
#define		lse20			lse2_addr.bit.b4	/* LCD port select bit 20 */
#define		lse21			lse2_addr.bit.b5	/* LCD port select bit 21 */
#define		lse22			lse2_addr.bit.b6	/* LCD port select bit 22 */
#define		lse23			lse2_addr.bit.b7	/* LCD port select bit 23 */
#define		lse16_lse2		lse2_addr.bit.b0	/* LCD port select bit 16 */
#define		lse17_lse2		lse2_addr.bit.b1	/* LCD port select bit 17 */
#define		lse18_lse2		lse2_addr.bit.b2	/* LCD port select bit 18 */
#define		lse19_lse2		lse2_addr.bit.b3	/* LCD port select bit 19 */
#define		lse20_lse2		lse2_addr.bit.b4	/* LCD port select bit 20 */
#define		lse21_lse2		lse2_addr.bit.b5	/* LCD port select bit 21 */
#define		lse22_lse2		lse2_addr.bit.b6	/* LCD port select bit 22 */
#define		lse23_lse2		lse2_addr.bit.b7	/* LCD port select bit 23 */

/*------------------------------------------------------
  LCD Port Select Register 3
------------------------------------------------------*/
__no_init  volatile union	byte_def	lse3_addr@0x0209;
#define		lse3		lse3_addr.byte

#define		lse24			lse3_addr.bit.b0	/* LCD port select bit 24 */
#define		lse25			lse3_addr.bit.b1	/* LCD port select bit 25 */
#define		lse26			lse3_addr.bit.b2	/* LCD port select bit 26 */
#define		lse27			lse3_addr.bit.b3	/* LCD port select bit 27 */
#define		lse28			lse3_addr.bit.b4	/* LCD port select bit 28 */
#define		lse29			lse3_addr.bit.b5	/* LCD port select bit 29 */
#define		lse30			lse3_addr.bit.b6	/* LCD port select bit 30 */
#define		lse31			lse3_addr.bit.b7	/* LCD port select bit 31 */
#define		lse24_lse3		lse3_addr.bit.b0	/* LCD port select bit 24 */
#define		lse25_lse3		lse3_addr.bit.b1	/* LCD port select bit 25 */
#define		lse26_lse3		lse3_addr.bit.b2	/* LCD port select bit 26 */
#define		lse27_lse3		lse3_addr.bit.b3	/* LCD port select bit 27 */
#define		lse28_lse3		lse3_addr.bit.b4	/* LCD port select bit 28 */
#define		lse29_lse3		lse3_addr.bit.b5	/* LCD port select bit 29 */
#define		lse30_lse3		lse3_addr.bit.b6	/* LCD port select bit 30 */
#define		lse31_lse3		lse3_addr.bit.b7	/* LCD port select bit 31 */

/*------------------------------------------------------
  LCD Port Select Register 4
------------------------------------------------------*/
__no_init  volatile union	byte_def	lse4_addr@0x020A;
#define		lse4		lse4_addr.byte

#define		lse32			lse4_addr.bit.b0	/* LCD port select bit 32 */
#define		lse33			lse4_addr.bit.b1	/* LCD port select bit 33 */
#define		lse34			lse4_addr.bit.b2	/* LCD port select bit 34 */
#define		lse35			lse4_addr.bit.b3	/* LCD port select bit 35 */
#define		lse36			lse4_addr.bit.b4	/* LCD port select bit 36 */
#define		lse37			lse4_addr.bit.b5	/* LCD port select bit 37 */
#define		lse38			lse4_addr.bit.b6	/* LCD port select bit 38 */
#define		lse39			lse4_addr.bit.b7	/* LCD port select bit 39 */
#define		lse32_lse4		lse4_addr.bit.b0	/* LCD port select bit 32 */
#define		lse33_lse4		lse4_addr.bit.b1	/* LCD port select bit 33 */
#define		lse34_lse4		lse4_addr.bit.b2	/* LCD port select bit 34 */
#define		lse35_lse4		lse4_addr.bit.b3	/* LCD port select bit 35 */
#define		lse36_lse4		lse4_addr.bit.b4	/* LCD port select bit 36 */
#define		lse37_lse4		lse4_addr.bit.b5	/* LCD port select bit 37 */
#define		lse38_lse4		lse4_addr.bit.b6	/* LCD port select bit 38 */
#define		lse39_lse4		lse4_addr.bit.b7	/* LCD port select bit 39 */

/*------------------------------------------------------
  LCD Port Select Register 5
------------------------------------------------------*/
__no_init  volatile union	byte_def	lse5_addr@0x020B;
#define		lse5		lse5_addr.byte

#define		lse40			lse5_addr.bit.b0	/* LCD port select bit 40 */
#define		lse41			lse5_addr.bit.b1	/* LCD port select bit 41 */
#define		lse42			lse5_addr.bit.b2	/* LCD port select bit 42 */
#define		lse43			lse5_addr.bit.b3	/* LCD port select bit 43 */
#define		lse44			lse5_addr.bit.b4	/* LCD port select bit 44 */
#define		lse45			lse5_addr.bit.b5	/* LCD port select bit 45 */
#define		lse46			lse5_addr.bit.b6	/* LCD port select bit 46 */
#define		lse47			lse5_addr.bit.b7	/* LCD port select bit 47 */
#define		lse40_lse5		lse5_addr.bit.b0	/* LCD port select bit 40 */
#define		lse41_lse5		lse5_addr.bit.b1	/* LCD port select bit 41 */
#define		lse42_lse5		lse5_addr.bit.b2	/* LCD port select bit 42 */
#define		lse43_lse5		lse5_addr.bit.b3	/* LCD port select bit 43 */
#define		lse44_lse5		lse5_addr.bit.b4	/* LCD port select bit 44 */
#define		lse45_lse5		lse5_addr.bit.b5	/* LCD port select bit 45 */
#define		lse46_lse5		lse5_addr.bit.b6	/* LCD port select bit 46 */
#define		lse47_lse5		lse5_addr.bit.b7	/* LCD port select bit 47 */

/*------------------------------------------------------
  LCD Port Select Register 6
------------------------------------------------------*/
__no_init  volatile union	byte_def	lse6_addr@0x020C;
#define		lse6		lse6_addr.byte

#define		lse48			lse6_addr.bit.b0	/* LCD port select bit 48 */
#define		lse49			lse6_addr.bit.b1	/* LCD port select bit 49 */
#define		lse50			lse6_addr.bit.b2	/* LCD port select bit 50 */
#define		lse51			lse6_addr.bit.b3	/* LCD port select bit 51 */
#define		lse52			lse6_addr.bit.b4	/* LCD port select bit 52 */
#define		lse53			lse6_addr.bit.b5	/* LCD port select bit 53 */
#define		lse54			lse6_addr.bit.b6	/* LCD port select bit 54 */
#define		lse55			lse6_addr.bit.b7	/* LCD port select bit 55 */
#define		lse48_lse6		lse6_addr.bit.b0	/* LCD port select bit 48 */
#define		lse49_lse6		lse6_addr.bit.b1	/* LCD port select bit 49 */
#define		lse50_lse6		lse6_addr.bit.b2	/* LCD port select bit 50 */
#define		lse51_lse6		lse6_addr.bit.b3	/* LCD port select bit 51 */
#define		lse52_lse6		lse6_addr.bit.b4	/* LCD port select bit 52 */
#define		lse53_lse6		lse6_addr.bit.b5	/* LCD port select bit 53 */
#define		lse54_lse6		lse6_addr.bit.b6	/* LCD port select bit 54 */
#define		lse55_lse6		lse6_addr.bit.b7	/* LCD port select bit 55 */

/*------------------------------------------------------
  LCD Port Select Register 7
------------------------------------------------------*/
__no_init  volatile union	byte_def	lse7_addr@0x020D;
#define		lse7		lse7_addr.byte

#define		lse56			lse7_addr.bit.b0	/* LCD port select bit 56 */
#define		lse57			lse7_addr.bit.b1	/* LCD port select bit 57 */
#define		lse58			lse7_addr.bit.b2	/* LCD port select bit 58 */
#define		lse59			lse7_addr.bit.b3	/* LCD port select bit 59 */
#define		lse60			lse7_addr.bit.b4	/* LCD port select bit 60 */
#define		lse56_lse7		lse7_addr.bit.b0	/* LCD port select bit 56 */
#define		lse57_lse7		lse7_addr.bit.b1	/* LCD port select bit 57 */
#define		lse58_lse7		lse7_addr.bit.b2	/* LCD port select bit 58 */
#define		lse59_lse7		lse7_addr.bit.b3	/* LCD port select bit 59 */
#define		lse60_lse7		lse7_addr.bit.b4	/* LCD port select bit 60 */

/*------------------------------------------------------
  LCD Display Data Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra0l_addr@0x0210;
#define		lra0l		lra0l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra1l_addr@0x0211;
#define		lra1l		lra1l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra2l_addr@0x0212;
#define		lra2l		lra2l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 3
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra3l_addr@0x0213;
#define		lra3l		lra3l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 4
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra4l_addr@0x0214;
#define		lra4l		lra4l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 5
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra5l_addr@0x0215;
#define		lra5l		lra5l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 6
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra6l_addr@0x0216;
#define		lra6l		lra6l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 7
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra7l_addr@0x0217;
#define		lra7l		lra7l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 8
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra8l_addr@0x0218;
#define		lra8l		lra8l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 9
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra9l_addr@0x0219;
#define		lra9l		lra9l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 10
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra10l_addr@0x021A;
#define		lra10l		lra10l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 11
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra11l_addr@0x021B;
#define		lra11l		lra11l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 12
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra12l_addr@0x021C;
#define		lra12l		lra12l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 13
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra13l_addr@0x021D;
#define		lra13l		lra13l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 14
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra14l_addr@0x021E;
#define		lra14l		lra14l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 15
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra15l_addr@0x021F;
#define		lra15l		lra15l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 16
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra16l_addr@0x0220;
#define		lra16l		lra16l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 17
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra17l_addr@0x0221;
#define		lra17l		lra17l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 18
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra18l_addr@0x0222;
#define		lra18l		lra18l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 19
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra19l_addr@0x0223;
#define		lra19l		lra19l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 20
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra20l_addr@0x0224;
#define		lra20l		lra20l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 21
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra21l_addr@0x0225;
#define		lra21l		lra21l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 22
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra22l_addr@0x0226;
#define		lra22l		lra22l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 23
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra23l_addr@0x0227;
#define		lra23l		lra23l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 24
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra24l_addr@0x0228;
#define		lra24l		lra24l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 25
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra25l_addr@0x0229;
#define		lra25l		lra25l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 26
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra26l_addr@0x022A;
#define		lra26l		lra26l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 27
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra27l_addr@0x022B;
#define		lra27l		lra27l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 28
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra28l_addr@0x022C;
#define		lra28l		lra28l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 29
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra29l_addr@0x022D;
#define		lra29l		lra29l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 30
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra30l_addr@0x022E;
#define		lra30l		lra30l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 31
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra31l_addr@0x022F;
#define		lra31l		lra31l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 32
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra32l_addr@0x0230;
#define		lra32l		lra32l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 33
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra33l_addr@0x0231;
#define		lra33l		lra33l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 34
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra34l_addr@0x0232;
#define		lra34l		lra34l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 35
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra35l_addr@0x0233;
#define		lra35l		lra35l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 36
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra36l_addr@0x0234;
#define		lra36l		lra36l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 37
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra37l_addr@0x0235;
#define		lra37l		lra37l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 38
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra38l_addr@0x0236;
#define		lra38l		lra38l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 39
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra39l_addr@0x0237;
#define		lra39l		lra39l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 40
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra40l_addr@0x0238;
#define		lra40l		lra40l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 41
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra41l_addr@0x0239;
#define		lra41l		lra41l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 42
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra42l_addr@0x023A;
#define		lra42l		lra42l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 43
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra43l_addr@0x023B;
#define		lra43l		lra43l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 44
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra44l_addr@0x023C;
#define		lra44l		lra44l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 45
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra45l_addr@0x023D;
#define		lra45l		lra45l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 46
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra46l_addr@0x023E;
#define		lra46l		lra46l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 47
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra47l_addr@0x023F;
#define		lra47l		lra47l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 48
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra48l_addr@0x0240;
#define		lra48l		lra48l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 49
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra49l_addr@0x0241;
#define		lra49l		lra49l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 50
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra50l_addr@0x0242;
#define		lra50l		lra50l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 51
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra51l_addr@0x0243;
#define		lra51l		lra51l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 52
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra52l_addr@0x0244;
#define		lra52l		lra52l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 53
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra53l_addr@0x0245;
#define		lra53l		lra53l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 54
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra54l_addr@0x0246;
#define		lra54l		lra54l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 55
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra55l_addr@0x0247;
#define		lra55l		lra55l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 56
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra56l_addr@0x0248;
#define		lra56l		lra56l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 57
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra57l_addr@0x0249;
#define		lra57l		lra57l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 58
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra58l_addr@0x024A;
#define		lra58l		lra58l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 59
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra59l_addr@0x024B;
#define		lra59l		lra59l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 60
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra60l_addr@0x024C;
#define		lra60l		lra60l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 61
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra61l_addr@0x024D;
#define		lra61l		lra61l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 62
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra62l_addr@0x024E;
#define		lra62l		lra62l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 63
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra63l_addr@0x024F;
#define		lra63l		lra63l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 64
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra64l_addr@0x0250;
#define		lra64l		lra64l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 65
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra65l_addr@0x0251;
#define		lra65l		lra65l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 66
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra66l_addr@0x0252;
#define		lra66l		lra66l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 67
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra67l_addr@0x0253;
#define		lra67l		lra67l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 68
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra68l_addr@0x0254;
#define		lra68l		lra68l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 69
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra69l_addr@0x0255;
#define		lra69l		lra69l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 70
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra70l_addr@0x0256;
#define		lra70l		lra70l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 71
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra71l_addr@0x0257;
#define		lra71l		lra71l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 72
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra72l_addr@0x0258;
#define		lra72l		lra72l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 73
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra73l_addr@0x0259;
#define		lra73l		lra73l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 74
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra74l_addr@0x025A;
#define		lra74l		lra74l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 75
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra75l_addr@0x025B;
#define		lra75l		lra75l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 76
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra76l_addr@0x025C;
#define		lra76l		lra76l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 77
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra77l_addr@0x025D;
#define		lra77l		lra77l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 78
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra78l_addr@0x025E;
#define		lra78l		lra78l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 79
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra79l_addr@0x025F;
#define		lra79l		lra79l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 80
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra80l_addr@0x0260;
#define		lra80l		lra80l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 81
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra81l_addr@0x0261;
#define		lra81l		lra81l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 82
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra82l_addr@0x0262;
#define		lra82l		lra82l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 83
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra83l_addr@0x0263;
#define		lra83l		lra83l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 84
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra84l_addr@0x0264;
#define		lra84l		lra84l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 85
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra85l_addr@0x0265;
#define		lra85l		lra85l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 86
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra86l_addr@0x0266;
#define		lra86l		lra86l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 87
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra87l_addr@0x0267;
#define		lra87l		lra87l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 88
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra88l_addr@0x0268;
#define		lra88l		lra88l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 89
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra89l_addr@0x0269;
#define		lra89l		lra89l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 90
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra90l_addr@0x026A;
#define		lra90l		lra90l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 91
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra91l_addr@0x026B;
#define		lra91l		lra91l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 92
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra92l_addr@0x026C;
#define		lra92l		lra92l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 93
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra93l_addr@0x026D;
#define		lra93l		lra93l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 94
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra94l_addr@0x026E;
#define		lra94l		lra94l_addr.byte

/*------------------------------------------------------
  LCD Display Data Register 95
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra95l_addr@0x026F;
#define		lra95l		lra95l_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra0h_addr@0x0270;
#define		lra0h		lra0h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra1h_addr@0x0271;
#define		lra1h		lra1h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra2h_addr@0x0272;
#define		lra2h		lra2h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 3
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra3h_addr@0x0273;
#define		lra3h		lra3h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 4
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra4h_addr@0x0274;
#define		lra4h		lra4h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 5
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra5h_addr@0x0275;
#define		lra5h		lra5h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 6
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra6h_addr@0x0276;
#define		lra6h		lra6h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 7
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra7h_addr@0x0277;
#define		lra7h		lra7h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 8
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra8h_addr@0x0278;
#define		lra8h		lra8h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 9
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra9h_addr@0x0279;
#define		lra9h		lra9h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 10
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra10h_addr@0x027A;
#define		lra10h		lra10h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 11
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra11h_addr@0x027B;
#define		lra11h		lra11h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 12
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra12h_addr@0x027C;
#define		lra12h		lra12h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 13
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra13h_addr@0x027D;
#define		lra13h		lra13h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 14
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra14h_addr@0x027E;
#define		lra14h		lra14h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 15
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra15h_addr@0x027F;
#define		lra15h		lra15h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 16
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra16h_addr@0x0280;
#define		lra16h		lra16h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 17
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra17h_addr@0x0281;
#define		lra17h		lra17h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 18
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra18h_addr@0x0282;
#define		lra18h		lra18h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 19
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra19h_addr@0x0283;
#define		lra19h		lra19h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 20
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra20h_addr@0x0284;
#define		lra20h		lra20h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 21
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra21h_addr@0x0285;
#define		lra21h		lra21h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 22
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra22h_addr@0x0286;
#define		lra22h		lra22h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 23
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra23h_addr@0x0287;
#define		lra23h		lra23h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 24
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra24h_addr@0x0288;
#define		lra24h		lra24h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 25
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra25h_addr@0x0289;
#define		lra25h		lra25h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 26
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra26h_addr@0x028A;
#define		lra26h		lra26h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 27
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra27h_addr@0x028B;
#define		lra27h		lra27h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 28
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra28h_addr@0x028C;
#define		lra28h		lra28h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 29
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra29h_addr@0x028D;
#define		lra29h		lra29h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 30
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra30h_addr@0x028E;
#define		lra30h		lra30h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 31
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra31h_addr@0x028F;
#define		lra31h		lra31h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 32
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra32h_addr@0x0290;
#define		lra32h		lra32h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 33
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra33h_addr@0x0291;
#define		lra33h		lra33h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 34
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra34h_addr@0x0292;
#define		lra34h		lra34h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 35
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra35h_addr@0x0293;
#define		lra35h		lra35h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 36
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra36h_addr@0x0294;
#define		lra36h		lra36h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 37
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra37h_addr@0x0295;
#define		lra37h		lra37h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 38
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra38h_addr@0x0296;
#define		lra38h		lra38h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 39
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra39h_addr@0x0297;
#define		lra39h		lra39h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 40
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra40h_addr@0x0298;
#define		lra40h		lra40h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 41
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra41h_addr@0x0299;
#define		lra41h		lra41h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 42
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra42h_addr@0x029A;
#define		lra42h		lra42h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 43
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra43h_addr@0x029B;
#define		lra43h		lra43h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 44
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra44h_addr@0x029C;
#define		lra44h		lra44h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 45
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra45h_addr@0x029D;
#define		lra45h		lra45h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 46
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra46h_addr@0x029E;
#define		lra46h		lra46h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 47
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra47h_addr@0x029F;
#define		lra47h		lra47h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 48
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra48h_addr@0x02A0;
#define		lra48h		lra48h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 49
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra49h_addr@0x02A1;
#define		lra49h		lra49h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 50
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra50h_addr@0x02A2;
#define		lra50h		lra50h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 51
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra51h_addr@0x02A3;
#define		lra51h		lra51h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 52
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra52h_addr@0x02A4;
#define		lra52h		lra52h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 53
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra53h_addr@0x02A5;
#define		lra53h		lra53h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 54
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra54h_addr@0x02A6;
#define		lra54h		lra54h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 55
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra55h_addr@0x02A7;
#define		lra55h		lra55h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 56
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra56h_addr@0x02A8;
#define		lra56h		lra56h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 57
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra57h_addr@0x02A9;
#define		lra57h		lra57h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 58
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra58h_addr@0x02AA;
#define		lra58h		lra58h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 59
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra59h_addr@0x02AB;
#define		lra59h		lra59h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 60
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra60h_addr@0x02AC;
#define		lra60h		lra60h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 61
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra61h_addr@0x02AD;
#define		lra61h		lra61h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 62
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra62h_addr@0x02AE;
#define		lra62h		lra62h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 63
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra63h_addr@0x02AF;
#define		lra63h		lra63h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 64
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra64h_addr@0x02B0;
#define		lra64h		lra64h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 65
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra65h_addr@0x02B1;
#define		lra65h		lra65h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 66
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra66h_addr@0x02B2;
#define		lra66h		lra66h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 67
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra67h_addr@0x02B3;
#define		lra67h		lra67h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 68
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra68h_addr@0x02B4;
#define		lra68h		lra68h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 69
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra69h_addr@0x02B5;
#define		lra69h		lra69h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 70
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra70h_addr@0x02B6;
#define		lra70h		lra70h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 71
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra71h_addr@0x02B7;
#define		lra71h		lra71h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 72
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra72h_addr@0x02B8;
#define		lra72h		lra72h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 73
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra73h_addr@0x02B9;
#define		lra73h		lra73h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 74
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra74h_addr@0x02BA;
#define		lra74h		lra74h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 75
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra75h_addr@0x02BB;
#define		lra75h		lra75h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 76
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra76h_addr@0x02BC;
#define		lra76h		lra76h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 77
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra77h_addr@0x02BD;
#define		lra77h		lra77h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 78
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra78h_addr@0x02BE;
#define		lra78h		lra78h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 79
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra79h_addr@0x02BF;
#define		lra79h		lra79h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 80
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra80h_addr@0x02C0;
#define		lra80h		lra80h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 81
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra81h_addr@0x02C1;
#define		lra81h		lra81h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 82
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra82h_addr@0x02C2;
#define		lra82h		lra82h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 83
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra83h_addr@0x02C3;
#define		lra83h		lra83h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 84
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra84h_addr@0x02C4;
#define		lra84h		lra84h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 85
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra85h_addr@0x02C5;
#define		lra85h		lra85h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 86
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra86h_addr@0x02C6;
#define		lra86h		lra86h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 87
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra87h_addr@0x02C7;
#define		lra87h		lra87h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 88
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra88h_addr@0x02C8;
#define		lra88h		lra88h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 89
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra89h_addr@0x02C9;
#define		lra89h		lra89h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 90
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra90h_addr@0x02CA;
#define		lra90h		lra90h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 91
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra91h_addr@0x02CB;
#define		lra91h		lra91h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 92
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra92h_addr@0x02CC;
#define		lra92h		lra92h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 93
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra93h_addr@0x02CD;
#define		lra93h		lra93h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 94
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra94h_addr@0x02CE;
#define		lra94h		lra94h_addr.byte

/*------------------------------------------------------
  LCD Display Control Data Register 95
------------------------------------------------------*/
__no_init  volatile union	byte_def	lra95h_addr@0x02CF;
#define		lra95h		lra95h_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area0 (INT0)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct0_addr@0x2C00;
#define		dtcvct0		dtcvct0_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area1 (INT1)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct1_addr@0x2C01;
#define		dtcvct1		dtcvct1_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area2 (INT2)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct2_addr@0x2C02;
#define		dtcvct2		dtcvct2_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area3 (INT3)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct3_addr@0x2C03;
#define		dtcvct3		dtcvct3_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area4 (INT4)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct4_addr@0x2C04;
#define		dtcvct4		dtcvct4_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area5 (INT5)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct5_addr@0x2C05;
#define		dtcvct5		dtcvct5_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area6 (INT6)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct6_addr@0x2C06;
#define		dtcvct6		dtcvct6_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area7 (INT7)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct7_addr@0x2C07;
#define		dtcvct7		dtcvct7_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area8 (Key Input)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct8_addr@0x2C08;
#define		dtcvct8		dtcvct8_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area9 (A/D conversion)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct9_addr@0x2C09;
#define		dtcvct9		dtcvct9_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area10 (UART0 reception)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct10_addr@0x2C0A;
#define		dtcvct10	dtcvct10_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area11 (UART0 transmission)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct11_addr@0x2C0B;
#define		dtcvct11	dtcvct11_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area12 (UART1 reception)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct12_addr@0x2C0C;
#define		dtcvct12	dtcvct12_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area13 (UART1 transmission)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct13_addr@0x2C0D;
#define		dtcvct13	dtcvct13_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area14 (UART2 reception)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct14_addr@0x2C0E;
#define		dtcvct14	dtcvct14_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area15 (UART2 transmission)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct15_addr@0x2C0F;
#define		dtcvct15	dtcvct15_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area16 (SSU/I2C Receive data full)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct16_addr@0x2C10;
#define		dtcvct16	dtcvct16_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area17 (SSU/I2C Transmit data empty)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct17_addr@0x2C11;
#define		dtcvct17	dtcvct17_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area18 (Voltage monitor 2)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct18_addr@0x2C12;
#define		dtcvct18	dtcvct18_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area19 (Voltage monitor 1)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct19_addr@0x2C13;
#define		dtcvct19	dtcvct19_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area20
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct20_addr@0x2C14;
#define		dtcvct20	dtcvct20_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area21
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct21_addr@0x2C15;
#define		dtcvct21	dtcvct21_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area22 (TRC Input-capture/compare-match A)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct22_addr@0x2C16;
#define		dtcvct22	dtcvct22_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area23 (TRC Input-capture/compare-match B)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct23_addr@0x2C17;
#define		dtcvct23	dtcvct23_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area24 (TRC Input-capture/compare-match C)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct24_addr@0x2C18;
#define		dtcvct24	dtcvct24_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area25 (TRC Input-capture/compare-match D)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct25_addr@0x2C19;
#define		dtcvct25	dtcvct25_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area26 (TRD0 Input-capture/compare-match A)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct26_addr@0x2C1A;
#define		dtcvct26	dtcvct26_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area27 (TRD0 Input-capture/compare-match B)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct27_addr@0x2C1B;
#define		dtcvct27	dtcvct27_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area28 (TRD0 Input-capture/compare-match C)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct28_addr@0x2C1C;
#define		dtcvct28	dtcvct28_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area29 (TRD0 Input-capture/compare-match D)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct29_addr@0x2C1D;
#define		dtcvct29	dtcvct29_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area30 (TRD1 Input-capture/compare-match A)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct30_addr@0x2C1E;
#define		dtcvct30	dtcvct30_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area31 (TRD1 Input-capture/compare-match B)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct31_addr@0x2C1F;
#define		dtcvct31	dtcvct31_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area32 (TRD1 Input-capture/compare-match C)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct32_addr@0x2C20;
#define		dtcvct32	dtcvct32_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area33 (TRD1 Input-capture/compare-match D)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct33_addr@0x2C21;
#define		dtcvct33	dtcvct33_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area34
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct34_addr@0x2C22;
#define		dtcvct34	dtcvct34_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area35
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct35_addr@0x2C23;
#define		dtcvct35	dtcvct35_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area36
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct36_addr@0x2C24;
#define		dtcvct36	dtcvct36_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area37
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct37_addr@0x2C25;
#define		dtcvct37	dtcvct37_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area38
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct38_addr@0x2C26;
#define		dtcvct38	dtcvct38_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area39
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct39_addr@0x2C27;
#define		dtcvct39	dtcvct39_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area40
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct40_addr@0x2C28;
#define		dtcvct40	dtcvct40_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area41
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct41_addr@0x2C29;
#define		dtcvct41	dtcvct41_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area42 (TRE)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct42_addr@0x2C2A;
#define		dtcvct42	dtcvct42_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area43
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct43_addr@0x2C2B;
#define		dtcvct43	dtcvct43_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area44
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct44_addr@0x2C2C;
#define		dtcvct44	dtcvct44_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area45
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct45_addr@0x2C2D;
#define		dtcvct45	dtcvct45_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area46
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct46_addr@0x2C2E;
#define		dtcvct46	dtcvct46_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area47 (TRG Input-capture/compare-match A)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct47_addr@0x2C2F;
#define		dtcvct47	dtcvct47_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area48 (TRG Input-capture/compare-match B)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct48_addr@0x2C30;
#define		dtcvct48	dtcvct48_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area49 (TRA)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct49_addr@0x2C31;
#define		dtcvct49	dtcvct49_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area50
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct50_addr@0x2C32;
#define		dtcvct50	dtcvct50_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area51 (TRB)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct51_addr@0x2C33;
#define		dtcvct51	dtcvct51_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area52 (Flash memory ready)
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct52_addr@0x2C34;
#define		dtcvct52	dtcvct52_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area53
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct53_addr@0x2C35;
#define		dtcvct53	dtcvct53_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area54
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct54_addr@0x2C36;
#define		dtcvct54	dtcvct54_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area55
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct55_addr@0x2C37;
#define		dtcvct55	dtcvct55_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area56
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct56_addr@0x2C38;
#define		dtcvct56	dtcvct56_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area57
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct57_addr@0x2C39;
#define		dtcvct57	dtcvct57_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area58
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct58_addr@0x2C3A;
#define		dtcvct58	dtcvct58_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area59
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct59_addr@0x2C3B;
#define		dtcvct59	dtcvct59_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area60
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct60_addr@0x2C3C;
#define		dtcvct60	dtcvct60_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area61
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct61_addr@0x2C3D;
#define		dtcvct61	dtcvct61_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area62
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct62_addr@0x2C3E;
#define		dtcvct62	dtcvct62_addr.byte

/*------------------------------------------------------
  DTC Transfer Vector Area63
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcvct63_addr@0x2C3F;
#define		dtcvct63	dtcvct63_addr.byte

/*------------------------------------------------------
  DTC Control Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr0_addr@0x2C40;
#define		dtccr0		dtccr0_addr.byte

#define		mode_dtccr0		dtccr0_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr0	dtccr0_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr0	dtccr0_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr0	dtccr0_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr0		dtccr0_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr0	dtccr0_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls0_addr@0x2C41;
#define		dtbls0		dtbls0_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct0_addr@0x2C42;
#define		dtcct0		dtcct0_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 0
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld0_addr@0x2C43;
#define		dtrld0		dtrld0_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 0
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar0_addr@0x2C44;
#define		dtsar0		dtsar0_addr

/*------------------------------------------------------
  DTC Destination Register 0
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar0_addr@0x2C46;
#define		dtdar0		dtdar0_addr

/*------------------------------------------------------
  DTC Control Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr1_addr@0x2C48;
#define		dtccr1		dtccr1_addr.byte

#define		mode_dtccr1		dtccr1_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr1	dtccr1_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr1	dtccr1_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr1	dtccr1_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr1		dtccr1_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr1	dtccr1_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls1_addr@0x2C49;
#define		dtbls1		dtbls1_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct1_addr@0x2C4A;
#define		dtcct1		dtcct1_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 1
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld1_addr@0x2C4B;
#define		dtrld1		dtrld1_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 1
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar1_addr@0x2C4C;
#define		dtsar1		dtsar1_addr

/*------------------------------------------------------
  DTC Destination Register 1
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar1_addr@0x2C4E;
#define		dtdar1		dtdar1_addr

/*------------------------------------------------------
  DTC Control Register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr2_addr@0x2C50;
#define		dtccr2		dtccr2_addr.byte

#define		mode_dtccr2		dtccr2_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr2	dtccr2_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr2	dtccr2_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr2	dtccr2_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr2		dtccr2_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr2	dtccr2_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls2_addr@0x2C51;
#define		dtbls2		dtbls2_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct2_addr@0x2C52;
#define		dtcct2		dtcct2_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 2
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld2_addr@0x2C53;
#define		dtrld2		dtrld2_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 2
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar2_addr@0x2C54;
#define		dtsar2		dtsar2_addr

/*------------------------------------------------------
  DTC Destination Register 2
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar2_addr@0x2C56;
#define		dtdar2		dtdar2_addr

/*------------------------------------------------------
  DTC Control Register 3
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr3_addr@0x2C58;
#define		dtccr3		dtccr3_addr.byte

#define		mode_dtccr3		dtccr3_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr3	dtccr3_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr3	dtccr3_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr3	dtccr3_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr3		dtccr3_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr3	dtccr3_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 3
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls3_addr@0x2C59;
#define		dtbls3		dtbls3_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 3
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct3_addr@0x2C5A;
#define		dtcct3		dtcct3_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 3
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld3_addr@0x2C5B;
#define		dtrld3		dtrld3_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 3
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar3_addr@0x2C5C;
#define		dtsar3		dtsar3_addr

/*------------------------------------------------------
  DTC Destination Register 3
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar3_addr@0x2C5E;
#define		dtdar3		dtdar3_addr

/*------------------------------------------------------
  DTC Control Register 4
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr4_addr@0x2C60;
#define		dtccr4		dtccr4_addr.byte

#define		mode_dtccr4		dtccr4_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr4	dtccr4_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr4	dtccr4_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr4	dtccr4_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr4		dtccr4_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr4	dtccr4_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 4
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls4_addr@0x2C61;
#define		dtbls4		dtbls4_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 4
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct4_addr@0x2C62;
#define		dtcct4		dtcct4_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 4
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld4_addr@0x2C63;
#define		dtrld4		dtrld4_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 4
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar4_addr@0x2C64;
#define		dtsar4		dtsar4_addr

/*------------------------------------------------------
  DTC Destination Register 4
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar4_addr@0x2C66;
#define		dtdar4		dtdar4_addr

/*------------------------------------------------------
  DTC Control Register 5
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr5_addr@0x2C68;
#define		dtccr5		dtccr5_addr.byte

#define		mode_dtccr5		dtccr5_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr5	dtccr5_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr5	dtccr5_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr5	dtccr5_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr5		dtccr5_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr5	dtccr5_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 5
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls5_addr@0x2C69;
#define		dtbls5		dtbls5_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 5
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct5_addr@0x2C6A;
#define		dtcct5		dtcct5_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 5
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld5_addr@0x2C6B;
#define		dtrld5		dtrld5_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 5
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar5_addr@0x2C6C;
#define		dtsar5		dtsar5_addr

/*------------------------------------------------------
  DTC Destination Register 5
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar5_addr@0x2C6E;
#define		dtdar5		dtdar5_addr

/*------------------------------------------------------
  DTC Control Register 6
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr6_addr@0x2C70;
#define		dtccr6		dtccr6_addr.byte

#define		mode_dtccr6		dtccr6_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr6	dtccr6_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr6	dtccr6_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr6	dtccr6_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr6		dtccr6_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr6	dtccr6_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 6
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls6_addr@0x2C71;
#define		dtbls6		dtbls6_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 6
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct6_addr@0x2C72;
#define		dtcct6		dtcct6_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 6
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld6_addr@0x2C73;
#define		dtrld6		dtrld6_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 6
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar6_addr@0x2C74;
#define		dtsar6		dtsar6_addr

/*------------------------------------------------------
  DTC Destination Register 6
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar6_addr@0x2C76;
#define		dtdar6		dtdar6_addr

/*------------------------------------------------------
  DTC Control Register 7
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr7_addr@0x2C78;
#define		dtccr7		dtccr7_addr.byte

#define		mode_dtccr7		dtccr7_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr7	dtccr7_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr7	dtccr7_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr7	dtccr7_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr7		dtccr7_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr7	dtccr7_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 7
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls7_addr@0x2C79;
#define		dtbls7		dtbls7_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 7
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct7_addr@0x2C7A;
#define		dtcct7		dtcct7_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 7
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld7_addr@0x2C7B;
#define		dtrld7		dtrld7_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 7
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar7_addr@0x2C7C;
#define		dtsar7		dtsar7_addr

/*------------------------------------------------------
  DTC Destination Register 7
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar7_addr@0x2C7E;
#define		dtdar7		dtdar7_addr

/*------------------------------------------------------
  DTC Control Register 8
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr8_addr@0x2C80;
#define		dtccr8		dtccr8_addr.byte

#define		mode_dtccr8		dtccr8_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr8	dtccr8_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr8	dtccr8_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr8	dtccr8_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr8		dtccr8_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr8	dtccr8_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 8
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls8_addr@0x2C81;
#define		dtbls8		dtbls8_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 8
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct8_addr@0x2C82;
#define		dtcct8		dtcct8_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 8
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld8_addr@0x2C83;
#define		dtrld8		dtrld8_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 8
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar8_addr@0x2C84;
#define		dtsar8		dtsar8_addr

/*------------------------------------------------------
  DTC Destination Register 8
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar8_addr@0x2C86;
#define		dtdar8		dtdar8_addr

/*------------------------------------------------------
  DTC Control Register 9
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr9_addr@0x2C88;
#define		dtccr9		dtccr9_addr.byte

#define		mode_dtccr9		dtccr9_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr9	dtccr9_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr9	dtccr9_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr9	dtccr9_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr9		dtccr9_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr9	dtccr9_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 9
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls9_addr@0x2C89;
#define		dtbls9		dtbls9_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 9
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct9_addr@0x2C8A;
#define		dtcct9		dtcct9_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 9
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld9_addr@0x2C8B;
#define		dtrld9		dtrld9_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 9
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar9_addr@0x2C8C;
#define		dtsar9		dtsar9_addr

/*------------------------------------------------------
  DTC Destination Register 9
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar9_addr@0x2C8E;
#define		dtdar9		dtdar9_addr

/*------------------------------------------------------
  DTC Control Register 10
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr10_addr@0x2C90;
#define		dtccr10		dtccr10_addr.byte

#define		mode_dtccr10	dtccr10_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr10	dtccr10_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr10	dtccr10_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr10	dtccr10_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr10	dtccr10_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr10	dtccr10_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 10
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls10_addr@0x2C91;
#define		dtbls10		dtbls10_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 10
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct10_addr@0x2C92;
#define		dtcct10		dtcct10_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 10
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld10_addr@0x2C93;
#define		dtrld10		dtrld10_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 10
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar10_addr@0x2C94;
#define		dtsar10		dtsar10_addr

/*------------------------------------------------------
  DTC Destination Register 10
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar10_addr@0x2C96;
#define		dtdar10		dtdar10_addr

/*------------------------------------------------------
  DTC Control Register 11
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr11_addr@0x2C98;
#define		dtccr11		dtccr11_addr.byte

#define		mode_dtccr11	dtccr11_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr11	dtccr11_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr11	dtccr11_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr11	dtccr11_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr11	dtccr11_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr11	dtccr11_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 11
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls11_addr@0x2C99;
#define		dtbls11		dtbls11_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 11
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct11_addr@0x2C9A;
#define		dtcct11		dtcct11_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 11
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld11_addr@0x2C9B;
#define		dtrld11		dtrld11_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 11
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar11_addr@0x2C9C;
#define		dtsar11		dtsar11_addr

/*------------------------------------------------------
  DTC Destination Register 11
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar11_addr@0x2C9E;
#define		dtdar11		dtdar11_addr

/*------------------------------------------------------
  DTC Control Register 12
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr12_addr@0x2CA0;
#define		dtccr12		dtccr12_addr.byte

#define		mode_dtccr12	dtccr12_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr12	dtccr12_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr12	dtccr12_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr12	dtccr12_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr12	dtccr12_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr12	dtccr12_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 12
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls12_addr@0x2CA1;
#define		dtbls12		dtbls12_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 12
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct12_addr@0x2CA2;
#define		dtcct12		dtcct12_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 12
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld12_addr@0x2CA3;
#define		dtrld12		dtrld12_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 12
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar12_addr@0x2CA4;
#define		dtsar12		dtsar12_addr

/*------------------------------------------------------
  DTC Destination Register 12
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar12_addr@0x2CA6;
#define		dtdar12		dtdar12_addr

/*------------------------------------------------------
  DTC Control Register 13
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr13_addr@0x2CA8;
#define		dtccr13		dtccr13_addr.byte

#define		mode_dtccr13	dtccr13_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr13	dtccr13_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr13	dtccr13_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr13	dtccr13_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr13	dtccr13_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr13	dtccr13_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 13
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls13_addr@0x2CA9;
#define		dtbls13		dtbls13_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 13
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct13_addr@0x2CAA;
#define		dtcct13		dtcct13_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 13
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld13_addr@0x2CAB;
#define		dtrld13		dtrld13_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 13
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar13_addr@0x2CAC;
#define		dtsar13		dtsar13_addr

/*------------------------------------------------------
  DTC Destination Register 13
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar13_addr@0x2CAE;
#define		dtdar13		dtdar13_addr

/*------------------------------------------------------
  DTC Control Register 14
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr14_addr@0x2CB0;
#define		dtccr14		dtccr14_addr.byte

#define		mode_dtccr14	dtccr14_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr14	dtccr14_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr14	dtccr14_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr14	dtccr14_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr14	dtccr14_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr14	dtccr14_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 14
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls14_addr@0x2CB1;
#define		dtbls14		dtbls14_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 14
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct14_addr@0x2CB2;
#define		dtcct14		dtcct14_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 14
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld14_addr@0x2CB3;
#define		dtrld14		dtrld14_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 14
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar14_addr@0x2CB4;
#define		dtsar14		dtsar14_addr

/*------------------------------------------------------
  DTC Destination Register 14
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar14_addr@0x2CB6;
#define		dtdar14		dtdar14_addr

/*------------------------------------------------------
  DTC Control Register 15
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr15_addr@0x2CB8;
#define		dtccr15		dtccr15_addr.byte

#define		mode_dtccr15	dtccr15_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr15	dtccr15_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr15	dtccr15_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr15	dtccr15_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr15	dtccr15_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr15	dtccr15_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 15
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls15_addr@0x2CB9;
#define		dtbls15		dtbls15_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 15
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct15_addr@0x2CBA;
#define		dtcct15		dtcct15_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 15
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld15_addr@0x2CBB;
#define		dtrld15		dtrld15_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 15
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar15_addr@0x2CBC;
#define		dtsar15		dtsar15_addr

/*------------------------------------------------------
  DTC Destination Register 15
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar15_addr@0x2CBE;
#define		dtdar15		dtdar15_addr

/*------------------------------------------------------
  DTC Control Register 16
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr16_addr@0x2CC0;
#define		dtccr16		dtccr16_addr.byte

#define		mode_dtccr16	dtccr16_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr16	dtccr16_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr16	dtccr16_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr16	dtccr16_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr16	dtccr16_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr16	dtccr16_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 16
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls16_addr@0x2CC1;
#define		dtbls16		dtbls16_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 16
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct16_addr@0x2CC2;
#define		dtcct16		dtcct16_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 16
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld16_addr@0x2CC3;
#define		dtrld16		dtrld16_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 16
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar16_addr@0x2CC4;
#define		dtsar16		dtsar16_addr

/*------------------------------------------------------
  DTC Destination Register 16
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar16_addr@0x2CC6;
#define		dtdar16		dtdar16_addr

/*------------------------------------------------------
  DTC Control Register 17
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr17_addr@0x2CC8;
#define		dtccr17		dtccr17_addr.byte

#define		mode_dtccr17	dtccr17_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr17	dtccr17_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr17	dtccr17_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr17	dtccr17_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr17	dtccr17_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr17	dtccr17_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 17
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls17_addr@0x2CC9;
#define		dtbls17		dtbls17_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 17
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct17_addr@0x2CCA;
#define		dtcct17		dtcct17_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 17
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld17_addr@0x2CCB;
#define		dtrld17		dtrld17_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 17
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar17_addr@0x2CCC;
#define		dtsar17		dtsar17_addr

/*------------------------------------------------------
  DTC Destination Register 17
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar17_addr@0x2CCE;
#define		dtdar17		dtdar17_addr

/*------------------------------------------------------
  DTC Control Register 18
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr18_addr@0x2CD0;
#define		dtccr18		dtccr18_addr.byte

#define		mode_dtccr18	dtccr18_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr18	dtccr18_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr18	dtccr18_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr18	dtccr18_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr18	dtccr18_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr18	dtccr18_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 18
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls18_addr@0x2CD1;
#define		dtbls18		dtbls18_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 18
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct18_addr@0x2CD2;
#define		dtcct18		dtcct18_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 18
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld18_addr@0x2CD3;
#define		dtrld18		dtrld18_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 18
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar18_addr@0x2CD4;
#define		dtsar18		dtsar18_addr

/*------------------------------------------------------
  DTC Destination Register 18
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar18_addr@0x2CD6;
#define		dtdar18		dtdar18_addr

/*------------------------------------------------------
  DTC Control Register 19
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr19_addr@0x2CD8;
#define		dtccr19		dtccr19_addr.byte

#define		mode_dtccr19	dtccr19_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr19	dtccr19_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr19	dtccr19_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr19	dtccr19_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr19	dtccr19_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr19	dtccr19_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 19
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls19_addr@0x2CD9;
#define		dtbls19		dtbls19_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 19
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct19_addr@0x2CDA;
#define		dtcct19		dtcct19_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 19
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld19_addr@0x2CDB;
#define		dtrld19		dtrld19_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 19
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar19_addr@0x2CDC;
#define		dtsar19		dtsar19_addr

/*------------------------------------------------------
  DTC Destination Register 19
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar19_addr@0x2CDE;
#define		dtdar19		dtdar19_addr

/*------------------------------------------------------
  DTC Control Register 20
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr20_addr@0x2CE0;
#define		dtccr20		dtccr20_addr.byte

#define		mode_dtccr20	dtccr20_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr20	dtccr20_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr20	dtccr20_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr20	dtccr20_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr20	dtccr20_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr20	dtccr20_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 20
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls20_addr@0x2CE1;
#define		dtbls20		dtbls20_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 20
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct20_addr@0x2CE2;
#define		dtcct20		dtcct20_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 20
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld20_addr@0x2CE3;
#define		dtrld20		dtrld20_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 20
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar20_addr@0x2CE4;
#define		dtsar20		dtsar20_addr

/*------------------------------------------------------
  DTC Destination Register 20
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar20_addr@0x2CE6;
#define		dtdar20		dtdar20_addr

/*------------------------------------------------------
  DTC Control Register 21
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr21_addr@0x2CE8;
#define		dtccr21		dtccr21_addr.byte

#define		mode_dtccr21	dtccr21_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr21	dtccr21_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr21	dtccr21_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr21	dtccr21_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr21	dtccr21_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr21	dtccr21_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 21
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls21_addr@0x2CE9;
#define		dtbls21		dtbls21_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 21
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct21_addr@0x2CEA;
#define		dtcct21		dtcct21_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 21
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld21_addr@0x2CEB;
#define		dtrld21		dtrld21_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 21
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar21_addr@0x2CEC;
#define		dtsar21		dtsar21_addr

/*------------------------------------------------------
  DTC Destination Register 21
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar21_addr@0x2CEE;
#define		dtdar21		dtdar21_addr

/*------------------------------------------------------
  DTC Control Register 22
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr22_addr@0x2CF0;
#define		dtccr22		dtccr22_addr.byte

#define		mode_dtccr22	dtccr22_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr22	dtccr22_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr22	dtccr22_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr22	dtccr22_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr22	dtccr22_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr22	dtccr22_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 22
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls22_addr@0x2CF1;
#define		dtbls22		dtbls22_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 22
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct22_addr@0x2CF2;
#define		dtcct22		dtcct22_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 22
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld22_addr@0x2CF3;
#define		dtrld22		dtrld22_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 22
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar22_addr@0x2CF4;
#define		dtsar22		dtsar22_addr

/*------------------------------------------------------
  DTC Destination Register 22
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar22_addr@0x2CF6;
#define		dtdar22		dtdar22_addr

/*------------------------------------------------------
  DTC Control Register 23
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtccr23_addr@0x2CF8;
#define		dtccr23		dtccr23_addr.byte

#define		mode_dtccr23	dtccr23_addr.bit.b0	/* Transfer mode select bit */	
#define		rptsel_dtccr23	dtccr23_addr.bit.b1	/* Repeat area select bit */	
#define		samod_dtccr23	dtccr23_addr.bit.b2	/* Source address control bit */	
#define		damod_dtccr23	dtccr23_addr.bit.b3	/* Destination address control bit */	
#define		chne_dtccr23	dtccr23_addr.bit.b4	/* Chain transfer enable bit */	
#define		rptint_dtccr23	dtccr23_addr.bit.b5	/* Repeat mode interrupt enable bit */	

/*------------------------------------------------------
  DTC Block Size Register 23
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtbls23_addr@0x2CF9;
#define		dtbls23		dtbls23_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Register 23
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtcct23_addr@0x2CFA;
#define		dtcct23		dtcct23_addr.byte

/*------------------------------------------------------
  DTC Transfer Count Reload Register 23
------------------------------------------------------*/
__no_init  volatile union	byte_def	dtrld23_addr@0x2CFB;
#define		dtrld23		dtrld23_addr.byte

/*------------------------------------------------------
  DTC Source Address Register 23
------------------------------------------------------*/
__no_init  volatile unsigned short	dtsar23_addr@0x2CFC;
#define		dtsar23		dtsar23_addr

/*------------------------------------------------------
  DTC Destination Register 23
------------------------------------------------------*/
__no_init  volatile unsigned short	dtdar23_addr@0x2CFE;
#define		dtdar23		dtdar23_addr

/*------------------------------------------------------
  Timer RC Counter, General register A,B,C,D
------------------------------------------------------*/
__no_init  volatile unsigned short trc_addr@0x0126, trcgra_addr@0x0128, trcgrb_addr@0x012A, trcgrc_addr@0x012C, trcgrd_addr@0x012E;
#define		trc				trc_addr			/* Timer RC Counter */
#define		trcgra			trcgra_addr			/* Timer RC general register A */
#define		trcgrb			trcgrb_addr			/* Timer RC general register B */
#define		trcgrc			trcgrc_addr			/* Timer RC general register C */
#define		trcgrd			trcgrd_addr			/* Timer RC general register D */

/*------------------------------------------------------
  Timer RD counter 0, Timer RD Counter 1, General register A,B,C,D
------------------------------------------------------*/
__no_init  volatile unsigned short trd0_addr@0x0146, trdgra0_addr@0x0148, trdgrb0_addr@0x014A, trdgrc0_addr@0x014C, trdgrd0_addr@0x014E;
__no_init  volatile unsigned short trd1_addr@0x0156, trdgra1_addr@0x0158, trdgrb1_addr@0x015A, trdgrc1_addr@0x015C, trdgrd1_addr@0x015E;

#define		trd0			trd0_addr			/* Timer RD counter 0 */
#define		trdgra0			trdgra0_addr		/* Timer RD general register A0 */
#define		trdgrb0			trdgrb0_addr		/* Timer RD general register B0 */
#define		trdgrc0			trdgrc0_addr		/* Timer RD general register C0 */
#define		trdgrd0			trdgrd0_addr		/* Timer RD general register D0 */

#define		trd1			trd1_addr			/* Timer RD counter 1 */
#define		trdgra1			trdgra1_addr		/* Timer RD general register A1 */
#define		trdgrb1			trdgrb1_addr		/* Timer RD general register B1 */
#define		trdgrc1			trdgrc1_addr		/* Timer RD general register C1 */
#define		trdgrd1			trdgrd1_addr		/* Timer RD general register D1 */

/*------------------------------------------------------
  Interrupt control register
------------------------------------------------------*/
__no_init  volatile union{
	struct{
		unsigned char	ilvl0:1;				/* Interrupt priority level select bit */
		unsigned char	ilvl1:1;				/* Interrupt priority level select bit */
		unsigned char	ilvl2:1;				/* Interrupt priority level select bit */
		unsigned char	ir:1;					/* Interrupt request bit */
		unsigned char	pol:1;					/* Polarity select bit */
		unsigned char	b5:1;
		unsigned char	b6:1;
		unsigned char	b7:1;
	} bit;
	unsigned char	byte;
} fmrdyic_addr@0x0041, int7ic_addr@0x0043,int6ic_addr@0x0044, int5ic_addr@0x0045,int4ic_addr@0x0046, trcic_addr@0x0047, trd0ic_addr@0x0048,
trd1ic_addr@0x0049, treic_addr@0x004A, s2tic_addr@0x004B, s2ric_addr@0x004C, kupic_addr@0x004D, adic_addr@0x004E, ssuic_addr@0x004F,
iicic_addr@0x004F,  s0tic_addr@0x0051, s0ric_addr@0x0052, s1tic_addr@0x0053, s1ric_addr@0x0054, int2ic_addr@0x0055,
traic_addr@0x0056, trbic_addr@0x0058, int1ic_addr@0x0059, int3ic_addr@0x005A, int0ic_addr@0x005D,
u2bcnic_addr@0x005E, vcmp1ic_addr@0x0072, vcmp2ic_addr@0x0073, trgic_addr@0x006B;

/*------------------------------------------------------
  Flash Memory Ready Interrupt Control Register
------------------------------------------------------*/
#define		fmrdyic		fmrdyic_addr.byte

#define		ilvl0_fmrdyic	fmrdyic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_fmrdyic	fmrdyic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_fmrdyic	fmrdyic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_fmrdyic		fmrdyic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  INT7 interrupt control register
------------------------------------------------------*/
#define		int7ic		int7ic_addr.byte

#define		ilvl0_int7ic	int7ic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_int7ic	int7ic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_int7ic	int7ic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_int7ic		int7ic_addr.bit.ir		/* Interrupt request bit */
#define		pol_int7ic		int7ic_addr.bit.pol		/* Polarity switch bit */

/*------------------------------------------------------
  INT6 interrupt control register
------------------------------------------------------*/
#define		int6ic		int6ic_addr.byte

#define		ilvl0_int6ic	int6ic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_int6ic	int6ic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_int6ic	int6ic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_int6ic		int6ic_addr.bit.ir		/* Interrupt request bit */
#define		pol_int6ic		int6ic_addr.bit.pol		/* Polarity switch bit */

/*------------------------------------------------------
  INT5 interrupt control register
------------------------------------------------------*/
#define		int5ic		int5ic_addr.byte

#define		ilvl0_int5ic	int5ic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_int5ic	int5ic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_int5ic	int5ic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_int5ic		int5ic_addr.bit.ir		/* Interrupt request bit */
#define		pol_int5ic		int5ic_addr.bit.pol		/* Polarity switch bit */

/*------------------------------------------------------
  INT4 interrupt control register
------------------------------------------------------*/
#define		int4ic		int4ic_addr.byte

#define		ilvl0_int4ic	int4ic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_int4ic	int4ic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_int4ic	int4ic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_int4ic		int4ic_addr.bit.ir		/* Interrupt request bit */
#define		pol_int4ic		int4ic_addr.bit.pol		/* Polarity switch bit */

/*------------------------------------------------------
  Timer RC interrupt control register
------------------------------------------------------*/
#define		trcic		trcic_addr.byte

#define		ilvl0_trcic		trcic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_trcic		trcic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_trcic		trcic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_trcic		trcic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  Timer RD0 Interrupt Control Register
------------------------------------------------------*/
#define		trd0ic		trd0ic_addr.byte

#define		ilvl0_trd0ic	trd0ic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_trd0ic	trd0ic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_trd0ic	trd0ic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_trd0ic		trd0ic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  Timer RD1 Interrupt Control Register
------------------------------------------------------*/
#define		trd1ic		trd1ic_addr.byte

#define		ilvl0_trd1ic	trd1ic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_trd1ic	trd1ic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_trd1ic	trd1ic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_trd1ic		trd1ic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  Timer RE Interrupt Control Register
------------------------------------------------------*/
#define		treic		treic_addr.byte

#define		ilvl0_treic		treic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_treic		treic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_treic		treic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_treic		treic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  UART2 transmit interrupt control register
------------------------------------------------------*/
#define		s2tic		s2tic_addr.byte

#define		ilvl0_s2tic		s2tic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_s2tic		s2tic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_s2tic		s2tic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_s2tic		s2tic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  UART2 receive interrupt control register
------------------------------------------------------*/
#define		s2ric		s2ric_addr.byte

#define		ilvl0_s2ric		s2ric_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_s2ric		s2ric_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_s2ric		s2ric_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_s2ric		s2ric_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  Key input interrupt control register
------------------------------------------------------*/
#define		kupic		kupic_addr.byte

#define		ilvl0_kupic		kupic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_kupic		kupic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_kupic		kupic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_kupic		kupic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  A/D Conversion Interrupt Control Register
------------------------------------------------------*/
#define		adic		adic_addr.byte

#define		ilvl0_adic		adic_addr.bit.ilvl0		/* Interrupt priority level select bit */
#define		ilvl1_adic		adic_addr.bit.ilvl1		/* Interrupt priority level select bit */
#define		ilvl2_adic		adic_addr.bit.ilvl2		/* Interrupt priority level select bit */
#define		ir_adic			adic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  SSU interrupt control register
------------------------------------------------------*/
#define		ssuic		ssuic_addr.byte

#define		ilvl0_ssuic	ssuic_addr.bit.ilvl0		/* Interrupt priority level select bit */
#define		ilvl1_ssuic	ssuic_addr.bit.ilvl1		/* Interrupt priority level select bit */
#define		ilvl2_ssuic	ssuic_addr.bit.ilvl2		/* Interrupt priority level select bit */
#define		ir_ssuic		ssuic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  IIC bus Interrupt Control Register
------------------------------------------------------*/
#define		iicic		iicic_addr.byte

#define		ilvl0_iicic	iicic_addr.bit.ilvl0		/* Interrupt priority level select bit */
#define		ilvl1_iicic	iicic_addr.bit.ilvl1		/* Interrupt priority level select bit */
#define		ilvl2_iicic	iicic_addr.bit.ilvl2		/* Interrupt priority level select bit */
#define		ir_iicic		iicic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  UART0 transmit interrupt control register
------------------------------------------------------*/
#define		s0tic		s0tic_addr.byte

#define		ilvl0_s0tic		s0tic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_s0tic		s0tic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_s0tic		s0tic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_s0tic		s0tic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  UART0 receive interrupt control register
------------------------------------------------------*/
#define		s0ric		s0ric_addr.byte

#define		ilvl0_s0ric		s0ric_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_s0ric		s0ric_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_s0ric		s0ric_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_s0ric		s0ric_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  UART1 transmit interrupt control register
------------------------------------------------------*/
#define		s1tic		s1tic_addr.byte

#define		ilvl0_s1tic		s1tic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_s1tic		s1tic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_s1tic		s1tic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_s1tic		s1tic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  UART1 receive interrupt control register
------------------------------------------------------*/
#define		s1ric		s1ric_addr.byte

#define		ilvl0_s1ric		s1ric_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_s1ric		s1ric_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_s1ric		s1ric_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_s1ric		s1ric_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  INT2 interrupt control register
------------------------------------------------------*/
#define		int2ic		int2ic_addr.byte

#define		ilvl0_int2ic	int2ic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_int2ic	int2ic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_int2ic	int2ic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_int2ic		int2ic_addr.bit.ir		/* Interrupt request bit */
#define		pol_int2ic		int2ic_addr.bit.pol		/* Polarity switch bit */

/*------------------------------------------------------
  Timer RA interrupt control register
------------------------------------------------------*/
#define		traic		traic_addr.byte

#define		ilvl0_traic		traic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_traic		traic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_traic		traic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_traic		traic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  Timer RB interrupt control register
------------------------------------------------------*/
#define		trbic		trbic_addr.byte

#define		ilvl0_trbic		trbic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_trbic		trbic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_trbic		trbic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_trbic		trbic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  INT1 interrupt control register
------------------------------------------------------*/
#define		int1ic		int1ic_addr.byte

#define		ilvl0_int1ic	int1ic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_int1ic	int1ic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_int1ic	int1ic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_int1ic		int1ic_addr.bit.ir		/* Interrupt request bit */
#define		pol_int1ic		int1ic_addr.bit.pol		/* Polarity switch bit */

/*------------------------------------------------------
  INT3 interrupt control register
------------------------------------------------------*/
#define		int3ic		int3ic_addr.byte

#define		ilvl0_int3ic	int3ic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_int3ic	int3ic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_int3ic	int3ic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_int3ic		int3ic_addr.bit.ir		/* Interrupt request bit */
#define		pol_int3ic		int3ic_addr.bit.pol		/* Polarity switch bit */

/*------------------------------------------------------
  INT0 interrupt control register
------------------------------------------------------*/
#define		int0ic		int0ic_addr.byte

#define		ilvl0_int0ic	int0ic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_int0ic	int0ic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_int0ic	int0ic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_int0ic		int0ic_addr.bit.ir		/* Interrupt request bit */
#define		pol_int0ic		int0ic_addr.bit.pol		/* Polarity switch bit */

/*------------------------------------------------------
  UART2 bus collision detection interrupt control register
------------------------------------------------------*/
#define		u2bcnic		u2bcnic_addr.byte

#define		ilvl0_u2bcnic	u2bcnic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_u2bcnic	u2bcnic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_u2bcnic	u2bcnic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_u2bcnic		u2bcnic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  Timer RG interrupt control register
------------------------------------------------------*/
#define		trgic		trgic_addr.byte

#define		ilvl0_trgic			trgic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_trgic			trgic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_trgic			trgic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_trgic			trgic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  Voltage monitor 1 Interrupt Control Register
------------------------------------------------------*/
#define		vcmp1ic		vcmp1ic_addr.byte

#define		ilvl0_vcmp1ic	vcmp1ic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_vcmp1ic	vcmp1ic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_vcmp1ic	vcmp1ic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_vcmp1ic		vcmp1ic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  Voltage monitor circuit 2 interrupt control register
------------------------------------------------------*/
#define		vcmp2ic		vcmp2ic_addr.byte

#define		ilvl0_vcmp2ic	vcmp2ic_addr.bit.ilvl0	/* Interrupt priority level select bit */
#define		ilvl1_vcmp2ic	vcmp2ic_addr.bit.ilvl1	/* Interrupt priority level select bit */
#define		ilvl2_vcmp2ic	vcmp2ic_addr.bit.ilvl2	/* Interrupt priority level select bit */
#define		ir_vcmp2ic		vcmp2ic_addr.bit.ir		/* Interrupt request bit */

/*------------------------------------------------------
  UARTi transmit/receive mode register
------------------------------------------------------*/
__no_init  volatile union{
	struct{
		unsigned char	smd0:1;					/* Serial I/O mode select bit */
		unsigned char	smd1:1;					/* Serial I/O mode select bit */
		unsigned char	smd2:1;					/* Serial I/O mode select bit */
		unsigned char	ckdir:1;				/* Internal/external clock select bit */
		unsigned char	stps:1;					/* Stop bit length select bit */
		unsigned char	pry:1;					/* Odd/even parity select bit */
		unsigned char	prye:1;					/* Parity enable bit */
		unsigned char	b7:1;
	} bit;
	unsigned char	byte;
} u0mr_addr@0x00A0, u1mr_addr@0x0160, u2mr_addr@0x00A8;

/*------------------------------------------------------
  UARTi transmit/receive mode register
------------------------------------------------------*/
#define		u0mr		u0mr_addr.byte			/* UART0 Transmit/Receive Mode Register */

#define		smd0_u0mr		u0mr_addr.bit.smd0	/* Serial I/O mode select bit */
#define		smd1_u0mr		u0mr_addr.bit.smd1	/* Serial I/O mode select bit */
#define		smd2_u0mr		u0mr_addr.bit.smd2	/* Serial I/O mode select bit */
#define		ckdir_u0mr		u0mr_addr.bit.ckdir	/* Internal/external clock select bit */
#define		stps_u0mr		u0mr_addr.bit.stps	/* Stop bit length select bit */
#define		pry_u0mr		u0mr_addr.bit.pry	/* Odd/even parity select bit */
#define		prye_u0mr		u0mr_addr.bit.prye	/* Parity enable bit */

#define		u2mr		u2mr_addr.byte			/* UART2 Transmit/Receive Mode Register */

#define		smd0_u2mr		u2mr_addr.bit.smd0	/* Serial I/O mode select bit */
#define		smd1_u2mr		u2mr_addr.bit.smd1	/* Serial I/O mode select bit */
#define		smd2_u2mr		u2mr_addr.bit.smd2	/* Serial I/O mode select bit */
#define		ckdir_u2mr		u2mr_addr.bit.ckdir	/* Internal/external clock select bit */
#define		stps_u2mr		u2mr_addr.bit.stps	/* Stop bit length select bit */
#define		pry_u2mr		u2mr_addr.bit.pry	/* Odd/even parity select bit */
#define		prye_u2mr		u2mr_addr.bit.prye	/* Parity enable bit */
#define		iopol_u2mr		u2mr_addr.bit.b7	/* TXD, RXD I/O polarity switch bit */

#define		u1mr		u1mr_addr.byte			/* UART1 Transmit/Receive Mode Register */

#define		smd0_u1mr		u1mr_addr.bit.smd0	/* Serial I/O mode select bit */
#define		smd1_u1mr		u1mr_addr.bit.smd1	/* Serial I/O mode select bit */
#define		smd2_u1mr		u1mr_addr.bit.smd2	/* Serial I/O mode select bit */
#define		ckdir_u1mr		u1mr_addr.bit.ckdir	/* Internal/external clock select bit */
#define		stps_u1mr		u1mr_addr.bit.stps	/* Stop bit length select bit */
#define		pry_u1mr		u1mr_addr.bit.pry	/* Odd/even parity select bit */
#define		prye_u1mr		u1mr_addr.bit.prye	/* Parity enable bit */

/*------------------------------------------------------
  UARTi transmit/receive control register0
------------------------------------------------------*/
__no_init  volatile union{
	struct{
		unsigned char	clk0:1;					/* BRG Count source select bit */
		unsigned char	clk1:1;					/* BRG Count source select bit */
		unsigned char	crs:1;					/* CTS/RTS select bit */
		unsigned char	txept:1;				/* Transmit register empty flag */
		unsigned char	crd:1;					/* CTS/RTS disable bit */
		unsigned char	nch:1;					/* Data output select bit */
		unsigned char	ckpol:1;				/* CLK polarity select bit */
		unsigned char	uform:1;				/* Transfer format select bit */
	} bit;
	unsigned char	byte;
} u0c0_addr@0x00A4, u1c0_addr@0x0164, u2c0_addr@0x00AC;

/*------------------------------------------------------
  UARTi transmit/receive control register0
------------------------------------------------------*/
#define		u0c0		u0c0_addr.byte			/* UART0 Transmit/Receive Control Register 0 */

#define		clk0_u0c0		u0c0_addr.bit.clk0	/* BRG Count source select bit */
#define		clk1_u0c0		u0c0_addr.bit.clk1	/* BRG Count source select bit */
#define		txept_u0c0		u0c0_addr.bit.txept	/* Transmit register empty flag */
#define		nch_u0c0		u0c0_addr.bit.nch	/* Data output select bit */
#define		ckpol_u0c0		u0c0_addr.bit.ckpol	/* CLK polarity select bit */
#define		uform_u0c0		u0c0_addr.bit.uform	/* Transfer format select bit */

#define		u2c0		u2c0_addr.byte			/* UART2 Transmit/Receive Control Register 0 */

#define		clk0_u2c0		u2c0_addr.bit.clk0	/* U2BRG count source select bit */
#define		clk1_u2c0		u2c0_addr.bit.clk1	/* U2BRG count source select bit */
#define		crs_u2c0		u2c0_addr.bit.crs	/* CTS/RTS function select bit */
#define		txept_u2c0		u2c0_addr.bit.txept	/* Transmit register empty flag */
#define		crd_u2c0		u2c0_addr.bit.crd	/* CTS/RTS disable bit */
#define		nch_u2c0		u2c0_addr.bit.nch	/* Data output select bit */
#define		ckpol_u2c0		u2c0_addr.bit.ckpol	/* CLK polarity select bit */
#define		uform_u2c0		u2c0_addr.bit.uform	/* Transfer format select bit */

#define		u1c0		u1c0_addr.byte			/* UART1 Transmit/Receive Control Register 0 */

#define		clk0_u1c0		u1c0_addr.bit.clk0	/* BRG Count source select bit */
#define		clk1_u1c0		u1c0_addr.bit.clk1	/* BRG Count source select bit */
#define		txept_u1c0		u1c0_addr.bit.txept	/* Transmit register empty flag */
#define		nch_u1c0		u1c0_addr.bit.nch	/* Data output select bit */
#define		ckpol_u1c0		u1c0_addr.bit.ckpol	/* CLK polarity select bit */
#define		uform_u1c0		u1c0_addr.bit.uform	/* Transfer format select bit */

/*------------------------------------------------------
  UARTi transmit/receive control register1
------------------------------------------------------*/
__no_init  volatile union{
	struct{
		unsigned char	te:1;					/* Transmission enable bit */
		unsigned char	ti:1;					/* Transmit buffer empty flag */
		unsigned char	re:1;					/* Reception enable bit */
		unsigned char	ri:1;					/* Reception complete flag */
		unsigned char	irs:1;
		unsigned char	rrm:1;
		unsigned char	lch:1;
		unsigned char	ere:1;
	} bit;
	unsigned char	byte;
} u0c1_addr@0x00A5, u1c1_addr@0x0165, u2c1_addr@0x00AD;

/*------------------------------------------------------
  UARTi transmit/receive control register1
------------------------------------------------------*/
#define		u0c1		u0c1_addr.byte			/* UART0 Transmit/Receive Control Register 1 */

#define		te_u0c1			u0c1_addr.bit.te	/* Transmission enable bit */
#define		ti_u0c1			u0c1_addr.bit.ti	/* Transmit buffer empty flag */
#define		re_u0c1			u0c1_addr.bit.re	/* Reception enable bit */
#define		ri_u0c1			u0c1_addr.bit.ri	/* Reception complete flag */
#define		u0irs_u0c1		u0c1_addr.bit.irs	/* UART0 transmit interrupt source select bit */
#define		u0rrm_u0c1		u0c1_addr.bit.rrm	/* UART0 continuous receive mode enable bit */

#define		u2c1		u2c1_addr.byte			/* UART2 Transmit/Receive Control Register 1 */

#define		te_u2c1			u2c1_addr.bit.te	/* Transmission enable bit */
#define		ti_u2c1			u2c1_addr.bit.ti	/* Transmit buffer empty flag */
#define		re_u2c1			u2c1_addr.bit.re	/* Reception enable bit */
#define		ri_u2c1			u2c1_addr.bit.ri	/* Reception complete flag */
#define		u2irs_u2c1		u2c1_addr.bit.irs	/* UART2 transmit interrupt source select bit */
#define		u2rrm_u2c1		u2c1_addr.bit.rrm	/* UART2 continuous receive mode enable bit */
#define		u2lch_u2c1		u2c1_addr.bit.lch	/* Data logic select bit */
#define		u2ere_u2c1		u2c1_addr.bit.ere	/* Error signal output enable bit */

#define		u1c1			u1c1_addr.byte		/* UART1 Transmit/Receive Control Register 1 */

#define		te_u1c1			u1c1_addr.bit.te	/* Transmission enable bit */
#define		ti_u1c1			u1c1_addr.bit.ti	/* Transmit buffer empty flag */
#define		re_u1c1			u1c1_addr.bit.re	/* Reception enable bit */
#define		ri_u1c1			u1c1_addr.bit.ri	/* Reception complete flag */
#define		u1irs_u1c1		u1c1_addr.bit.irs	/* UART1 transmit interrupt source select bit */
#define		u1rrm_u1c1		u1c1_addr.bit.rrm	/* UART1 continuous receive mode enable bit */

/********************************************************
*  declare SFR union                                    *
********************************************************/

__no_init  volatile union{
	struct{
		unsigned char	b0:1;
		unsigned char	b1:1;
		unsigned char	b2:1;
		unsigned char	b3:1;
		unsigned char	b4:1;
		unsigned char	b5:1;
		unsigned char	b6:1;
		unsigned char	b7:1;
		unsigned char	b8:1;
		unsigned char	b9:1;
		unsigned char	b10:1;
		unsigned char	b11:1;
		unsigned char	b12:1;
		unsigned char	b13:1;
		unsigned char	b14:1;
		unsigned char	b15:1;
		unsigned char	b16:1;
		unsigned char	b17:1;
		unsigned char	b18:1;
		unsigned char	b19:1;
	} bit;
	struct{
		unsigned char	low;					/* low  8 bit */
		unsigned char	mid;					/* mid  8 bit */
		unsigned char	high;					/* high 8 bit */
		unsigned char	nc;						/* non use */
	} byte;

	unsigned long	dword;
} rmad0_addr@0x01C0,rmad1_addr@0x01C4;

#define		rmad0		rmad0_addr.dword		/* Address Match Interrupt Register 0 */
#define		rmad0l		rmad0_addr.byte.low		/* Address Match Interrupt Register 0 Low */
#define		rmad0m		rmad0_addr.byte.mid		/* Address Match Interrupt Register 0 Middle */
#define		rmad0h		rmad0_addr.byte.high	/* Address Match Interrupt Register 0 High */
#define		rmad1		rmad1_addr.dword		/* Address Match Interrupt Register 1 */
#define		rmad1l		rmad1_addr.byte.low		/* Address Match Interrupt Register 1 Low */
#define		rmad1m		rmad1_addr.byte.mid		/* Address Match Interrupt Register 1 Middle */
#define		rmad1h		rmad1_addr.byte.high	/* Address Match Interrupt Register 1 High */


__no_init  volatile union{
	struct{
		unsigned char	b0:1;
		unsigned char	b1:1;
		unsigned char	b2:1;
		unsigned char	b3:1;
		unsigned char	b4:1;
		unsigned char	b5:1;
		unsigned char	b6:1;
		unsigned char	b7:1;
		unsigned char	b8:1;
		unsigned char	b9:1;
		unsigned char	b10:1;
		unsigned char	b11:1;
		unsigned char	b12:1;
		unsigned char	b13:1;
		unsigned char	b14:1;
		unsigned char	b15:1;
	} bit;
	struct{
		unsigned char	low;					/* low  8 bit */
		unsigned char	high;					/* high 8 bit */
	} byte;
	unsigned short		word;
} ad0_addr@0x00C0, ad1_addr@0x00C2, ad2_addr@0x00C4, ad3_addr@0x00C6, ad4_addr@0x00C8, ad5_addr@0x00CA, ad6_addr@0x00CC, ad7_addr@0x00CE,
  sstdr_addr@0x0194, ssrdr_addr@0x0196;

/*------------------------------------------------------
  A/D Register 0
------------------------------------------------------*/
#define		ad0			ad0_addr.word			/* A/D Register 0 */
#define		ad0l		ad0_addr.byte.low		/* A/D Register 0 Low */
#define		ad0h		ad0_addr.byte.high		/* A/D Register 0 High */

/*------------------------------------------------------
  A/D Register 1
------------------------------------------------------*/
#define		ad1			ad1_addr.word			/* A/D Register 1 */
#define		ad1l		ad1_addr.byte.low		/* A/D Register 1 Low */
#define		ad1h		ad1_addr.byte.high		/* A/D Register 1 High */

/*------------------------------------------------------
  A/D Register 2
------------------------------------------------------*/
#define		ad2			ad2_addr.word			/* A/D Register 2 */
#define		ad2l		ad2_addr.byte.low		/* A/D Register 2 Low */
#define		ad2h		ad2_addr.byte.high		/* A/D Register 2 High */

/*------------------------------------------------------
  A/D Register 3
------------------------------------------------------*/
#define		ad3			ad3_addr.word			/* A/D Register 3 */
#define		ad3l		ad3_addr.byte.low		/* A/D Register 3 Low */
#define		ad3h		ad3_addr.byte.high		/* A/D Register 3 High */

/*------------------------------------------------------
  A/D Register 4
------------------------------------------------------*/
#define		ad4			ad4_addr.word			/* A/D Register 4 */
#define		ad4l		ad4_addr.byte.low		/* A/D Register 4 Low */
#define		ad4h		ad4_addr.byte.high		/* A/D Register 4 High */

/*------------------------------------------------------
  A/D Register 5
------------------------------------------------------*/
#define		ad5			ad5_addr.word			/* A/D Register 5 */
#define		ad5l		ad5_addr.byte.low		/* A/D Register 5 Low */
#define		ad5h		ad5_addr.byte.high		/* A/D Register 5 High */

/*------------------------------------------------------
  A/D Register 6
------------------------------------------------------*/
#define		ad6			ad6_addr.word			/* A/D Register 6 */
#define		ad6l		ad6_addr.byte.low		/* A/D Register 6 Low */
#define		ad6h		ad6_addr.byte.high		/* A/D Register 6 High */

/*------------------------------------------------------
  A/D Register 7
------------------------------------------------------*/
#define		ad7			ad7_addr.word			/* A/D Register 7 */
#define		ad7l		ad7_addr.byte.low		/* A/D Register 7 Low */
#define		ad7h		ad7_addr.byte.high		/* A/D Register 7 High */

/*------------------------------------------------------
  SS Transmit Data Register
------------------------------------------------------*/
#define		sstdr		sstdr_addr.word			/* SS Transmit Data Register */
#define		sstdrl		sstdr_addr.byte.low		/* SS Transmit Data Register Low */
#define		sstdrh		sstdr_addr.byte.high	/* SS Transmit Data Register High */

/*------------------------------------------------------
  SS Receive Data Register
------------------------------------------------------*/
#define		ssrdr		ssrdr_addr.word			/* SS Receive Data Register */
#define		ssrdrl		ssrdr_addr.byte.low		/* SS Receive Data Register Low */
#define		ssrdrh		ssrdr_addr.byte.high	/* SS Receive Data Register High */


#pragma language=default
#endif  /* __IAR_SYSTEMS_ICC__  */


#endif // __IO_R8CL35C_H__    
